// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.
Jsw.namespace('Smb.Database');

Smb.Database.ListOperations = Class.create(Jsw.Component, {
    openWebAdmin: function(event, databaseId, userLogin) {
        var params = {};
        Event.extend(event).preventDefault();

        if (userLogin) {
            var dbPassword = prompt(this._locale['promptPassword'].replace('%%login%%', userLogin));
            if (!dbPassword) {
                return ;
            }
            params['dbPassword'] = dbPassword;
        }
        Jsw.redirectPost('/database/webadmin/id/' + databaseId, params, 'dbedit');
    },

    connectionInfo: function(event, serverAddress, databaseType, databaseName, userLogin, userPassword) {
        Event.extend(event).preventDefault();

        new Smb.Database.ConnectionInfoPopup({
            cls: 'popup-panel',
            locale: this._locale,
            serverAddress: serverAddress,
            databaseType: databaseType,
            databaseName: databaseName,
            userLogin: userLogin || this._locale.connectionInfoNoUserLogin,
            userPassword: (userLogin && (userPassword || '******')) || ''
        });
    },

    downloadDump: function(event, args) {
        Event.extend(event).preventDefault();
        new Smb.Database.DownloadPopup(Object.extend({
            cls: 'popup-panel',
            locale: this._locale
        }, args));
    },

    uploadDump: function(event, databaseId, databaseName, allowRecreateDatabase, isWebspace) {
        Event.extend(event).preventDefault();
        new Smb.Database.UploadPopup({
            cls: 'popup-panel',
            locale: this._locale,
            databaseId: databaseId,
            databaseName: databaseName,
            allowRecreateDatabase: allowRecreateDatabase,
            isWebspace: isWebspace
        });
    },

    repairDatabase: function(event, databaseId, taskId, tables) {
        Event.extend(event).preventDefault();
        var beginOffset = event.target.cumulativeOffset();
        var progressBar = Jsw.getComponent('asyncProgressBarWrapper');
        var itemId = progressBar.fly(beginOffset,
            this._locale['taskRepairDatabase'],
            function() {
                Jsw.redirectPost(
                    '/database/repair-tables/id/' + databaseId,
                    {
                        tables: tables,
                        taskId: taskId
                    }
                );

            }
        );
    },

    assignToSubscription: function(event, databaseId, isPowerUserMode) {
        Event.extend(event).preventDefault();
        new Smb.Database.AssignToSubscription({
            cls: 'popup-panel',
            locale: this._locale,
            databaseId: databaseId,
            isPowerUserMode : isPowerUserMode
        });
    },

    checkDatabase: function(event, databaseId) {
        Event.extend(event).preventDefault();
        var beginOffset = event.target.cumulativeOffset();
        var progressBar = Jsw.getComponent('asyncProgressBarWrapper');
        var itemId = progressBar.fly(beginOffset,
            this._locale['taskCheckDatabase'],
            function() {
                new Ajax.Request(Jsw.prepareUrl('/database/check/id/' + databaseId), {
                    method: 'post',
                    onSuccess: function(response) {
                        progressBar.removePreparingItem(itemId);
                        progressBar.update();
                    }
                });

            }
        );
    },

    deleteConfirmation: function(event, databaseId) {
        Event.stop(event);
        Jsw.messageBox.show({
            type: Jsw.messageBox.TYPE_YESNO,
            buttonTitles: {
                yes: this._locale['buttonDeleteConfirmationYes'],
                no: this._locale['buttonDeleteConfirmationNo']
            },
            text: this._locale['buttonDeleteConfirmationDescription'],
            subtype: 'delete',
            onYesClick: function() {
                Jsw.redirectPost('/database/delete', {ids: {0: databaseId}, redirect: true});
            }
        });
    }
});

Smb.Database.AssignToSubscription = Class.create(Jsw.PopupForm, {
    _initConfiguration: function($super, config) {
        $super(config);
        this._databaseId = this._getConfigParam('databaseId', null);
        this._ids = this._getConfigParam('ids', []);
        this._isPowerUserMode = this._getConfigParam('isPowerUserMode', null);
        this._handlerUrl = this._getConfigParam('handlerUrl', '/database/assign-to-subscription');
        this._sendButtonId = this._getConfigParam('sendButtonId', 'btn-send');
        this._cancelButtonId = this._getConfigParam('cancelButtonId', 'btn-cancel');
        this._searchElementId = this._id + '-domain-name';
    },

    render: function($super) {
        $super();

        this.setBoxType('form-box');
        this.setTitle(this._isPowerUserMode ? this._locale['assignToWebspacePopupTitle'] : this._locale['assignToSubscriptionPopupTitle']);

        var fieldLabel = this._isPowerUserMode ? this._locale['assignToWebspace'] : this._locale['assignToSubscription'];
        var popupDescription = this._isPowerUserMode ? this._locale['assignToWebspacePopupDesc'] : this._locale['assignToSubscriptionPopupDesc'];
        $(this._contentAreaId).update(
            '<p>' + popupDescription + '</p>' +
            '<form method="post" id="' + this._id + '-form">' +
                '<div class="form-row">' +
                '<div class="field-name"><label for="' + this._id + '-domain-name">' + fieldLabel + '</label></div>' +
                '<div class="field-value" id="' + this._id + '-container">' +
                '</div>' +
                '</form>'
        );

        this._initSearch();
        this._initOnSubmitEvent();
        this.addOkButton();
        this.addCancelButton();
    },

    _initSearch: function() {
        new Jsw.LookUp({
            id: this._searchElementId,
            name:  this._searchElementId,
            renderTo:  this._id + '-container',
            locale: this._locale,
            dataUrl: '/database/subscription-list/',
            copyTitleValue: true
        });
        $(this._searchElementId).focus();
    },

    _onSubmitEvent: function(event) {
        this._handler();
        Event.stop(event);
        return false;
    },

    _initOnSubmitEvent: function() {
        var form = $(this._id + '-form');
        form._formSubmit = form.submit;
        form.submit = this._onOkClick.bind(this);
        form.observe('submit', this._onSubmitEvent.bind(this));
    },

    addOkButton: function() {
        this.addRightButton(this._locale.buttonOk, this._onOkClick, true, true, {id: this._sendButtonId} );
    },

    addCancelButton: function() {
        this.addRightButton(this._locale.buttonCancel, this._onCancelClick, false, false, {id: this._cancelButtonId} );
    },

    _onOkClick: function() {
        this._handler();
    },

    _onCancelClick: function() {
        this.hide();
    },

    disable: function() {
        var sendButtonWrapper = $(this._sendButtonId);
        if (sendButtonWrapper) {
            var sendButton = sendButtonWrapper.down('button');
            sendButton.disabled = true;
            sendButtonWrapper.addClassName('disabled');
            if (!this._sendButtonTitle) {
                this._sendButtonTitle = sendButton.innerHTML;
            }
            sendButton.update('<span class="wait">' + this._locale.loading + '</span>');
        }

        var cancelButtonWrapper = $(this._cancelButtonId);
        if (cancelButtonWrapper) {
            cancelButtonWrapper.down('button').disabled = true;
            cancelButtonWrapper.addClassName('disabled');
        }
    },

    enable: function() {
        var sendButtonWrapper = $(this._sendButtonId);
        if (sendButtonWrapper) {
            sendButton = sendButtonWrapper.down('button');
            sendButton.disabled = false;
            sendButton.update(this._sendButtonTitle);
            sendButtonWrapper.removeClassName('disabled');
        }

        var cancelButtonWrapper = $(this._cancelButtonId);
        if (cancelButtonWrapper) {
            cancelButtonWrapper.down('button').disabled = false;
            cancelButtonWrapper.removeClassName('disabled');
        }
    },

    _onException: function(transport, exception) {
        this._addErrorMessage('Internal error: ' + exception);
        this.enable();
    },

    _onSuccess: function(request) {
        Jsw.clearStatusMessages();
        try {
            var response = request.responseText.evalJSON();
            this._processForm(response);
        } catch (e) {
            // show error, if request wasn't aborted by user
            if (0 != request.status) {
                Jsw.showInternalError(request.responseText);
                this.hide();
            }
        }
    },

    _processForm: function(response) {
        if (response.status && 'error' == response.status) {
            $A(response.statusMessages).each(function(value) {
                Jsw.addStatusMessage(value.status, value.content, { 'title': value.title });
            });

            this.hide();
        } else {
            document.location.reload();
        }
    },

    _handler: function() {
        this.disable();
        var params = {};
        params['domainName'] = $$('[name="' + this._searchElementId + '"]').first().value;
        if ('' == params['domainName']) {
            this.enable();
            return;
        }
        params['ids[]'] = (this._databaseId) ? [this._databaseId] : this._ids;

        new Ajax.Request(
            Jsw.baseUrl + this._handlerUrl,
            {
                method: 'post',
                parameters: params,
                onException: this._onException.bind(this),
                onSuccess: this._onSuccess.bind(this)
            }
        );
    }
});

Smb.Database.DownloadPopup = Class.create(Jsw.PopupForm, {
    _initConfiguration: function($super, config) {
        $super(config);
        this._databaseId = this._getConfigParam('databaseId');
        this._databaseName = this._getConfigParam('databaseName');
        this._isWebspace = this._getConfigParam('isWebspace', false);
        this._dumpExt = 'mssql' == this._getConfigParam('databaseType') ? '.zip' : '.sql.zip';
        this._dumpPathMaxLength = this._getConfigParam('dumpPathMaxLength');
        this._invalidPathChars = this._getConfigParam('invalidPathChars', '');
    },

    _getDateString: function() {
        var padString = function(input) {
            return ('0' + input).slice(-2);
        }

        var dateObj = new Date();
        return dateObj.getFullYear() + '-' + padString(dateObj.getMonth() + 1) + '-' + padString(dateObj.getDate()) + '_' +
            padString(dateObj.getHours())  + '-' + padString(dateObj.getMinutes())  + '-' + padString(dateObj.getSeconds());
    },

    render: function($super) {
        $super();

        this.setBoxType('form-box');
        this.setTitle(this._locale['downloadPopupTitle']);
        this.setTitleType(this._getConfigParam('titleCls', 'pp-download'));

        var dumpName = this._databaseName.escapeHTML() + '_' + this._getDateString();

        var relativePath = this._isWebspace ?
            '<div class="form-row">' +
                '<div class="field-name"><label>' + this._locale['downloadRelativePath'] + '</label></div>' +
                '<div class="field-value">' +
                    '<div class="scrollable fm-scrollable">' +
                        '<div class="scrollable-wrap">' +
                            '<div id="' + this._id + '-files-tree" class="tree"></div>' +
                        '</div>' +
                    '</div>' +
                '</div>' +
            '</div>'
            : '';
        $(this._contentAreaId).update(
            '<form method="post" id="' + this._id + '-form">' +
                '<p>' + this._locale['downloadHint'].replace('%%database%%', '<b>' + this._databaseName.escapeHTML() + '</b>') + '</p>' +
                relativePath +
                '<div class="form-row">' +
                    '<div class="field-name"><label for="' + this._id + '-dump-name">' + this._locale['downloadDumpName'] + '</label></div>' +
                    '<div class="field-value">' +
                        '<input id="' + this._id + '-dump-name" type="text" class="input-text f-middle-size" value="' + dumpName + '">' + this._dumpExt +
                        '<span class="field-errors" style="display: none;"></span>' +
                    '</div>' +
                '</div>' +
                '<div class="form-row">' +
                    '<div class="single-row">' +
                        '<div class="indent-box">' +
                            '<input type="checkbox" id="' + this._id + '-download-dump-automatically" class="checkbox">' +
                            '<div class="indent-box-content">' +
                                '<label for="' + this._id + '-download-dump-automatically">' + this._locale.downloadDumpAutomatically + '</label>' +
                            '</div>' +
                        '</div>' +
                    '</div>' +
                '</div>' +
            '</form>'
        );

        if (this._isWebspace) {
            this._tree = new Smb.FileManager.Tree({
                applyTo: this._id + '-files-tree',
                data: null,
                dataUrl: '/file-manager/tree-data',
                rootNodeTitle: this._locale['rootDirectory'],
                waitMessage: this._locale['waitMessage'],
                onReload: function() {
                    this.setDirectory('/');
                }
            });
        }

        $(this._id + '-form').observe('submit', this._onOkClick.bindAsEventListener(this));
        this._buttonOk = this.addRightButton(this._locale['buttonOk'], this._onOkClick, true, true);
        this._buttonCancel = this.addRightButton(this._locale['buttonCancel'], this._onCancelClick, false, false);
        $(this._id + '-dump-name').focus();
    },

    _onOkClick: function(event) {
        if (event) {
            event.preventDefault();
        }
        if (this._buttonOk.down('button').disabled) {
            return;
        }

        this._clearFieldErrors();

        var dumpName = $(this._id + '-dump-name').getValue();
        if ('' == dumpName) {
            this._addFieldError(this._locale.errorDumpNameEmpty);
            return;
        }

        if (0 != this._invalidPathChars.length && dumpName.match(new RegExp("[" + this._invalidPathChars + "]"))) {
            this._addFieldError(this._locale.errorDumpNameInvalid.replace('%%chars%%', this._invalidPathChars));
            return;
        }

        var context = this;
        var params = {
            relativePath: this._isWebspace ? this._tree.getSelectedItemData().path : '',
            dumpName: dumpName + this._dumpExt
        };

        if ((params['relativePath'] + '/' + params['dumpName']).length > this._dumpPathMaxLength) {
            this._addFieldError(this._locale.errorDumpNameTooLong.replace('%%maxLength%%', this._dumpPathMaxLength));
            return;
        }

        var downloadDumpAutomatically = $(this._id + '-download-dump-automatically').checked;

        this._updateButton(this._buttonOk, {disabled: true});
        this._updateButton(this._buttonCancel, {disabled: true});
        var beginOffset = this._buttonOk.cumulativeOffset();
        var progressBar = Jsw.getComponent('asyncProgressBarWrapper');
        var itemId = progressBar.fly(beginOffset,
            this._locale['downloadTask'].replace('%%database%%', this._databaseName.escapeHTML()),
            function(){
                context.hide();
                new Ajax.Request(Jsw.prepareUrl('/database/download-dump/id/' + context._databaseId), {
                    method: 'post',
                    parameters: params,
                    onSuccess: function(response) {
                        var response = response.responseText.evalJSON();
                        if (response.redirect) {
                            Jsw.redirect(response.redirect);
                            return;
                        }
                        var onItemStatusChange = progressBar.onItemStatusChange;
                        progressBar.onItemStatusChange = function(item) {
                            onItemStatusChange(item);
                            if (downloadDumpAutomatically && 'database-download' == item['type'] && 'done' == item['status']) {
                                var downloadLink = new Element('div').insert(item['progressTitle']).select('.download-link').first();
                                var downloadParams = downloadLink ? downloadLink.href.toQueryParams() : {};
                                if (downloadParams.file == params.dumpName && downloadParams.currentDir == params.relativePath) {
                                    Jsw.redirect(downloadLink.href);
                                }
                            }
                        };
                        progressBar.removePreparingItem(itemId);
                        progressBar.update();
                    }
                });
            });
    },

    _onCancelClick: function() {
        this.hide();
    },

    _addFieldError: function(message) {
        var errors = $(this._id + '-dump-name').next('.field-errors');
        errors.up('.form-row').addClassName('error');
        errors.update('<span class="error-hint">' + message.escapeHTML() + '</span>');
        errors.show();
    },

    _clearFieldErrors: function() {
        var errors = $(this._id + '-dump-name').next('.field-errors');
        errors.up('.form-row').removeClassName('error');
        errors.hide();
    }
});

Smb.Database.UploadPopup = Class.create(Jsw.PopupForm, {
    _initConfiguration: function($super, config) {
        $super(config);
        this._databaseId = this._getConfigParam('databaseId');
        this._databaseName = this._getConfigParam('databaseName');
        this._isWebspace = this._getConfigParam('isWebspace');
        this._allowRecreateDatabase = this._getConfigParam('allowRecreateDatabase', false);
    },

    render: function($super) {
        $super();

        this.setBoxType('form-box');
        this.setTitle(this._locale['uploadPopupTitle']);
        this.setTitleType(this._getConfigParam('titleCls', 'pp-upload'));
        var recreateDatabaseContent = this._allowRecreateDatabase ?
            '<div class="form-row">' +
                '<div class="single-row">' +
                    '<div class="indent-box">' +
                        '<input type="checkbox" value="1" name="recreateDatabase" id="' + this._id + '-recreate-database" class="checkbox" checked="checked">' +
                        '<div class="indent-box-content">' +
                            '<label for="' + this._id + '-recreate-database">' + this._locale.recreateDatabase + '</label>' +
                        '</div>' +
                    '</div>' +
                '</div>' +
            '</div>' : '';

        $(this._contentAreaId).update(
            '<form method="post" action="' + Jsw.prepareUrl('/database/upload-dump/id/' + this._databaseId) + '" enctype="multipart/form-data" id="' + this._id + '-form" target="_uploadIFrame">' +
                '<input name="forgery_protection_token" type="hidden" value="' + $('forgery_protection_token').content + '"/>' +
                '<p>' + this._locale['uploadHint'].replace('%%database%%', '<b>' + this._databaseName.escapeHTML() + '</b>') + '</p>' +
                (!this._isWebspace ? (
                '<div class="form-row">' +
                    '<div class="single-row">' +
                        '<input id="' + this._id + '-dump-file" name="file[]" type="file" class="input-file f-max-size">' +
                    '</div>' +
                '</div>'
                ) : (
                '<div class="form-row">' +
                    '<div class="single-row">' +
                        '<div class="indent-box">' +
                            '<input type="radio" value="file" id="' + this._id + '-upload-type-file" class="radio" name="' + this._id + '-upload-type" checked>' +
                            '<div class="indent-box-content">' +
                                '<label for="' + this._id + '-upload-type-file">' + this._locale.uploadFromFile + '</label>' +
                                '<div class="form-row">' +
                                    '<div class="single-row">' +
                                        '<input id="' + this._id + '-dump-file" name="file[]" type="file" class="input-file f-max-size">' +
                                    '</div>' +
                                '</div>' +
                            '</div>' +
                        '</div>' +
                        '<div class="indent-box">' +
                            '<input type="radio" value="webspace" id="' + this._id + '-upload-type-webspace" class="radio" name="' + this._id + '-upload-type">' +
                            '<div class="indent-box-content">' +
                                '<label for="' + this._id + '-upload-type-webspace">' + this._locale.uploadFromWebspace + '</label>' +
                                '<div class="form-row">' +
                                    '<div class="single-row">' +
                                        '<div class="scrollable fm-scrollable">' +
                                            '<div class="scrollable-wrap">' +
                                                '<div id="' + this._id + '-files-tree" class="tree"></div>' +
                                            '</div>' +
                                        '</div>' +
                                    '</div>' +
                                '</div>' +
                            '</div>' +
                        '</div>' +
                    '</div>' +
                '</div>'
                )) +
                recreateDatabaseContent +
            '</form>'
        );

        if (this._isWebspace) {
            this._tree = new Smb.FileManager.Tree({
                applyTo: this._id + '-files-tree',
                data: null,
                dataUrl: '/file-manager/tree-data',
                showFiles: true,
                rootNodeTitle: this._locale['rootDirectory'],
                waitMessage: this._locale['waitMessage'],
                onNodeClick: this._onTreeNodeClick.bind(this),
                onRootNodeClick: this._onTreeNodeClick.bind(this),
                onReload: function() {
                    this.setDirectory('/');
                }
            });
        }

        this._fileInputElement = $(this._id + '-dump-file');
        this._fileInputElement.observe('click', this._onFileInputClick.bind(this));
        this._fileInputElement.observe('change', this._updateOkStatus.bind(this));

        if (this._isWebspace) {
            this._uploadTypeFile = $(this._id + '-upload-type-file');
            this._uploadTypeFile.observe('change', this._updateOkStatus.bind(this));

            this._uploadTypeWebspace = $(this._id + '-upload-type-webspace');
            this._uploadTypeWebspace.observe('change', this._updateOkStatus.bind(this));
        }

        this._uploadAdapter = new Smb.FileManager.UploadAdapterIframe({
            contentAreaId: this._contentAreaId,
            handlerUrl: this._fileInputElement.up('form').action,
            startUploadHandler: function() {},
            finishUploadHandler: this._onFinishUpload.bind(this),
            progressUploadHandler: function() {}
        });

        this._buttonOk = this.addRightButton(this._locale['buttonOk'], this._onOkClick, true, true, {disabled: true});
        this._updateButton(this._buttonOk, {disabled: true});
        this._buttonCancel = this.addRightButton(this._locale['buttonCancel'], this._onCancelClick, false, false);
    },

    _onTreeNodeClick: function() {
        this._uploadTypeWebspace.checked = true;
        this._updateOkStatus();
    },

    _onFileInputClick: function() {
        this._uploadTypeFile.checked = true;
        this._updateOkStatus();
    },

    _updateOkStatus: function() {
        var checkStatus = this._fileInputElement.value;
        if (this._isWebspace) {
            checkStatus = checkStatus && this._uploadTypeFile.checked || this._uploadTypeWebspace.checked && !this._tree.getSelectedItemData().isDirectory;
        }
        this._updateButton(this._buttonOk, {
            disabled: !(checkStatus)
        });
    },

    _onOkClick: function() {
        this._updateButton(this._buttonOk, {
            title: '<span class="wait">' + this._locale.uploading + '</span>',
            disabled: true
        });

        this._updateButton(this._buttonCancel, {disabled: true});
        var recreateDatabase = this._allowRecreateDatabase ? $(this._id + '-recreate-database').checked : false;

        var uploadTypeFile = this._isWebspace ? this._uploadTypeFile.checked : true;
        if (uploadTypeFile) {
            this._fileInputElement.up('form').submit();
            return;
        }

        var context = this;
        var beginOffset = this._buttonOk.cumulativeOffset();
        var progressBar = Jsw.getComponent('asyncProgressBarWrapper');
        var itemId = progressBar.fly(beginOffset,
            this._locale.uploadTask.replace('%%database%%', this._databaseName.escapeHTML()),
            function(){
                context.hide();
                new Ajax.Request(Jsw.prepareUrl('/database/upload-dump/id/' + context._databaseId), {
                    method: 'post',
                    parameters: {
                        recreateDatabase: recreateDatabase,
                        dumpPath: context._isWebspace ? context._tree.getSelectedItemData().path : ''
                    },
                    onSuccess: function(response) {
                        progressBar.removePreparingItem(itemId);
                        progressBar.update();
                    }
                });
            });
    },

    _onFinishUpload: function() {
        var context = this;

        var beginOffset = this._buttonOk.cumulativeOffset();
        var progressBar = Jsw.getComponent('asyncProgressBarWrapper');
        var itemId = progressBar.fly(beginOffset,
            this._locale.uploadTask.replace('%%database%%', this._databaseName.escapeHTML()),
            function() {
                context.hide();
                progressBar.removePreparingItem(itemId);
                progressBar.update();
            });
    },

    _onCancelClick: function() {
        this.hide();
    }
});

Smb.Database.ConnectionInfoPopup = Class.create(Jsw.PopupForm, {
    _initConfiguration: function($super, config) {
        $super(config);
        this._serverAddress = this._getConfigParam('serverAddress');
        this._databaseType = this._getConfigParam('databaseType');
        this._databaseName = this._getConfigParam('databaseName');
        this._userLogin = this._getConfigParam('userLogin');
        this._userPassword = this._getConfigParam('userPassword');
    },

    render: function($super) {
        $super();

        this.setBoxType('form-box');
        this.setTitle(this._locale.connectionInfoTitle.replace('%%database%%', this._databaseName));
        this.setHint1(this._locale.connectionInfoDesc);

        $(this._contentAreaId).update(
            '<div class="form-row">' +
                '<div class="field-name">' + this._locale.connectionInfoServerAddress + '</div>' +
                '<div class="field-value"><div class="text-value"><b>' + this._serverAddress + '</b></div></div>' +
            '</div>' +
            '<div class="form-row">' +
                '<div class="field-name">' + this._locale.connectionInfoDatabaseName + '</div>' +
                '<div class="field-value"><div class="text-value"><b>' + this._databaseName + '</b></div></div>' +
            '</div>' +
            '<div class="form-row">' +
                '<div class="field-name">' + this._locale.connectionInfoUserLogin + '</div>' +
                '<div class="field-value"><div class="text-value"><b>' + this._userLogin + '</b></div></div>' +
            '</div>' +
            '<div class="form-row">' +
                '<div class="field-name">' + this._locale.connectionInfoUserPassword + '</div>' +
                '<div class="field-value"><div class="text-value"><b>' + this._userPassword + '</b></div></div>' +
            '</div>'
        );

        this.addRightButton(this._locale.buttonClose, function() {
            this.hide();
        }.bind(this));
    }
});
