// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.
Jsw.ScrollableList = Class.create(Jsw.List, {
    _getListHtml: function() {
        return '' +
            this._getPagerHtml() +
            '<div class="' + this._listCls + ' scrollable-list">' +
                '<table width="100%" cellspacing="0" class="fixed-table-head">' +
                '</table>' +
                '<div class="scrollable-list-wrapper">' +
                    '<table width="100%" cellspacing="0" id="' + this._tableId + '" class="scrollable-list-table">' +
                        this._getListHeadersHtml() +
                        this._getListDataHtml() +
                    '</table>' +
                '</div>' +
            '</div>' +
            this._getPagerHtml() +
            '<span class="empty-list">' + this._locale.noEntriesFound + '</span>';
    },

    checkEmptyList: function($super) {
        $super();

        var isEmpty = this.isListEmpty();
        this._componentElement.select('.' + this._listCls).invoke('toggle', true);
        this._componentElement.select('.scrollable-list-wrapper').invoke('toggle', !isEmpty);
    },

    redraw: function($super, place, dataLen) {
        var bottom = true;
        var scrollTop, tableHeight = 0;
        var wrapper = $(this._id).down('.scrollable-list-wrapper');
        if (wrapper) {
            bottom = (wrapper.offsetHeight + wrapper.scrollTop >= wrapper.scrollHeight);
            scrollTop = wrapper.scrollTop;
            tableHeight = $(this._tableId).getHeight();
        }

        $super(place, dataLen);
        var table = $(this._tableId);
        var headerTable = table.up('.' + this._listCls).down('.fixed-table-head');
        var invisibleHeader = table.down('thead');
        var visibleHeader = headerTable.down('thead');
        if (!visibleHeader) {
            visibleHeader = invisibleHeader.clone(true);
            headerTable.insert(visibleHeader);
        }

        table.setStyle({marginTop: -headerTable.getHeight() + 'px'});
        setTimeout(function() {
            this._resizeList();
            var wrapper = table.up('.scrollable-list-wrapper');
            if (bottom) {
                this.scrollToBottom();
            } else if ('before' == place) {
                wrapper.scrollTop += table.getHeight() - tableHeight;
            } else if ('after' == place) {
            } else {
                wrapper.scrollTop = scrollTop;
            }
        }.bind(this), 0);
        this._initDropdowns();
        Jsw.Tooltip.initData(visibleHeader);
    },

    updateFilter: function($super, force) {
        $super(force);
        this._resizeList();
    },

    scrollToBottom: function() {
        var table = $(this._tableId);
        var wrapper = table.up('.scrollable-list-wrapper');
        wrapper.scrollTop = wrapper.select('tr').filter(Element.visible).last().offsetTop;
    },

    _resizeList: function() {
        var minHeight = 200;
        var table = $(this._tableId);
        var wrapper = table.up('.scrollable-list-wrapper');

        var headerTable = table.up('.' + this._listCls).down('.fixed-table-head');
        var visibleHeader = headerTable.down('thead');
        if (visibleHeader) {
            var isEmpty = this.isListEmpty();
            visibleHeader.select('tr').each(function(tr) {
                if (!tr.hasClassName('list-search-filter')) {
                    isEmpty ? tr.hide() : tr.show();
                }
            });
        }

        var blockHeight = $(document.body).getHeight() - wrapper.cumulativeOffset().top;
        for (var up = wrapper; up instanceof Element; up = up.up()) {
            blockHeight = blockHeight
                - (parseInt(up.getStyle('borderBottomWidth')) || 0)
                - (parseInt(up.getStyle('marginBottom')) || 0)
                - (parseInt(up.getStyle('paddingBottom')) || 0);
            for (var next = up.next(); next instanceof Element; next = next.next()) {
                if ('none' != next.getStyle('display')) {
                    blockHeight = blockHeight - next.getHeight();
                }
            }
        }

        if (blockHeight < minHeight) {
            blockHeight = minHeight;
        }

        if (blockHeight > table.getHeight() + parseInt(table.getStyle('marginTop'))) {
            wrapper.setStyle({height: null});
        } else {
            wrapper.setStyle({height: blockHeight + 'px'});
        }

        if (!visibleHeader || table.select('tr.odd,tr.even').filter(Element.visible) == 0) {
            return;
        }

        var invisibleHeader = table.down('thead');
        invisibleHeader.select('th').each(function(th, index) {
            visibleHeader.select('th')[index].setStyle({width: th.getWidth() + 'px'});
        });
        var lastHeader = visibleHeader.down('th:last');
        lastHeader.setStyle({width: (headerTable.getWidth() - invisibleHeader.up('table').getWidth()) + parseInt(lastHeader.getStyle('width')) +'px'});
    },

    _addResponsiveHtml: function() {
        // Don't need responsive UI in case of logs list
    },

    _addEvents: function($super) {
        $super();
        Event.observe(
            window,
            'resize',
            this._resizeList.bind(this),
            false
        );
    }
});