// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.
Jsw.namespace('Jsw.WordpressPopupManager');

Jsw.WordpressPopupManager.updatesConfirmation = function(ids, name, locale, onYesClick) {
    Jsw.messageBox.show({
        type: Jsw.messageBox.TYPE_YESNO,
        isAjax: true,
        requestUrl: Jsw.prepareUrl('/wordpress/backup/'),
        requestParams: {'ids[]': ids},
        subtype: 'toggle',
        text: locale.updatesConfirmTitle.replace('%%name%%', '<b>' + name + '</b>'),
        onYesClick: onYesClick,
        buttonTitles: {
            yes: locale.updatesConfirmYes,
            no: locale.updatesConfirmNo
        }
    });
}

Jsw.WordpressPopupManager.manageThemes = function(ids, name, locale, dashboardUrl, returnUrl) {
    new Jsw.WordpressPopupManager.ManageThemes({
        id: 'manageThemes',
        cls: 'popup-panel popup-panel-wordpress',
        prepareUrl: Jsw.prepareUrl('/wordpress/installed-themes/'),
        handlerUrl: Jsw.prepareUrl('/wordpress/update-installed-themes/'),
        returnUrl: returnUrl,
        locale: locale,
        ids: ids,
        name: name,
        dashboardUrl: dashboardUrl,
        longtask: locale.taskUpdate
    });
}

Jsw.WordpressPopupManager.managePlugins = function(ids, name, locale, dashboardUrl, returnUrl) {
    new Jsw.WordpressPopupManager.ManagePlugins({
        id: 'managePlugins',
        cls: 'popup-panel popup-panel-wordpress',
        prepareUrl: Jsw.prepareUrl('/wordpress/installed-plugins/'),
        handlerUrl: Jsw.prepareUrl('/wordpress/update-installed-plugins/'),
        returnUrl: returnUrl,
        locale: locale,
        ids: ids,
        name: name,
        dashboardUrl: dashboardUrl,
        longtask: locale.taskUpdate
    });
}

Jsw.WordpressPopupManager.securityScan = function(ids, name, locale) {
    new Jsw.WordpressPopupManager.CheckWordpressInstances({
        id: 'securityScan',
        cls: 'popup-panel popup-panel-wordpress popup-panel-security',
        prepareUrl: Jsw.prepareUrl('/wordpress/check/'),
        handlerUrl: Jsw.prepareUrl('/wordpress/check/resolve/1/'),
        rollbackUrl: Jsw.prepareUrl('/wordpress/check/rollback/1/'),
        locale: locale,
        ids: ids,
        name: name,
        sendButtonId: 'resolveButton',
        cancelButtonId: 'cancelButton'
    });
}

Jsw.WordpressPopupManager.CommonPopupForm = Class.create(Jsw.ConfirmationPopupManager.PopupForm, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._name = this._getConfigParam('name', '');
        this._dashboardUrl = this._getConfigParam('dashboardUrl', null);
        this._returnUrl = this._getConfigParam('returnUrl', null);
    },

    getName: function() {
        return this._name;
    },

    _getUrl: function() {
        return this._dashboardUrl;
    },

    _setHintToItems: function() {
        this._setInfoHint();
        this._setTogglerHint();
    },

    _setInfoHint: function() {
        $$('span.hint.hint-info').each(function(hintElement) {
            var jsItemTitleElement = hintElement.up('td').down('.jsItemTitle');
            var textContent = jsItemTitleElement.textContent || jsItemTitleElement.innerText;
            var tooltip = new Jsw.AjaxTooltip.Instance({
                title: textContent.escapeHTML(),
                target: hintElement
            });
            tooltip.setText(hintElement.down('.tooltipData').innerHTML.replace(/\n/, '<br>'));
        });
    },

    _setTogglerHint: function() {
        $(this._formListAreaId).select('.toggler').each(function(hintElement) {
            var jsItemTitleElement = hintElement.up('tr').down('.jsItemTitle');
            var textContent = jsItemTitleElement.textContent || jsItemTitleElement.innerText;
            var tooltip = new Jsw.AjaxTooltip.Instance({
                title: textContent.escapeHTML(),
                target: hintElement
            });
            tooltip.setText(hintElement.up('td').down('.tooltipData').innerHTML);
        });
    },

    _setTitle: function() {
        if (1 === this._ids.length) {
            this.setTitle(this.lmsg('titleSingle', {url: this.getName().escapeHTML()}));
        } else {
            this.setTitle(this.lmsg('title', {number: this._ids.length}));
        }
    }

});

Jsw.WordpressPopupManager.CheckWordpressInstances = Class.create(Jsw.WordpressPopupManager.CommonPopupForm, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._formListAdditionalCheckersAreaId = this._id + '-form-list-additional-checkers';

        this._rollbackUrl = this._getConfigParam('rollbackUrl', null);
        this._reloadOnCancel = false;
        this._backupDescription = '';
    },

    _renderPreparePopup: function($super) {
        $super();
        $(this._sendButtonId).firstDescendant().disable();
    },

    _onCancelClick: function() {
        this.hide();
        var popup = $('wordPressInstancesListPopup');
        if (popup) {
            popup.toggleClassName('collapsed', true);
        }
        if (this._reloadOnCancel) {
            var list = Jsw.getComponent('wordpress-instances-list');
            if (list) {
                list.reload();
            }
        }
    },

    _updateReloadOnCancel: function(checkResults, cachedResults) {
        for (var wpInstanceId in checkResults) {
            if (cachedResults[wpInstanceId] && checkResults[wpInstanceId] != cachedResults[wpInstanceId]) {
                this._reloadOnCancel = true;
                return;
            }
        }
    },

    _onSuccessPreparePopup: function(transport) {

        this._clearMessages();
        $(this._sendButtonId).firstDescendant().enable();
        try {
            this._response = transport.responseText.evalJSON();
            if ('success' != this._response.status) {
                if (this._response.redirect) {
                    Jsw.redirect(this._response.redirect);
                    return;
                }
                this._addErrorMessage(this._response.message.replace(/\n/, '<br>'));
            }

            if (0 >= this._response.checkers.length) {
                $(this._formBoxAreaId).update('');
                $(this._formListAreaId).update( '<p>' + this.lmsg('checkersNotFound') + '</p>');
                return
            }

            $(this._formBoxAreaId).update('');
            $(this._formListAreaId).update(
                '<table cellspacing="0" width="100%">' +
                    '<tbody id="' + this._formListItemsAreaId + '">' +
                    '</tbody>' +
                '</table>' +
                (this._response.hasAdditionalCheckers ? '<br/>' +
                '<p>' + this.lmsg('additionalCheckersDescription') + '</p>' +
                    '<table cellspacing="0" width="100%">' +
                    '<tbody id="' + this._formListAdditionalCheckersAreaId + '">' +
                    '</tbody>' +
                '</table>' : '')
            );

            this._response.checkers.each(function(checker) {
                this._addChecker(checker);
            }, this);
            this._updateReloadOnCancel(this._response.checkResults, this._response.cachedResults);

            if (this._response.backupLink) {
                this._backupDescription = this.lmsg('securityConfirmBackup', {link: this._response.backupLink});
            }

            this._onAllSuccess();

            this._checkChosenCheckers(this);

        } catch (e) {
            this._addErrorMessage(e.message);
            this._addErrorMessage(
                'Internal error: ' + transport.responseText
            );
        }
    },

    _getLoadingIndicatorItems: function(checkers) {
        var items = [];
        $$('.checkers').each(function(row) {
            if (row.checked) {
                items[row.title] = row.title;
            }
        });

        return items;
    },

    _addLoadingIndicator: function(checkers) {
        for (var checker in checkers) {
            if (!checkers.hasOwnProperty(checker)) continue;
            $('checker-image-' + checkers[checker]).src = Jsw.skinUrl + '/icons/16/plesk/indicator.gif';
        }
    },

    _addChecker: function(checker) {
        this._itemClass = ('odd' == this._itemClass) ? 'even' : 'odd';

        var image = (0 == checker.unresolved)
            ? '<img id="checker-image-' + checker.id + '" src="' + Jsw.skinUrl + '/icons/16/plesk/ok.png" title="">'
            : '<img id="checker-image-' + checker.id + '" src="' + Jsw.skinUrl + '/icons/16/plesk/' + (checker.isAdditional ? 'att.png' : 'warning.png') + '" title="' + checker.mainMessage.escapeHTML() + '">';
        var warning = ('' != checker.warningMessage)
            ? '<div class="error-hint hint-sub">' + checker.warningMessage.escapeHTML() + '</div>'
            : '';
        var hint = ('' != checker.hintMessage)
            ? '<span class="hint hint-info" id="hint_' + checker.id + '"> (?)<span class="tooltipData">' + checker.hintMessage.stripTags().escapeHTML() + '</span></span>'
            : '';
        var unresolvedText = (1 < this._ids.length && 0 < checker.unresolved)
            ? '<div class="info-hint hint-sub" id="checker-not-secure-item-' + checker.id + '">' + this.lmsg('notSecureOn') + ' ' +
            '<a class="toggler" href="#" id="wordpress-count-item-' + checker.id + '">' +
            this.lmsg('wordPressCount', {count: checker.unresolved}) +
            '</a>' +
            '</div>'
            : '<div class="info-hint hint-sub" id="checker-not-secure-item-' + checker.id + '"></div>';

        var itemHtml = '' +
            '<tr class="' + this._itemClass + '">' +
                '<td>' +
                    '<div class="b-indent">' +
                        '<span class="b-indent-icon">' +
                            image +
                        '</span>' +
                        '<span class="jsItemTitle">' +
                            checker.title.escapeHTML() +
                        '</span>' +
                        hint +
                        warning +
                        unresolvedText +
                    '</div>' +
                '</td>' +
                '<td class="last t-r">' + this._getCheckerHtml(checker) + '</td>' +
            '</tr>';

        if (checker.isAdditional) {
            $(this._formListAdditionalCheckersAreaId).insert({bottom : itemHtml});
        } else {
            $(this._formListItemsAreaId).insert({bottom : itemHtml});
        }

        this._addCheckChosenCheckersListener(checker);
        this._addWordPressCountCheckerListener(checker);
        this._addRollbackButton(checker);
    },

    _getNotSecuredCheckerHintHtml: function(checker) {
        var unresolvedText = (1 < this._ids.length && 0 < checker.unresolved)
            ? this.lmsg('notSecureOn') + ' ' +
            '<a class="toggler" href="#" id="wordpress-count-item-' + checker.id + '">' +
            this.lmsg('wordPressCount', {count: checker.unresolved}) +
            '</a>'
            : '';
        $('checker-not-secure-item-' + checker.id).update(unresolvedText);
        this._addWordPressCountCheckerListener(checker);
    },

    _addWordPressCountCheckerListener: function(checker)
    {
        var unresolvedCountElement = $('wordpress-count-item-' + checker.id);
        if (unresolvedCountElement) {
            unresolvedCountElement.observe('click',
                this._getUnresolved.bindAsEventListener(this, checker)
            );
        }
    },

    _addCheckChosenCheckersListener: function(checker)
    {
        var checkerElement = $('checker-checkbox-' + checker.id);
        if (checkerElement) {
            checkerElement.observe('change',
                this._checkChosenCheckers.bindAsEventListener(this)
            );
        }
    },

    _checkChosenCheckers: function(event) {
        var checkedCheckersCount = 0;
        $$('.checkers').each(function(row){
            if (row.checked) {
                checkedCheckersCount++;
            }
        });

        if (0 < checkedCheckersCount) {
            $(this._sendButtonId).show();
        } else {
            $(this._sendButtonId).hide();
        }
    },

    _setTogglerHint: function() {

    },

    _getUnresolved: function(event, checker) {
        Event.stop(event);
        var resultElement = $('wordPressInstancesListResult');
        if (resultElement) {
            var instanceId;
            var instancesText = '';
            for (instanceId in checker.unresolvedInstances) {
                var instance = checker.unresolvedInstances[instanceId];
                instancesText += '<tr><td>' +
                    '<a href="' + Jsw.baseUrl + '/wordpress/detail/id/' + instanceId + '">' + instance.name.escapeHTML() + '</a>' +
                    '</td><td>(' +
                    '<a href="' + instance.url + '" target="_blank">' + instance.url + '</a>)' +
                '</td></tr>'
            }
            resultElement.update(instancesText);
        }
        var popupElement = $('wordPressInstancesListPopup');
        var topOffset = 0;
        if (popupElement) {
            popupElement.toggleClassName('collapsed', false);
            var currentElement = $('wordpress-count-item-' + checker.id);

            var pos = currentElement.cumulativeOffset();
            var elWidth = popupElement.getWidth();
            var elHeight = popupElement.getHeight();
            var leftPos = (pos[0] - elWidth);
            var topPos = (pos[1]-(elHeight/2)+18);

            var marginTop = parseFloat(popupElement.getStyle('margin-top'));
            var dimensions = document.viewport.getDimensions();
            var viewportOffset = currentElement.getBoundingClientRect();
            var popupBottom = (elHeight/2 + 2*Math.abs(marginTop) + viewportOffset.top);
            var popupTop = popupBottom - elHeight;
            var offset = dimensions.height - popupBottom;

            if (offset < 0) {
                topPos += offset;
                topOffset -= offset;
                if (topPos < 0) {
                    topPos = 0;
                    topOffset -= topPos;
                }
            } else {
                if (topPos < 0) {
                    topOffset = topPos;
                    topPos = 0;
                    if (marginTop < 0 ) {
                        topOffset += marginTop;
                        topPos =  Math.abs(marginTop);
                    }
                } else {
                    if (popupTop < 0) {
                        topPos -= popupTop;
                        topOffset += popupTop;
                    }
                }
            }

            popupElement.removeClassName('collapsed');
            popupElement.setStyle({'left': leftPos + 'px', 'top': topPos + 'px'});
        }

        var arrowElement = $$('.arrow').first();
        if (arrowElement) {
            arrowElement.setStyle({ 'top': '50%'});
            if (topOffset != 0) {
                var topPercent = 50*(elHeight + 2 * topOffset)/(elHeight);
                arrowElement.setStyle({ 'top': topPercent.toFixed(2) + '%'});
            }
        }
    },

    _getCheckerHtml: function(checker) {
        var checked = (checker.chosenByDefault) ? 'checked' : '';
        var checkerHtml = (0 == checker.unresolved)
            ? '<span id="checker-text-' + checker.id + '">' + this.lmsg('ok') + '</span>'
            : '<input class="checkers" type="checkbox" name="checkers[' + checker.id + ']" id="checker-checkbox-' + checker.id + '" ' + checked + ' title="' + checker.id + '">';

        return checkerHtml;
    },

    _onSuccessResponse: function(response) {
        this.enable();

        if (0 >= response.checkers.length) {
            return;
        }

        response.checkers.each(function(checker) {

            if (0 == checker.unresolved) {
                if ($('checker-checkbox-' + checker.id)) {
                    $('checker-checkbox-' + checker.id).up().update(this._getCheckerHtml(checker));
                }
                $('checker-image-' + checker.id).src = Jsw.skinUrl + '/icons/16/plesk/ok.png';
                this._addRollbackButton(checker);
                this._getNotSecuredCheckerHintHtml(checker);

            } else {
                if ($('checker-text-' + checker.id)) {
                    $('checker-text-' + checker.id).up().update(this._getCheckerHtml(checker));
                }
                $('checker-image-' + checker.id).src = Jsw.skinUrl + '/icons/16/plesk/' + (checker.isAdditional ? 'att.png' : 'warning.png');
                this._getNotSecuredCheckerHintHtml(checker);

            }
            this._addCheckChosenCheckersListener(checker);
            this._onAllSuccess();
        }, this);
        this._updateReloadOnCancel(response.checkResults, response.cachedResults);
    },

    _getHeadDescription: function() {
        return '<p id="' + this._formDescriptionId + '-headDescription">' + this.lmsg('headDescription') + '</p>';
    },

    _getBottomDescription: function() {
        return '<p style="display: none" id="' + this._formDescriptionId + '-bottomDescription"></p>';
    },

    _getAdditionalParams: function(params) {
        $$('.checkers').each(function(row){
            params.set('checkers[' + row.title + ']', row.checked);
        });
        return params;
    },

    _onAllSuccess: function() {
        var bottomDescription = $(this._formDescriptionId + '-bottomDescription');
        if (0 >= $$('.checkers').length) {
            $(this._sendButtonId).hide();
            bottomDescription.writeAttribute('align', 'center');
            bottomDescription.update(this.lmsg('bottomDescription'));
            bottomDescription.show();
        } else {
            $(this._sendButtonId).show();
            bottomDescription.writeAttribute('align', null);
            bottomDescription.update(this._backupDescription);
            this._backupDescription ? bottomDescription.show() : bottomDescription.hide();
        }
        this._checkChosenCheckers(this);
        this._setHintToItems();
    },

    _onRollbackSubmit: function(event) {
        var rollbackChecker = $(event.target).up().readAttribute('data');

        var params = $H();
        var count = 0;
        this._ids.each(function(id) {
            params.set('ids[' + count + ']', id);
            count++;
        });

        params.set('checkers[' + rollbackChecker + ']', true);

        this.disable();
        this._addLoadingIndicator([rollbackChecker]);

        new Ajax.Request(
            this._rollbackUrl,
            {
                method: 'post',
                parameters: params,
                onSuccess: this._onSuccess.bind(this),
                onException: this._onException.bind(this)
            }
        );
    },

    _addRollbackButton: function(checker) {
        if (checker.hasRollback && 0 == checker.unresolved) {
            if ($('checker-text-' + checker.id) && $('checker-text-' + checker.id).up().select('span[class="btn"]').length > 0) {
                return;
            }
            $('checker-text-' + checker.id).insert({before: this._createButton(this.lmsg('rollback'), this._onRollbackSubmit, false, false, {'data': checker.id})});
        } else if (!checker.hasRollback && 0 < checker.unresolved) {
            $('checker-checkbox-' + checker.id).insert({after: '<div class="hint-sub minor">' + this.lmsg('unableRollback') + '</div> '});
        }
    }
});

Jsw.WordpressPopupManager.Items = Class.create(Jsw.WordpressPopupManager.CommonPopupForm, {

    _renderPreparePopup: function($super) {
        $super();

        if (this._isSelectRequired()) {
            this._disableSendButton();
        }
    },

    _onSuccessPreparePopup: function(transport) {
        this._clearMessages();
        this._response = transport.responseText.evalJSON();
        if ('success' != this._response.status) {
            if (this._response.redirect) {
                Jsw.redirect(this._response.redirect);
                return;
            }
            this._addErrorMessage(this._response.message.replace(/\n/, '<br>'));
        }
        this._renderTable(this._response.items);
    },

    _getHeadDescription: function() {
        return '<p id="' + this._formDescriptionId + '-headDescription">' + this.lmsg('headDescription') + '</p>';
    },

    _getColumnHeadersHtml: function(totalInstances) {
        return '<th class="first">' + this.lmsg('fieldName') + '</th>' +
            (totalInstances > 1 ? '<th>' + this.lmsg('fieldState') + '</th><th></th>' : '<th>' + this.lmsg('fieldActivate') + '</th>') +
            '<th class="action-icon-set t-r last"></th>';
    },

    _getRowHtml: function(items, totalInstances) {
        return ''
    },

    _addHandlers: function(twoStateControl) {
        return false;
    },

    _getUninstallUrl: function() {
        return '';
    },

    _addUninstallHandlers: function() {
        var context = this;

        $$('a.jsRemoveItem').each(function(link) {
            link.observe('click', function() {
                Jsw.messageBox.show({
                    type: Jsw.messageBox.TYPE_YESNO,
                    buttonTitles: {
                        yes: context._locale.removeDialogButtonYes,
                        no: context._locale.removeDialogButtonNo
                    },
                    text: context._locale.confirmUninstall,
                    subtype: 'delete',
                    onYesClick: function() {
                        context.initialConfig.autoload = false;
                        newContext = new context.constructor(context.initialConfig);
                        params = {
                            'ids[]': context._ids,
                            'item-id': link.readAttribute('data-item-id'),
                            'returnUrl': context._returnUrl
                        };
                        new Ajax.Request(
                            Jsw.prepareUrl(context._getUninstallUrl()),
                            {
                                method: 'post',
                                parameters: params,
                                onSuccess: function(){
                                    newContext.reload();
                                },
                                onException: context._onException.bind(this)
                            }
                        );
                    },
                    onNoClick: function() {
                        context.initialConfig.autoload = true;
                        new context.constructor(context.initialConfig);
                    }
                });
            });
        })
    },

    _getUpdateUrl: function() {
        return '';
    },

    _addUpdateHandlers: function() {
        var context = this;

        $$('a.jsUpdateItem').each(function(link) {
            link.observe('click', function() {
                var onYesClick = function() {
                    Jsw.redirectPost(Jsw.prepareUrl(context._getUpdateUrl()), {
                        'ids': context._ids,
                        'item-id': link.readAttribute('data-item-id'),
                        'returnUrl': context._returnUrl
                    });
                };
                var instanceIds = link.readAttribute('wp-instances').evalJSON();
                var name = (1 == context._ids.length)
                    ? context.lmsg('updatesConfirmNameSingle', {url: context.getName()})
                    : context.lmsg('updatesConfirmName', {number: instanceIds.length});
                Jsw.WordpressPopupManager.updatesConfirmation(instanceIds, name, context._locale, onYesClick);
            })
        })
    },

    _addSelectHandlers: function() {
        if (!this._isSelectRequired()) {
            return;
        }

        var context = this;
        var globalCheckbox = $(this._formListAreaId).select('input[name="listGlobalCheckbox"]').first();
        var listCheckbox = $(this._formListAreaId).select('input[name="listCheckbox[]"]');

        listCheckbox.each(function(checkbox) {
            checkbox.observe('click', function() {
                if (checkbox.checked) {
                    context._selectedMarked++;
                } else {
                    context._selectedMarked--;
                    if (globalCheckbox) {
                        globalCheckbox.checked = false;
                    }
                }
                context._toggleSendButton();
            });
        });

        if (globalCheckbox) {
            globalCheckbox.observe('click', function(){
                listCheckbox.each(function(checkbox) {
                    checkbox.checked = globalCheckbox.checked;
                });
                context._selectedMarked = globalCheckbox.checked ? context._ids.length : 0;
                context._toggleSendButton();
            });
        }
    },

    _toggleSendButton: function() {
        if ($(this._cancelButtonId).down('button').disabled) {
            return;
        }
        0 == this._selectedMarked ? this._disableSendButton() : this._enableSendButton();
    },

    _preRenderTable: function(items) {
        $(this._formBoxAreaId).update('');
        if (0 == items.length) {
            $(this._formListAreaId).setStyle({ overflow: 'visible' });
            $(this._formListAreaId).update(this.lmsg('noItems'));
            return;
        }
        $(this._formListAreaId).setStyle({ overflow: 'auto', maxHeight: '350px' });
    },

    _renderTableContent: function(items) {

        var totalInstances = this._ids.length;
        $(this._formListAreaId).update(
            '<table cellspacing="0" width="100%">' +
                '<thead>' +
                    '<tr>' + this._getColumnHeadersHtml(totalInstances) + '</tr>' +
                '</thead>' +
                '<tbody id="' + this._formListItemsAreaId + '">' +
                '</tbody>' +
            '</table>'
        );
        var rowsHtml = this._getRowHtml(items, totalInstances);
        $(this._formListItemsAreaId).update(rowsHtml);

        this._addHandlers(1 == totalInstances);
        this._addUpdateHandlers();
        this._addUninstallHandlers();
        this._addSelectHandlers();
    },

    _postRenderTable: function(items) {
        this._setHintToItems();

        if (this._isSelectRequired()) {
            this._selectedMarked = 0;
            $(this._formListAreaId).select('input[name="listCheckbox[]"]').each(function(checkbox) {
                if (checkbox.checked) {
                    this._selectedMarked++
                };
            }, this);
            this._toggleSendButton();
        }
    },

    _renderTable: function(items) {
        this._preRenderTable(items);
        this._renderTableContent(items);
        this._postRenderTable(items);
    },

    _getUpdatesInfo: function(totalInstances, item) {
        if (0 == item._updatesTotal) {
            return '';
        }

        var updatesLabel = (1 == totalInstances) ?
            this.lmsg('updateAvailableSingle', {version: item._updateVersion.escapeHTML()}) :
            this.lmsg('updateAvailable');
        var updatesLink = (1 == totalInstances) ?
            this.lmsg('linkUpdateSingle') :
            this.lmsg('linkUpdate', {number: item._updatesTotal});

        var instanceIds = $A();
        item._instances.each( function(wpInstance) {
            if (wpInstance.hasUpdates) {
                instanceIds.push(wpInstance.id);
            }
        });

        var updatesInfo =
            '<div class="hint-sub hint-attention update-available">' + updatesLabel + '&nbsp;' +
                '<a href="#" class="jsUpdateItem" data-item-id="' + item._id + '" wp-instances="[' + instanceIds + ']">' +
                    updatesLink +
                '</a>' +
            '</div>';

        return updatesInfo;
    },

    _getEscapedItem: function(item) {
        var escapedItem = {};
        for(var prop in item) {
            if (!item.hasOwnProperty(prop)) {
                continue;
            }
            escapedItem[prop] = String(item[prop]).escapeHTML();
        }

        return escapedItem;
    },

    _getInstancesState: function(item) {
        var activeInstances = 0;
        var tooltipData = '';
        var context = this;

        item._instances.each(function(instance) {
            if (instance.status == 'active') {
                activeInstances++;
            }
            tooltipData += this.lmsg('stateForOneInstance', {
                name: '<a href="' + instance.url.escapeHTML() + '" target="_blank">' + instance.name.escapeHTML() + '</a>',
                state: context._getStateText(instance.status == 'active', true)
            }) + '<br>';
        }, this);
        tooltipData = '<span class="tooltipData">' + tooltipData + '</span>';

        var areSameStates = (activeInstances == 0 || activeInstances == item._total);
        var statesCount = '<a href="#" class="toggler">' +
            this.lmsg(areSameStates ? 'sameStatesCount' : 'differentStatesCount', {
                count: activeInstances,
                total: item._total
            }) + '</a>' + tooltipData;

        return this.lmsg('stateForAllInstance', {
            count: statesCount,
            state: this._getStateText(activeInstances != 0, areSameStates)
        })
    },

    _getStateText: function(isActive, isColored) {
        var stateClass = '';
        if (isColored) {
            stateClass = isActive ? "e-checkbox-on" : "e-checkbox-off";
        }
        var stateText = this.lmsg(isActive ? 'stateOn' : 'stateOff');

        return '<span class="' + stateClass + '">' + stateText + '</span>';
    },

    _disableSendButton: function() {
        $(this._sendButtonId).firstDescendant().disable();
        $(this._sendButtonId).addClassName('disabled');
    },

    _enableSendButton: function() {
        $(this._sendButtonId).firstDescendant().enable();
        $(this._sendButtonId).removeClassName('disabled');
    },

    _isSelectRequired: function() {
        return false;
    }
});

Jsw.WordpressPopupManager.ManageItems = Class.create(Jsw.WordpressPopupManager.Items, {
    render: function($super) {
        $super();

        new Jsw.SmallTools({
            renderTo: this._id + '-form',
            renderMode: 'before',
            operations: [{
                componentType: 'Jsw.SmallButton',
                title: this.lmsg('installItem'),
                addCls: 'sb-install',
                handler: function() {
                    new Jsw.WordpressPopupManager.InstallPlugins({
                        id: 'installPlugins',
                        cls: 'popup-panel popup-panel-wordpress',
                        prepareUrl: Jsw.prepareUrl('/wordpress/available-plugins/'),
                        handlerUrl: Jsw.prepareUrl('/wordpress/install-plugins/'),
                        locale: this._locale,
                        ids: this._ids,
                        name: this.getName(),
                        returnUrl: (this._returnUrl ? this._returnUrl : '/wordpress/list'),
                        longtask: this.taskInstall
                    });
                }.bind(this)
            }]
        });
    }
});

Jsw.WordpressPopupManager.ManagePlugins = Class.create(Jsw.WordpressPopupManager.ManageItems, {

    _initConfiguration: function($super, config) {
        $super(config);
        this._pluginsStartStates = new Object();
    },

    _getBottomDescription: function() {
        if (1 === this._ids.length) {
            return this._getUrl() ? ('<a href="' + this._getUrl() + '" target="_blank">' + this.lmsg('managePluginsInsideWordpress') + '</a>') : '';
        } else {
            return '';
        }
    },

    _getRowHtml: function(items, totalInstances) {
        var rowsHtml = '';
        var oddRow = true;

        items.each(function(plugin) {
            var pluginEscaped = this._getEscapedItem(plugin);
            if (this._ids.length == 1) {
                this._pluginsStartStates[pluginEscaped._id] = ('active' == plugin.status) ? true : false;
            }
            var stateLabel = '<label for="' + pluginEscaped._id + '_active">' + this.lmsg('activeState') + '</label>';
            rowsHtml += '<tr class="' + (oddRow ? 'odd' : 'even') + '">' +
                    '<td class="first">' +
                        '<span class="jsItemTitle">' +
                            pluginEscaped.title + ' ' + pluginEscaped.version +
                        '</span>' +
                        '<span class="hint hint-info"> (?)' +
                            '<span class="tooltipData">' + plugin.description.stripTags().escapeHTML() + '</span>' +
                        '</span>' +
                        this._getUpdatesInfo(totalInstances, plugin) +
                    '</td>' +
                    (totalInstances == 1 ? (
                        '<td class="nowrap">' +
                            '<label for="' + pluginEscaped._id + '" class="e-checkbox ' + this._getCheckboxCssClass(totalInstances, pluginEscaped) + '">' +
                            '<input type="checkbox" class="checkbox" id="' + pluginEscaped._id + '" name="' + pluginEscaped._id + '" ' + this._getCheckboxStateAttribute(totalInstances, pluginEscaped) + '> ' +
                            this._getStateLabels() +
                            '</label>' +
                        '</td>'
                    ) : (
                        '<td class="nowrap">' + this._getInstancesState(plugin) + '</td>' +
                        '<td>' +
                            '<select name="' + pluginEscaped._id + '">' +
                                '<option class="e-checkbox-pre" value="pre">' + this.lmsg('stateDoNotChange') + '</option>' +
                                '<option class="e-checkbox-on" value="on">' + this.lmsg('stateActivate') + '</option>' +
                                '<option class="e-checkbox-off" value="off">' + this.lmsg('stateDeactivate') + '</option>' +
                            '</select>' +
                        '</td>'
                    )) +
                    '<td class="action-icon-set t-r last min">' +
                        '<a href="#" class="jsRemoveItem" data-item-id="' + pluginEscaped._id + '">' +
                            '<img src="' + Jsw.skinUrl + '/icons/16/plesk/uninstall-app.png">' +
                        '</a>' +
                    '</td>' +
                '</tr>';

            oddRow = !oddRow;
        }, this);

        return rowsHtml;
    },

    _getCheckboxCssClass: function(totalInstances, plugin) {
        if (1 == totalInstances) {
            return ('active' == plugin.status) ? 'e-checkbox-on' : 'e-checkbox-off';
        } else {
            return 'e-checkbox-pre';
        }
    },

    _getCheckboxStateAttribute: function(totalInstances, plugin) {
        if (1 == totalInstances && ('active' == plugin.status)) {
            return 'checked="checked"';
        }

        return '';
    },

    _getAdditionalParams: function(params) {
        $(this._formListAreaId).select('.e-checkbox').each(function(label) {
            if (label.hasClassName('e-checkbox-on')) {
                params.set('items[' + label.readAttribute('for') + ']', 1);
            } else if (label.hasClassName('e-checkbox-off')) {
                params.set('items[' + label.readAttribute('for') + ']', 0);
            }
        });
        $(this._formListAreaId).select('select').each(function(select) {
            if (select.getValue() == 'on') {
                params.set('items[' + select.readAttribute('name') + ']', 1);
            } else if (select.getValue() == 'off') {
                params.set('items[' + select.readAttribute('name') + ']', 0);
            }
        });

        params.set('returnUrl', this._returnUrl);

        return params;
    },

    _getStateLabels: function() {
        var labels = '<span class="e-checkbox-text e-checkbox-text-pre" style="width: 83px;">' + this.lmsg('stateDoNotChange') + '</span>' +
            '<span class="e-checkbox-text e-checkbox-text-on" style="width: 83px;">' + this.lmsg('stateOn') + '</span>' +
            '<span class="e-checkbox-text e-checkbox-text-off" style="width: 83px;">' + this.lmsg('stateOff') + '</span>';
        return labels;
    },

    _addHandlers: function(twoStateControl) {
        $$('.e-checkbox').each(function(el) {
            var text = [el.down('.e-checkbox-text-off').getWidth(), el.down('.e-checkbox-text-on').getWidth(), el.down('.e-checkbox-text-pre').getWidth()];
            var textMax = text.max();
            var checkboxElement = el.down('.checkbox');

            checkboxElement.observe('click', function(e) {
                if (twoStateControl) {
                    if (checkboxElement.checked) {
                        el.addClassName('e-checkbox-on');
                        el.removeClassName('e-checkbox-off');
                        el.down('.e-checkbox-text-on').setStyle({width: textMax + 'px'});
                    } else {
                        el.addClassName('e-checkbox-off');
                        el.removeClassName('e-checkbox-on');
                        el.down('.e-checkbox-text-off').setStyle({width: textMax + 'px'});
                    }
                } else {
                    if (el.hasClassName('e-checkbox-pre')) {
                        el.addClassName('e-checkbox-on');
                        el.removeClassName('e-checkbox-pre');
                        el.down('.checkbox').checked = true;
                        el.down('.e-checkbox-text-on').setStyle({width: textMax + 'px'});
                    } else if (el.hasClassName('e-checkbox-on')) {
                        el.addClassName('e-checkbox-off');
                        el.removeClassName('e-checkbox-on');
                        el.down('.checkbox').checked = false;
                        el.down('.e-checkbox-text-off').setStyle({width: textMax + 'px'});
                    } else if (el.hasClassName('e-checkbox-off')) {
                        el.addClassName('e-checkbox-pre');
                        el.removeClassName('e-checkbox-off');
                        el.down('.checkbox').checked = false;
                        el.down('.e-checkbox-text-pre').setStyle({width: textMax + 'px'});
                    }
                }
            });
        });
    },

    _getUninstallUrl: function() {
        return '/wordpress/uninstall-plugin';
    },

    _getUpdateUrl: function() {
        return '/wordpress/update-plugin';
    },

    _needFlyEffect: function() {
        if (this._ids.length > 1) {
            return true;
        }

        var affectedPluginsCount = 0;
        for (var plugin in this._pluginsStartStates) if (this._pluginsStartStates.hasOwnProperty(plugin)) {
            if ($(plugin) && $(plugin).checked != this._pluginsStartStates[plugin]) {
                affectedPluginsCount++;
            }
        }

        return (affectedPluginsCount > 1);
    }
});

Jsw.WordpressPopupManager.ManageThemes = Class.create(Jsw.WordpressPopupManager.ManageItems, {

    _getHeadDescription: function() {
        return '<p id="' + this._formDescriptionId + '-headDescription">' + this.lmsg('headDescription') + '</p>';
    },

    _getBottomDescription: function() {
        if (1 === this._ids.length) {
            return this._getUrl() ? ('<a href="' + this._getUrl() + '" target="_blank">' + this.lmsg('manageThemesInsideWordpress') + '</a>') : '';
        } else {
            return '';
        }
    },

    _getRadioStateAttribute: function(totalInstances, theme) {
        if (1 == totalInstances && ('active' == theme.status)) {
            return 'checked="checked"';
        }

        return '';
    },

    _getRowHtml: function(items, totalInstances) {
        var rowsHtml = '';
        var oddRow = true;
        var activeText = this.lmsg(totalInstances > 1 ? 'setActive' : 'active');

        items.each(function(theme) {
            var themeEscaped = this._getEscapedItem(theme);
            rowsHtml += '<tr class="' + (oddRow ? 'odd' : 'even') + '">' +
                    '<td class="first">' +
                        '<span class="jsItemTitle">' +
                            themeEscaped.title + ' ' + themeEscaped.version +
                        '</span>' +
                        '<span class="hint hint-info" id="hint_' + themeEscaped._id + '"> (?)' +
                            '<span class="tooltipData">' + theme.description.stripTags().escapeHTML() + '</span>' +
                        '</span>' +
                        this._getUpdatesInfo(totalInstances, theme) +
                    '</td>' +
                    (totalInstances > 1 ? ('<td class="nowrap">' + this._getInstancesState(theme) + '</td>') : '') +
                    '<td class="nowrap">' +
                        '<label for="' + themeEscaped._id + '"><input class="radio theme-active" type="radio" ' + this._getRadioStateAttribute(totalInstances, themeEscaped) + ' name="themes_active" id="' + themeEscaped._id + '"> ' + activeText + '</label>' +
                    '</td>' +
                    '<td class="action-icon-set t-r last min">' +
                        '<a href="#" class="jsRemoveItem" data-item-id="' + themeEscaped._id + '">' +
                            '<img src="' + Jsw.skinUrl + '/icons/16/plesk/uninstall-app.png">' +
                        '</a>' +
                    '</td>' +
                '</tr>';

            oddRow = !oddRow;
        }, this);
        if (totalInstances > 1) {
            rowsHtml += '<tfoot>' +
                    '<tr>' +
                        '<td class="first"></td>' +
                        '<td></td>' +
                        '<td>' +
                            '<label for="themes_active"><input class="radio" type="radio" checked="checked" name="themes_active" id="themes_active"> ' + this.lmsg('setDoNotChange') + '</label>' +
                        '</td>' +
                        '<td class="last min nowrap"></td>' +
                    '</tr>' +
                '</tfoot>';
        }


        return rowsHtml;
    },

    _getAdditionalParams: function(params) {
        $(this._formListAreaId).select('.theme-active').each(function(element) {
            if (element.checked) {
                params.set('items[' + element.id + ']', 1);
            }
        });

        params.set('returnUrl', this._returnUrl);

        return params;
    },

    _addHandlers: function(twoStateControl) {
        var context = this;
        $$('#' + this._contentAreaId + ' .sb-install').first().observe('click', function() {
            var locale = context._locale;
            new Jsw.WordpressPopupManager.InstallThemes({
                id: 'installThemes',
                cls: 'popup-panel popup-panel-wordpress',
                prepareUrl: Jsw.prepareUrl('/wordpress/available-themes/'),
                handlerUrl: Jsw.prepareUrl('/wordpress/install-themes/'),
                locale: locale,
                ids: context._ids,
                name: context.getName(),
                returnUrl: (context._returnUrl ? context._returnUrl : '/wordpress/list'),
                longtask: locale.taskInstall
            });
        });

    },

    _getUninstallUrl: function() {
        return '/wordpress/uninstall-theme';
    },

    _getUpdateUrl: function() {
        return '/wordpress/update-theme';
    },

    _needFlyEffect: function() {
        return this._ids.length > 1;
    }
});


Jsw.WordpressPopupManager.InstallItems = Class.create(Jsw.WordpressPopupManager.Items, {

    render: function($super) {
        $super();

        var actionBox = new Jsw.SmallTools({
            renderTo: this._id + '-form',
            renderMode: 'before',
            operations: []
        });

        var quickSearchBoxEl = new Element('div', {'class': 'quick-search-box'})
            .update(
                '<span class="search-field">' +
                    '<input type="text" value="" id="popupListSearchTerm">' +
                    '<em><span></span></em>' +
                '</span>'
            )
            .observe('click', function(event) {
                event.stopPropagation();
            });

        actionBox._componentElement.down('.objects-toolbar').insert(quickSearchBoxEl);
        this._addActionBoxHandlers();

        actionBox.addResponsiveButton('search');
    },

    _initConfiguration: function($super, config) {
        $super(config);

        this._selectInstances = this._getConfigParam('selectInstances', false);
    },

    _setTitle: function() {
        if (1 === this._ids.length) {
            this.setTitle(this.lmsg('installTitleSingle', {url: this.getName()}));
        } else {
            this.setTitle(this.lmsg('installTitle', {number: this._ids.length}));
        }
    },

    _getHeadDescription: function() {
        return '<p id="' + this._formDescriptionId + '-headDescription">' + this.lmsg('installHeadDescription') + '</p>';
    },

    _renderTableContent: function(items) {

        $(this._formListAreaId).update(
            '<table cellspacing="0" width="100%">' +
                '<thead>' +
                    '<tr>' +
                        '<th class="select first"></th>' +
                        '<th class="first">' + this.lmsg('fieldName') + '</th>' +
                        '<th>' + this.lmsg('fieldVersion') + '</th>' +
                        '<th class="last">' + this.lmsg('fieldRating') + '</th>' +
                    '</tr>' +
                '</thead>' +
                '<tbody id="' + this._formListItemsAreaId + '">' +
                '</tbody>' +
            '</table>'
        );

        var rowsHtml = '';
        var oddRow = true;

        items.each(function(item) {
            var itemEscaped = this._getEscapedItem(item);
            var safeDescription = new Element('span');
            safeDescription.innerHTML = item.description.stripTags().escapeHTML();
            rowsHtml += '<tr class="' + (oddRow ? 'odd' : 'even') + '">' +
                '<td class="select first"><input type="checkbox" class="checkbox" name="listCheckbox[]" id="' + itemEscaped.name + '"></td>' +
                    '<td class="first">' +
                        '<span class="jsItemTitle">' +
                            itemEscaped.title +
                        '</span>' +
                        '<span class="hint hint-info" id="hint_' + itemEscaped.name + '"> (?)' +
                            '<span class="tooltipData">' + (safeDescription.textContent || safeDescription.innerText) + '</span>' +
                        '</span>' +
                    '</td>' +
                    '<td>' + itemEscaped.version + '</td>' +
                    '<td class="last min nowrap">' +
                        '<div class="star-holder">' +
                            '<div class="star-rating" style="width: ' + itemEscaped.rating + '%;"></div>' +
                        '</div>' +
                    '</td>' +
                '</tr>';

            oddRow = !oddRow;
        }, this);

        $(this._formListItemsAreaId).update(rowsHtml);
        this._addSelectHandlers();
    },

    _addActionBoxHandlers: function() {
        var context = this;
        var originalPrepareUrl = this._prepareUrl;

        var searchHandler = function() {
            context._disableSendButton();

            if ($('popupListSearchTerm').value.length < 2) {
                context.renderTryToSearch();
            } else {
                context._prepareUrl = originalPrepareUrl + '?term=' + encodeURIComponent($('popupListSearchTerm').value);
                context.reload();
            }
        }

        $('popupListSearchTerm').observe('keydown', function(event) {
            if (Jsw.keyCode.ENTER == event.keyCode) {
                event.preventDefault();
                searchHandler();
            }
        });

        $$('#' + this._contentAreaId + ' .search-field em').first().observe('click', searchHandler);
    },

    _renderPreparePopup: function() {
        this._disableSendButton();
        this.renderTryToSearch();
    },

    renderTryToSearch: function() {
        $(this._formBoxAreaId).update('');
        $(this._formListAreaId).setStyle({ overflow: 'visible' });
        $(this._formListAreaId).update(this.lmsg('tryToSearch'));
    },

    _getSelectedItems: function() {
        var items = $H();
        $(this._formListAreaId).select('input[name="listCheckbox[]"]').each(function(checkbox) {
            if (checkbox.checked) {
                items.set('items[' + checkbox.id + ']', 1);
            }
        });
        return items;
    },

    _getAdditionalParams: function(params) {
        params.update(this._getSelectedItems());
        params.set('returnUrl', this._returnUrl);
        params.set('activate', this._getActivateState());
        return params;
    },

    _addButtons: function() {
        if (this._selectInstances) {
            var sendButton = this._addSplitButton();
            this._updateSendButtonHandlers(sendButton);
        } else {
            this.addRightButton(this._locale.buttonInstall, this._onOkClick, true, true, {id: this._sendButtonId} );
        }
        this.addRightButton(this._locale.buttonCancel, this._onCancelClick, false, false, {id: this._cancelButtonId} );
    },

    _addSplitButton: function() {
        $(this._rightActionButtonsAreaId).insert(new Element('span', {id: this._sendButtonId}));

        var context = this;
        var selectWpInstances = function() {
            new Jsw.WordpressPopupManager.SelectWpInstances({
                id: 'selectWpInstances',
                cls: 'popup-panel popup-panel-wordpress',
                prepareUrl: Jsw.prepareUrl('/wordpress/select-instances/'),
                handlerUrl: context._handlerUrl,
                locale: context._locale,
                ids: context._ids,
                returnUrl: (context._returnUrl ? context._returnUrl : '/wordpress/list'),
                activate: context._getActivateState(),
                items: context._getSelectedItems(),
                bottomDescriptionHandler: context._getBottomDescription,
                getActivateStateHandler: context._getActivateState,
                longtask: context._locale.taskInstall
            });
        };

        sendButton = new Jsw.SplitButton({
            applyTo: this._sendButtonId,
            link: {
                title: this.lmsg('buttonInstallAll', {number: this._ids.length}),
                isAction: true,
                isDefault: true,
                onclick: this._onClick.bindAsEventListener(this, this._onOkClick.bind(this))
            },
            additionalLinks: [
                {
                    id: this._sendButtonId + '-select-instances',
                    title: this._locale.buttonSelectInstances,
                    onclick: this._onClick.bindAsEventListener(this, selectWpInstances)
                }
            ]
        });
        return sendButton;
    },

    _updateSendButtonHandlers: function(sendButton) {
        this._disableSendButton = function() {
            sendButton.disable();
        },

        this._enableSendButton = function() {
            sendButton.enable();
        },

        this.disable = function() {
            sendButton.disable();
            sendButton.setText('<span class="wait">' + this._locale.loading + '</span>');

            $(this._cancelButtonId).down('button').disabled = true;
            $(this._cancelButtonId).addClassName('disabled');
        },

        this.enable = function() {
            sendButton.enable();
            sendButton.setText(this.lmsg('buttonInstallAll', {number: this._ids.length}));

            $(this._cancelButtonId).down('button').disabled = false;
            $(this._cancelButtonId).removeClassName('disabled');
        }
    },

    _isSelectRequired: function() {
        return true;
    },

    _getActivateState: function() {
        return 0;
    },

    _needFlyEffect: function() {
        if (this._ids.length > 1) {
            return true;
        }

        return ($(this._formListAreaId).select('input:checkbox[name="listCheckbox[]"]:checked').length > 1);
    }
});

Jsw.WordpressPopupManager.InstallPlugins = Class.create(Jsw.WordpressPopupManager.InstallItems, {

    _getBottomDescription: function() {
        var checkboxId = this._contentAreaId + '-activate';
        var checked = this._getConfigParam('activate', true) ? 'checked="checked"' : '';
        return '<div class="text-center">' +
            '<label for="' + checkboxId + '"><input type="checkbox" id="' + checkboxId + '" ' + checked + '> ' + this.lmsg('activateAfterInstall') + '</label>' +
        '</div>';
    },

    _getActivateState: function() {
        return $(this._contentAreaId + '-activate').checked ? 1 : 0;
    }
});

Jsw.WordpressPopupManager.InstallThemes = Class.create(Jsw.WordpressPopupManager.InstallItems, {

    _getBottomDescription: function() {
        return '';
    }
});

Jsw.WordpressPopupManager.SelectWpInstances = Class.create(Jsw.WordpressPopupManager.Items, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._items = $H(this._getConfigParam('items', {}));
        this._bottomDescriptionHandler = this._getConfigParam('bottomDescriptionHandler', function(){});
        this._getActivateStateHandler = this._getConfigParam('getActivateStateHandler', function(){});
    },

    _setTitle: function() {
        if (1 === this._items.keys().length) {
            this.setTitle(this.lmsg('selectInstancesTitleSingle'));
        } else {
            this.setTitle(this.lmsg('selectInstancesTitle', {number: this._items.keys().length}));
        }
    },

    _getColumnHeadersHtml: function() {
        return '<th class="select first"><input type="checkbox" name="listGlobalCheckbox" class="checkbox" checked></th>' +
            '<th class="first">' + this.lmsg('fieldName') + '</th>' +
            '<th>' + this.lmsg('fieldUrl') + '</th>'
    },

    _getRowHtml: function(items) {
        var rowsHtml = '';
        var oddRow = true;

        items.each(function(item) {
            var itemEscaped = this._getEscapedItem(item);
            rowsHtml += '<tr class="' + (oddRow ? 'odd' : 'even') + '">' +
                '<td class="select first"><input type="checkbox" class="checkbox" name="listCheckbox[]" value="' + itemEscaped.id + '" checked></td>' +
                '<td><a href="' + Jsw.prepareUrl('/wordpress/detail/id/' + itemEscaped.id) + '">' +  itemEscaped.name + '</a></td>' +
                '<td><a href="' + itemEscaped.url + '" target="_blank">' + itemEscaped.url + '</a></td>' +
                '</tr>';

            oddRow = !oddRow;
        }, this);
        return rowsHtml;
    },

    _getHeadDescription: function() {
        return '<p id="' + this._formDescriptionId + '-headDescription">' + this.lmsg('selectInstancesHeadDescription') + '</p>';
    },

    _getBottomDescription: function() {
        return this._bottomDescriptionHandler();
    },

    _addButtons: function() {
        var buttonOk = (1 === this._items.keys().length) ? this.lmsg('buttonInstallOnSelectedSingle')
            : this.lmsg('buttonInstallOnSelected', {number: this._items.keys().length});
        this.addRightButton(buttonOk, this._onOkClick, true, true, {id: this._sendButtonId} );
        this.addRightButton(this._locale.buttonCancel, this._onCancelClick, false, false, {id: this._cancelButtonId} );
    },

    _getAdditionalParams: function(params) {
        var params = $H();
        var count = 0;

        $(this._formListAreaId).select('input[name="listCheckbox[]"]').each(function(checkbox) {
            if (checkbox.checked) {
                params.set('ids[' + count + ']', checkbox.value);
                count++;
            }
        });
        params.set('returnUrl', this._returnUrl);
        params.set('activate', this._getActivateStateHandler());
        params.update(this._items);

        return params;
    },

    _isSelectRequired: function() {
        return true;
    },

    _needFlyEffect: function() {
        if (this._items.keys().length > 1) {
            return true;
        }

        return ($(this._formListAreaId).select('input:checkbox[name="listCheckbox[]"]:checked').length > 1);
    }
});