// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.
/* JavaScript Widgets */
Jsw = {

    version: '1.0',
    baseUrl: '',
    ctxIdName: '',
    ctxId: '',
    uiContext: $H(),

    _registredComponents: null,
    _initOnReady: false,
    _firedOnReady: false,
    _onReadyEvents: null,

    priority: {
        high: 'high',
        normal: 'normal',
        low: 'low'
    },

    isRtl: function() {
        return document.documentElement.dir == 'rtl';
    },

    registerComponent: function(identity, component) {
        if (!Jsw._registredComponents) {
            Jsw._registredComponents = new Hash();
        }

        Jsw._registredComponents.set(identity, component);
    },

    getComponent: function(identity) {
        return Jsw._registredComponents.get(identity);
    },

    clearStatusMessages: function() {
        var contentElement = $('main');
        if (!contentElement) {
            return;
        }
        ['.msg-error', '.msg-info', '.msg-warning'].each(function(msgClass) {
            contentElement.select(msgClass).each(function(messageElement) {
                messageElement.remove();
            });
        });
    },

    addStatusMessage: function(type, message, params) {
        var params = ('undefined' != typeof params) ? params : {};

        var elementParams = { 'class': 'msg-box msg-'  + type };
        if (params['id']) {
            elementParams['id'] = params['id'];
        }

        if (params['title']) {
            message = '<b>' + params['title'] + ':</b> ' + message;
        }

        var statusElement = new Element('div', elementParams);
        statusElement.update(
            '<div><div><div><div><div>' +
            '<div class="msg-content">' + message + '</div>' +
            '</div></div></div></div></div>'
        );

        if (params['closable']) {
            var closeElement = new Element('span', { 'class': 'close' });
            closeElement.observe('click', params['onClose']);
            statusElement.down('.msg-content').insert({top: closeElement});
        }

        try {
            var target;
            if (params['renderTo']) {
                target = params['renderTo'];
            } else {
                target = 'main';
            }
            var mode = 'top';
            if (params['renderMode']) {
                mode = params['renderMode'];
            }
            var insertion = {};
            insertion[mode] = statusElement;

            $(target).insert(insertion);
        } catch (e) {
            alert(type + ' | ' + message);
        }
    },

    onReady: function(priority, callback) {
        if ('function' == typeof priority) {
            callback = priority;
            priority = Jsw.priority.normal;
        }

        if (Jsw._firedOnReady) {
            callback();
            return;
        }

        if (!Jsw._initOnReady) {
            Event.observe(window, 'load', Jsw._fireOnReady);
            Jsw._initOnReady = true;
            Jsw._onReadyEvents = [];
        }

        if ('undefined' == typeof Jsw._onReadyEvents[priority]) {
            Jsw._onReadyEvents[priority] = [];
        }

        Jsw._onReadyEvents[priority].push(callback);
    },

    _fireOnReady: function() {
        var eventsToFire = [];
        var predefinedPriorities = [Jsw.priority.high, Jsw.priority.normal, Jsw.priority.low];

        predefinedPriorities.each(function(priority) {
            if ('undefined' != typeof Jsw._onReadyEvents[priority]) {
                eventsToFire = eventsToFire.concat(Jsw._onReadyEvents[priority]);
            }
        });

        Jsw._onReadyEvents.each(function(events, priority) {
            if (-1 == predefinedPriorities.indexOf(priority)) {
                eventsToFire = eventsToFire.concat(events);
            }
        });

        eventsToFire.each(function(callback) {
            callback();
        });

        Jsw._firedOnReady = true;
    },

    namespace: function(ns) {
        var nsParts = ns.split('.');
        var root = window;

        for (var partIndex = 0; partIndex < nsParts.length; partIndex++) {
            if ('undefined' == typeof root[nsParts[partIndex]]) {
                root[nsParts[partIndex]] = {};
            }

            root = root[nsParts[partIndex]];
        }
    },

    prepareUrl: function(url) {
        if ('undefined' == typeof url || null === url) {
            return null;
        }

        url = Jsw.prepareCtxUrl(url);

        if (
                url.startsWith('/services/') ||
                url.startsWith('/server/spamassassin') ||
                url.startsWith('/server/mail_') ||
                url.startsWith('/plesk/') ||
                url.startsWith('/admin/') ||
                url.startsWith('/smb/') ||
                (Jsw.baseUrl != '' && url.startsWith(Jsw.baseUrl + '/')) ||
                (!url.startsWith('/') && (url.substr(0, 2) != '^/')) ||
                url.startsWith('/modules/')
        ) {
            return url;
        }
        if (url.substr(0, 2) == '^/') {
            return url.toString().substr(1);
        }

        return Jsw.baseUrl + url;
    },

    prepareCtxUrl: function(url, id) {
        if (('undefined' == typeof id || null === id) && Jsw.ctxId) {
            id = Jsw.ctxId;
        }

        if (! id
            || url.startsWith('#')
            || url.include(Jsw.ctxIdName+'=')
            || url.startsWith('javascript:')
            || (url.startsWith('http') && !url.include(window.location.hostname))) {
            return url;
        }

        var fragment = '';
        if (url.include('#')) {
            var splitUrl = url.split('#', 2);
            url = splitUrl[0];
            fragment = '#' + splitUrl[1];
        }
        url = Jsw.addUrlParams(url, Jsw.ctxIdName+'=' + encodeURIComponent(id) + fragment);
        return url;
    },

    addUrlParams: function(url, params) {
        return url + (url.include('?') ? '&' : '?') + params;
    },

    clonePosition: function(element, source, options) {
        // workaround for: https://prototype.lighthouseapp.com/projects/8886/tickets/90-cloneposition-problem-in-ie7

        try {
            element.clonePosition(source, options);
        } catch (e) {
            element.clonePosition(source, options);
        }
    },

    showInternalError: function(message) {
        Jsw.clearStatusMessages();
        message = 'Internal error.<br/>' + message;
        Jsw.addStatusMessage('error', message);
    }
};

Jsw.keyCode = {
    ESC: 27,
    ENTER: 13,
    LEFT_ARROW: 37,
    UP_ARROW: 38,
    RIGHT_ARROW: 39,
    DOWN_ARROW: 40
};

// Monkey patching Prototype for proper handling of session expiration
Ajax.PatchedRequest = Class.create(Ajax.Request, {
    initialize: function($super, url, options) {
        options = Object.extend({
            on400: function() {
                top.window.location.reload();
            },
            on500: function(transport) {
                Jsw.showInternalError(transport.responseText);
            },
            on0: function() {
                // do nothing in case of internal/network error
                return false;
            }
        }, options || {});

        $super(url, options);
    },
    request: function($super, url) {
        $super(Jsw.prepareCtxUrl(url));
    },
    abort: function() {
        this.transport.abort();
    }
});

Ajax.Request.prototype = Ajax.PatchedRequest.prototype;

// cross-site request forgery protection
(function() {
    Ajax.Base.prototype.initialize = Ajax.Base.prototype.initialize.wrap(function() {
        var args = $A(arguments), proceed = args.shift();
        args[0] = args[0] || {};
        var options = args[0];

        var addParamToOptions = function(param, value) {
            if (Object.isString(options.parameters)) {
                if (options.parameters.indexOf(param) == -1) {
                    options.parameters += '&' + param + '=' + value;
                }
            } else if (Object.isHash(options.parameters)) {
                options.parameters = options.parameters.toObject();
                options.parameters[param] = value;
            } else {
                options.parameters = options.parameters || {};
                options.parameters[param] = value;
            }
        };

        if (!(options.method && options.method.toUpperCase() == "GET")) {
            if ($('forgery_protection_token')) {
                addParamToOptions('forgery_protection_token', encodeURIComponent($('forgery_protection_token').content));
            }
        }
        if (Jsw.ctxId) {
            addParamToOptions(Jsw.ctxIdName, Jsw.ctxId);
        }
        proceed.apply(null, args);
    });
})();

/* testing mode support */
Jsw.onReady(function() {
    if ('true' != Jsw.Cookie.get('debug-testing-mode')) {
        return;
    }

    if ($('bottomAnchor')) {
        var date = new Date();
        $('bottomAnchor').innerHTML = date.getTime();
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.BrowserFeatures = (function() {
    var style = document.documentElement.style;
    var domPrefixes = ['Webkit', 'Moz', 'O', 'ms'];

    function checkProp(prop) {
        if ('undefined' != typeof style[prop]) {
            return true;
        }

        prop = prop.charAt(0).toUpperCase() + prop.slice(1);
        for (var i = 0; i < domPrefixes.length; i++) {
            if ('undefined' != typeof style[domPrefixes[i] + prop]) {
                return true;
            }
        }

        return false;
    }

    return {
        transition: checkProp('transition')
    };
})();
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.
Jsw.Component = Class.create({

    _tag: 'div',

    initialize: function(config) {
        this._initConfiguration(config);
        this._registerComponent();

        this._initComponentElement();

        if (this._autoRender && ((null != $(this._renderTargetId)) || (null != $(this._applyTargetId)))) {
            this.render();
        }

        if (this._getConfigParam('hidden', false)) {
            this.hide();
        }
    },

    _initConfiguration: function(config) {
        this.initialConfig = config;
        this._config = this.initialConfig;

        this._cls = this._getConfigParam('cls', '');
        this._attrs = this._getConfigParam('attrs', {});
        this._wrapperClass = this._getConfigParam('wrapperClass', '');
        this._autoRender = this._getConfigParam('autoRender', true);
        this._renderTargetId = this._getConfigParam('renderTo', null);
        this._renderMode = this._getConfigParam('renderMode', 'bottom');
        this._applyTargetId = this._getConfigParam('applyTo', null);
        this._locale = this._getConfigParam('locale', {});

        this._id = (this._applyTargetId)
            ? this._applyTargetId
            : this._getConfigParam('id', null);

        if (null === this._id) {
            this._id = this._getRandomId();
            this._idIsRandom = true;
        }

        this._tag = (this._applyTargetId)
            ? $(this._applyTargetId).tagName
            : this._getConfigParam('tag', this._tag);
    },

    _registerComponent: function() {
        Jsw.registerComponent(this._id, this);
    },

    _initComponentElement: function() {
        if (this._applyTargetId) {
            this._componentElement = $(this._applyTargetId);
            return ;
        }

        var attrs = Object.extend(this._attrs, {
            'id': this._id,
            'class': this._cls
        });

        this._componentElement = new Element(this._tag, attrs);
    },

    _initDisablerOverlay: function() {
        this._disablerOverlay = new Element('div');

        this._disablerOverlay.setStyle({
            display: 'none',
            zIndex: this._componentElement.style.zIndex + 1000
        });

        this._disablerOverlay.addClassName('content-blocker');
        this._componentElement.appendChild(this._disablerOverlay);
    },

    addEventObserver: function(eventName, handler) {
        if ('undefined' != typeof handler) {
            this._componentElement.observe(eventName, handler);
        }
    },

    removeEventObserver: function(eventName, handler) {
        if ('undefined' != typeof handler) {
            this._componentElement.stopObserving(eventName, handler);
        }
    },

    _hasConfigParam: function(name)
    {
        return 'undefined' != typeof this._config[name];
    },

    _getConfigParam: function(name, defaultValue) {
        return this._hasConfigParam(name)
            ? this._config[name]
            : defaultValue;
    },

    _getRandomId: function() {
        var id = 'gen-id-' + this._getRandomNumber();

        while(null != $(id)) {
            id = 'gen-id-' + this._getRandomNumber();
        }

        return id;
    },

    _getRandomNumber: function() {
        return Math.floor(1000000*Math.random());
    },

    _addEvents: function() {
    },

    _addTooltips: function() {
        var description = this._getConfigParam('description');
        if  (description) {
            this._tooltip = Jsw.Tooltip.init(this._componentElement, {text: description});
        }
    },

    _updateComponentElement: function(content) {
        if (this._componentElement.empty()) {
            this._componentElement.update(content);
            return ;
        }

        var oldElements = this._componentElement.childElements();

        Element.insert(this._componentElement.firstChild, {before: content});

        oldElements.each(function(oldElement) {
            if (
                'undefined' == typeof oldElement.id ||
                '' == oldElement.id
            ) {
                return ;
            }

            var newElement = this._componentElement.select('#' + oldElement.id).first();

            if (newElement) {
                newElement.replace(oldElement);
            }
        }, this);
    },

    getWrapperClass: function() {
        return this._wrapperClass;
    },

    getComponentHtml: function() {
        var wrapper = new Element('span');
        wrapper.update(this._componentElement);

        return wrapper.innerHTML;
    },

    getId: function() {
        return this._id;
    },

    setRenderTarget: function(targetId) {
        this._renderTargetId = targetId;
    },

    getRenderTarget: function() {
        return this._renderTargetId;
    },

    show: function() {
        this._componentElement.show();
    },

    hide: function() {
        this._componentElement.hide();
    },

    render: function() {
        if ($(this._renderTargetId)) {
            var insertion = {};
            insertion[this._renderMode] = this._componentElement;
            $(this._renderTargetId).insert(insertion);
        }

        this._addEvents();
        this._addTooltips();
    },

    lmsg: function(key) {
        if ('undefined' == typeof this._locale[key])  {
            return '[' + key + ']';
        }
        if ('undefined' == typeof arguments[1]) {
            return this._locale[key];
        }

        var params = arguments[1];
        var value = this._locale[key];
        for (var paramKey in params) if (params.hasOwnProperty(paramKey)) {
            value = value.replace('%%' + paramKey + '%%', params[paramKey]);
        }
        return value;
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.Hint = Class.create(Jsw.Component, {
    _tag: 'p',

    _initConfiguration: function($super, config) {
        $super(config);
        this._cls = this._getConfigParam('cls', '');
    },

    _initComponentElement: function($super) {
        $super();

        this.setHint(
            this._getConfigParam('hint', '')
        );

        if (this._getConfigParam('expandable', false)) {
            var contentElement = this._componentElement;
            var componentElement = new Element('div', {'class': 'screen-description'});
            var wrapElement = new Element('div', {'class': 'screen-description-wrap'});
            var btnShowMore = new Element('span', {'class': 'screen-description-control'});
            btnShowMore.observe('click', function() { this.up('.screen-description').addClassName('expanded'); });
            wrapElement.insert(contentElement);
            wrapElement.insert(btnShowMore);
            this._componentElement = componentElement.update(wrapElement);
            this._screenControl = function() {
                if (componentElement.getWidth() > wrapElement.getWidth()) {
                    btnShowMore.addClassName('off');
                } else {
                    btnShowMore.removeClassName('off');
                }
            };
        }
    },

    _addEvents: function($super) {
        $super();

        if (this._screenControl) {
            Event.observe(window, 'resize', this._screenControl);
            this._screenControl();
        }
    },

    setHint: function(hint) {
        this._componentElement.update(hint);
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.Button = Class.create(Jsw.Component, {

    _tag: 'a',

    _initConfiguration: function($super, config) {
        $super(config);

        this._handler = this._getConfigParam('handler', false);
        if (Object.isString(this._handler)) {
            eval('this._handler = ' + this._handler);
        }
        this._title = this._getConfigParam('title', '');
        this._cls = this._getConfigParam('cls', 'b-btn' + (!this._title ? ' icon-only' : ''));
        this._disabledClass = this._getConfigParam('disabledClass', 'btn-disabled');
        this._isNew = this._getConfigParam('isNew', false);
        this._newTitle = this._getConfigParam('newTitle', '');
    },

    _initComponentElement: function($super) {
        $super();

        this._componentElement.update(
            '<i><i><i><span>'
            + this._title
            + (this._isNew ? ' <span class="badge-new">' + this._newTitle + '</span>' : '')
            + '</span></i></i></i>'
        );

        this._initVisibility();
    },

    _initVisibility: function() {
        this._disabled = this._getConfigParam('disabled', false);

        if (this._disabled) {
            this._disabled = false;
            this.disable();
        } else {
            this._disabled = true;
            this.enable();
        }
    },

    _addAttribute: function(name, value) {
        if ('undefined' != typeof value) {
            this._componentElement.writeAttribute(name, value);
        }
    },

    setTooltip : function(tooltipText) {
        if (this._tooltip) {
            this._tooltip.setText(tooltipText);
        } else {
            this._tooltip = Jsw.Tooltip.init(this._componentElement, {text: tooltipText});
        }
    },

    enable: function() {
        if (!this._disabled) {
            return ;
        }
        this._disabled = false;

        var classNames = this._config['addCls'] || '';
        if (!Object.isArray(classNames)) {
            classNames = [classNames];
        }
        classNames.each(function(item) {
            this._componentElement.addClassName(item);
        }, this);
        classNames.each(function(item) {
            this._componentElement.removeClassName(item + '-disabled');
        }, this);
        this._componentElement.removeClassName(this._disabledClass);

        this._addAttribute('href', Jsw.prepareUrl(this._getConfigParam('href', 'javascript:;')));
        this._addAttribute('target', this._getConfigParam('target', null));

        this._addProgressHandler();
        if (this._handler) {
            this.addEventObserver('click', this._handler);
        }
    },

    disable: function() {
        if (this._disabled) {
            return ;
        }
        this._disabled = true;

        this._componentElement.addClassName(this._disabledClass);

        var classNames = this._config['addCls'];
        if (!Object.isArray(classNames)) {
            classNames = [classNames];
        }
        classNames.each(function(item) {
            this._componentElement.addClassName(item + '-disabled');
        }, this);
        classNames.each(function(item) {
            this._componentElement.removeClassName(item);
        }, this);
        this._componentElement.writeAttribute('href', null);
        this._componentElement.writeAttribute('target', null);

        if (this._handler) {
            this.removeEventObserver('click', this._handler);
        }
    },

    _addProgressHandler: function() {
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.SmallButton = Class.create(Jsw.Button, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._cls = this._getConfigParam('cls', 's-btn' + (!this._title ? ' icon-only' : ''));
    }

});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.BigButton = Class.create(Jsw.Button, {

    _initConfiguration: function($super, config) {
        $super(config);
        this._icon = this._getConfigParam('icon', null);
    },

    _initComponentElement: function($super) {
        $super();

        this._componentElement.update(
            '<span class="db-content">' +
                '<span class="db-icon"><img src="' + this._icon + '"></span>' +
                '<span class="db-name">' + this._config['title'] + '</span>' +
                '<span class="db-info">' + this._config['description'] + '</span>' +
            '</span>'
        );

        this._initVisibility();
    },

    _addProgressHandler: function() {
        if (this._getConfigParam('indicateProgress', false)) {
            this.addEventObserver('click', function() {
                this._componentElement.up().update('<div class="ajax-loading">' + this._config['waitMessage'] + '</div>');
            }.bind(this));
        }
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.SplitButton = Class.create(Jsw.Component, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._link = this._getConfigParam('link', $H());
        this._additionalLinks = this._getConfigParam('additionalLinks', $A());
        this._isEvenItem = this._getConfigParam('isEvenItem', false);
    },

    _initComponentElement: function($super) {
        $super();

        var buttonHtml = '<span class="btn-group">' +
            '<span id="' + this._id + '-button" class="btn ' + (this._link.isAction ? 'action' : '') + '" >' +
                '<button type="' + (this._link.isDefault ? 'submit' : 'button') + '">' + this._link.title.escapeHTML() + '</button>' +
            '</span>' +
            '<span id="' + this._id + '-dropdown" class="btn dropdown-toggle"><button type="button"><em class="caret"></em></button></span>' +
            '<ul id="' + this._id +'-dropdown-list" class="dropdown-menu' + (this._isEvenItem ? ' pull-right' : '' ) + '"></ul>' +
        '</span>';

        this._componentElement.update(buttonHtml);
        this._initAdditionalLinks();
    },

    _initAdditionalLinks: function() {
        this._additionalLinks.each(function(element) {
            var link = new Element('a', {
                'id': element.id,
                'href': element.href ? element.href : '#',
                'target': element.newWindow ? '_blank' : null
            }).update(element.title.escapeHTML());

            var listItem = new Element('li', {
                'class': (element.submenu ? 'dropdown-submenu' : '') + (this._isEvenItem ? ' to-left' : '')
            }).insert(link);

            if (element.submenu) {
                listItem.insert('<ul class="dropdown-menu"></ul>');
            }

            $(this._id + '-dropdown-list').insert(listItem);

            if (element.onclick) {
                link.observe('click', element.onclick);
            }
        }, this);
    },

    _addTooltips: function() {
        if (this._link.tooltip) {
            Jsw.Tooltip.init($(this._id + '-button'), {text: this._link.tooltip.escapeHTML()});
        }
        this._additionalLinks.each(function(element) {
            if (element.tooltip) {
                Jsw.Tooltip.init($(element.id), {text: element.tooltip.escapeHTML()});
            }
        });
    },

    _addEvents: function() {
        var context = this;

        if (this._link.onclick) {
            $(this._id + '-button').down('button').observe('click', this._link.onclick);
        }

        var btnGroup = $(this._id).down('.btn-group');
        var openSubmenu = function(menuItem){
            var submenu = menuItem.select('.dropdown-menu').first();
            if (!menuItem.hasClassName('open') && 'undefined' != typeof submenu && submenu.empty()) {
                context._additionalLinks.last().submenu ? context._additionalLinks.last().submenu() : '';
            }
            apsCatalog.closeSubmenu(menuItem);
            menuItem.addClassName('open');
            clearTimeout(apsCatalog._menuTimeouts[menuItem.identify()]);
        };

        $(this._id + '-dropdown').down('button').observe('click', function(e){
            Event.stop(e);
            if (!btnGroup.hasClassName('btn-group-open')) {
                $$('.btn-group').each(function(item){
                    item.removeClassName('btn-group-open');
                });
            }
            btnGroup.toggleClassName('btn-group-open');
        });

        btnGroup.select('.dropdown-menu > li').invoke('observe', 'mouseover', function(){
            if (this.hasClassName('dropdown-submenu open')) {
                return;
            }
            this.siblings('.dropdown-submenu.open').each(function(el) {
                apsCatalog.closeSubmenu(el);
                });
            });

        var submenu = btnGroup.select('.dropdown-submenu');
        submenu.invoke('observe', 'mouseover', function(e){
            openSubmenu(this);
        });
        submenu.each(function(item){
            item.down('a').observe('touchend', function(e){
                if (item.hasClassName('open')) {
                    apsCatalog.closeSubmenu(item);
                } else {
                    openSubmenu(item);
                }
            }).observe('click', function(e){
                Event.stop(e);
            });
        });

        btnGroup.select('.dropdown-submenu').invoke('observe', 'mouseleave', function(){
            var element = this;
            clearTimeout(apsCatalog._menuTimeouts[element.identify()]);
            apsCatalog._menuTimeouts[element.identify()] = setTimeout(function() {
                apsCatalog.closeSubmenu(element);
            }, 500);
        });

        $(document.body).observe('click', function() {
            btnGroup.removeClassName('btn-group-open');
        });
    },

    disable: function() {
        $(this._id + '-button').down('button').disable();
        $(this._id + '-button').addClassName('disabled');
        $(this._id + '-dropdown').down('button').disable();
        $(this._id + '-dropdown').addClassName('disabled');
    },

    enable: function() {
        $(this._id + '-button').down('button').enable();
        $(this._id + '-button').removeClassName('disabled');
        $(this._id + '-dropdown').down('button').enable();
        $(this._id + '-dropdown').removeClassName('disabled');
    },

    setText: function(text) {
        $(this._id + '-button').down('button').update(text);
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.submit = function(element, noRedirect) {
    element = $(element);
    if (element.tagName.toLowerCase() != 'form') {
        element = element.up("form");
    }
    element.noRedirect = noRedirect;
    element.submit();
};

Jsw.redirect = function(action, data, target) {
    if (data || target) {
        Jsw.FormRedirect.redirect(Jsw.prepareUrl(action), 'get', data, target);
    } else {
        $(document).location.href = Jsw.prepareUrl(action);
  }
};

Jsw.redirectPost = function(action, data, target) {
    Jsw.FormRedirect.redirect(Jsw.prepareUrl(action), 'post', data, target);
};

Jsw.FormRedirect = {
    redirect: function(action, method, data, target) {

    // workaround for http://code.google.com/p/chromium/issues/detail?id=10671
    var randomId = Math.floor(1000000*Math.random());
    action = Jsw.addUrlParams(action, '_randomId=' + randomId);

        var form = new Element(
            'form',
            {
                method: method,
                action: action
            }
        );
        if (target) {
            form.target = target;
        }
        if (data) {
            var elements = Jsw.FormRedirect.subToElements(data);
            $A(elements).each(function (element) {
                form.insert(element);
            });
        }

        if ($('forgery_protection_token')) {
            form.insert(new Element('input', {
                type: 'hidden',
                name: 'forgery_protection_token',
                value: $('forgery_protection_token').content
            }));
        }
        if (Jsw.ctxId) {
            form.insert(new Element('input', {
                type: 'hidden',
                name: Jsw.ctxIdName,
                value: Jsw.ctxId
            }));
        }

        $(document.body).insert(form);
        form.submit();
    },

    stringToElements: function(value, prefix)
    {
        return [new Element('input', {
            type: 'hidden',
            name: prefix,
            value: value
        })];
    },

    booleanToElements: function(value, prefix)
    {
        return [new Element('input', {
            type: 'hidden',
            name: prefix,
            value: value ? 1 : 0
        })];
    },

    arrayToElements: function(data, prefix)
    {
        var elements = [];
        $A(data).each(function(item) {
            elements = elements.concat(Jsw.FormRedirect.subToElements(item, '', prefix));
        });
        return elements;
    },

    hashToElements: function(data, prefix)
    {
        var elements = [];
        $H(data).each(function(pair) {
            elements = elements.concat(Jsw.FormRedirect.subToElements(pair.value, pair.key, prefix));
        });
        return elements;
    },

    subToElements: function(value, key, prefix)
    {
        var elements = [];
        var name = prefix
            ? prefix + '[' + key + ']'
            : key;
        if (Object.isString(value) || Object.isNumber(value)) {
            elements = elements.concat(Jsw.FormRedirect.stringToElements(value, name));
        } else
        if ('boolean' == typeof value) {
            elements = elements.concat(Jsw.FormRedirect.booleanToElements(value, name));
        } else
        if(Object.isArray(value)) {
            elements = elements.concat(Jsw.FormRedirect.arrayToElements(value, name));
        } else {
            elements = elements.concat(Jsw.FormRedirect.hashToElements(value, name));
        }
        return elements;
    }
};
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.CommandButton = Class.create(Jsw.Component, {
    _initConfiguration: function($super, config) {
        $super(config);

        this._handler = this._getConfigParam('handler', false);
        if (Object.isString(this._handler)) {
            eval('this._handler = ' + this._handler);
        }

        this._value = this._config['value'] || ''
        this._tabIndex = this._getConfigParam('tabIndex', null);
    },

    _initComponentElement: function($super) {
        $super();

        var buttonElement = new Element('button', {
            type: 'button',
            value: this._value,
            name: this._config['name']
        }).update(this._config['title']);

        if (null != this._tabIndex) {
            buttonElement.writeAttribute('tabindex', this._tabIndex);
        }

        this._updateComponentElement(buttonElement);

        this._initVisibility();
    },

    _initVisibility: function() {
        this._disabled = this._getConfigParam('disabled', false);

        if (this._disabled) {
            this._disabled = false;
            this.disable();
        } else {
            this._disabled = true;
            this.enable();
        }
    },

    enable: function() {
        if (!this._disabled) {
            return ;
        }

        this._disabled = false;
        if ('send' == this._config['name'] || 'apply' == this._config['name']) {
            this._componentElement.addClassName('action');
        }
        this._componentElement.removeClassName('disabled');
        this._componentElement.disabled = false;
        if (this._handler) {
            this.addEventObserver('click', this._handler);
        }
    },

    disable: function() {
        if (this._disabled) {
            return ;
        }

        this._disabled = true;
        this._componentElement.disabled = true;
        if ('send' == this._config['name'] || 'apply' == this._config['name']) {
            this._componentElement.removeClassName('action');
        }
        this._componentElement.addClassName('disabled');
        if (this._handler) {
            this.removeEventObserver('click', this._handler);
        }
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.namespace('Jsw.form');

Jsw.form.DisplayField = Class.create(Jsw.Component, {
    _tag: 'div',

    _initConfiguration: function($super, config) {
        $super(config);
        this._cls = this._getConfigParam('cls', 'form-row');
        this._valueRenderer = this._getConfigParam('valueRenderer', null);
    },

    _initComponentElement: function($super) {
        $super();

        var values = ('function' == typeof this._valueRenderer)
            ? this._valueRenderer()
            : this._getConfigParam('value', '');

        values = (typeof values == 'string') ? [values] : values;

        var valuesElements = '';
        values.each(function(value) {
            valuesElements += '<div class="text-value">' + value + '</div>';
        });

        if (this._getConfigParam('singleRow', false)) {
            if (1 == values.length) {
                valuesElements = values.valueOf();
            }
            this._componentElement.update('<div class="single-row">' + valuesElements + '</div>');
        } else {
            this._componentElement.update(
                '<div class="field-name">' + this._getConfigParam('fieldLabel', '') + '</div>' +
                '<div class="field-value">' + valuesElements + '</div>'
            );
        }
    }
});

Jsw.form.Values = new Class.create({
    initialize: function(config) {
        this.selector = config.selector;
        this.formValues = {};
        $$(this.selector).each(function(input){
            this.formValues[this._getStorageName(input)] = input.getValue();
        }, this);
    },

    isChanged: function() {
        var changed = false;
        $$(this.selector).each(function(input){
            if (this.formValues[this._getStorageName(input)] != input.getValue()) {
                changed = true;
            }
        }, this);
        return changed;
    },

    _getStorageName: function(input) {
        return input.getAttribute('type') + '/' + input.getAttribute('name');
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.FormAjax = Class.create(Jsw.Component, {
    _actionButtonTitle: '',

    _initConfiguration: function($super, config) {
        $super(config);
        this._sendButtonId = this._getConfigParam('sendButtonId', 'btn-send');
        this._applyButtonId = this._getConfigParam('applyButtonId', 'btn-apply');
        this._cancelButtonId = this._getConfigParam('cancelButtonId', 'btn-cancel');
        this._submitHandler = this._getConfigParam('submitHandler', function() { return true; });
    },

    disable: function() {
        [this._sendButtonId, this._applyButtonId, this._cancelButtonId].each(function(buttonId){
            this._toggleButton(buttonId, true);
        }, this)

        var actionButton = this._getActionButton();
        if (actionButton) {
            this._actionButtonTitle = actionButton.innerHTML;
            actionButton.update('<span class="wait">' + this._config['waitButtonTitle'] + '</span>');
        }
    },

    enable: function() {
        [this._sendButtonId, this._applyButtonId, this._cancelButtonId].each(function(buttonId){
            this._toggleButton(buttonId, false);
        }, this)

        var actionButton = this._getActionButton();
        if (actionButton) {
            actionButton.update(this._actionButtonTitle);
        }
    },

    _toggleButton: function(buttonId, disable) {
        var buttonWrapper = $(buttonId);
        if (buttonWrapper) {
            buttonWrapper.down('button').disabled = disable;
            disable ? buttonWrapper.addClassName('disabled') : buttonWrapper.removeClassName('disabled');
        }
    },

    _getActionButton: function() {
        var actionButtonWrapper = $(this._componentElement.noRedirect ? this._applyButtonId : this._sendButtonId);
        if (actionButtonWrapper) {
            return actionButtonWrapper.down('button');
        }

        return null;
    },

    _initComponentElement: function($super) {
        this._componentElement = $(this._id);
        this._initDisablerOverlay();

        var firstElement = this._componentElement.findFirstElement();

        if ('undefined' != typeof firstElement) {
            try {
                firstElement.focus();
            } catch (e) {}
        }

        this._submitInProgress = false;
    },

    _addEvents: function() {
        this._componentElement._formSubmit = this._componentElement.submit;
        this._componentElement.submit = this._onSubmit.bind(this);
        this._componentElement.observe('submit', this._onSubmitEvent.bind(this));
        this._addChoiceRadioButtonsOnClickEvent();
    },

    _addChoiceRadioButtonsOnClickEvent: function() {
        $$('input[type="radio"]').each(function(element) {
            if (!$(element.id).up('div.choice-block')) {
                return;
            }
            element.observe('click', function() {
                $(this.id).up('div.choice-block').select('span').each(function(element) {
                    element.removeClassName('selected');

                    if ('0' == $(this.id).value) {
                        element.removeClassName('no');
                    }
                }, this);

                $(this.id).up('span').addClassName('selected');

                if ('0' == $(this.id).value) {
                    $(this.id).up('span').addClassName('no');
                }
            });
        });
    },

    _onSubmitEvent: function(event) {
        this._onSubmit();
        Event.stop(event);
        return false;
    },

    _onSubmit: function() {
        if (false === this._submitHandler()) {
            return false;
        }

        if (this._submitInProgress) {
            return false;
        } else {
            this._submitInProgress = true;
        }

        this.disable();

        if (this._componentElement.enctype == "multipart/form-data") {
            this._componentElement._formSubmit();
            return true;
        }

        var actionUrl = this._componentElement.getAttribute('action');

        if (!actionUrl) {
            actionUrl = $(document).location.href;
        }

        // remove hash symbol (and the following) cause this will encoded and lead to problems
        actionUrl = actionUrl.replace(/#.*$/, "");

        var params = this._componentElement.serialize();
        var context = this;
        var request = new Ajax.Request(
            actionUrl,
            {
                method:'post',
                parameters: params,
                onSuccess: this._onSuccess.bind(this),
                onFailure: this._onFailure.bind(this)
            }
        );
        return true;
    },

    _onFailure: function(req) {
        this._submitInProgress = false;
        this._clearMessages();

        if (504 == req.status) {
            Jsw.addStatusMessage('error', this._config['timeoutMessage']);
        } else {
            Jsw.showInternalError(req.responseText);
        }

        this.enable();
    },

    _onSuccess: function(req) {
        this._submitInProgress = false;
        Jsw.clearStatusMessages();

        try {
            var response = req.responseText.evalJSON();
            this._processForm(response);
        } catch (e) {
            this._clearMessages();
            this.enable();

            // show error, if request wasn't aborted by user
            if (0 != req.status) {
                Jsw.showInternalError(req.responseText);
            }
        }
    },

    _processForm: function(response) {
        this._processResponseRedirect(response);

        if (!response.redirect) {
            this._clearMessages();
            this._processResponseStatus(response.status);
            this._processResponseStatusMessages(response.statusMessages);
            this._processResponseFormMessages(response.formMessages);

            if (this._hasFieldErrors) {
                this._showFieldErrorArea();
            }
            this.enable();
        }
    },

    _showFieldErrorArea: function() {
        var errorsElements = this._componentElement.select('.field-errors');
        var firstError = null;

        errorsElements.each(function(errorElement) {
            if (errorElement.visible()) {
                firstError = errorElement;
            }
        });

        var hiddenContainerId = null;

        firstError.ancestors().each(function(element) {
            if (!element.visible()) {
                hiddenContainerId = element.id;
            }
        });

        if (!hiddenContainerId) {
            return ;
        }

        // in case of tabbed form we must switch to corresponding tab
        var tabsBar = Jsw.getComponent('form-tab-buttons');

        if (tabsBar) {
            tabsBar.switchTab(hiddenContainerId);
        }
    },

    _processResponseStatus: function (status) {
        if ('success' != status) {
            this._hasErrors = true;
        }
    },

    _clearMessages: function() {
        //clear field messages
        try {
            this._componentElement.select('.field-errors').each(function(errors){
                errors.hide();
                var rowElement = errors.up('.form-row');
                if (rowElement) {
                    rowElement.removeClassName('error');
                }
                errors.select('.error-hint').each(function(error) {
                    error.remove();
                });
            });
        } catch (e) {
        }

        this._hasErrors = false;
        this._hasFieldErrors = false;
    },

    _processResponseStatusMessages: function (messages) {
        $A(messages).each(function(value) {
            this._addFormMessage(value.status, value.content, value.title);
        }, this);
    },

    _processResponseFormMessages: function (messages) {
        this._processFieldMessages(messages, []);
    },

    _addFieldMessage: function(errors, message) {
        errors.up('.form-row').addClassName('error');
        errors.insert({bottom: '<span class="error-hint">' + message.escapeHTML() + '</span>' });
        errors.show();
    },

    _processFieldMessage: function(prefix, name, message) {
        var fieldErrors;
        var formElement = this._componentElement.down('#' + prefix.join('-'));
        fieldErrors = formElement ? formElement.next('.field-errors') : null;
        if (!fieldErrors) {
            fieldErrors = formElement ? formElement.up('.form-row').down('.field-errors') : null;
        }
        if (!fieldErrors) {
            fieldErrors = this._componentElement.down('#' + prefix.join('-') + '-form-row').select('.field-errors').last();
        }
        this._addFieldMessage(fieldErrors, message);
        this._hasFieldErrors = true;
    },

    _processFieldMessages: function(messages, prefix) {
        if (Object.isArray(messages)) {
            $A(messages).each(function(message) {
                if (Object.isString(message)) {
                    this._processFieldMessage(prefix, 'error', message);
                } else {
                    prefix.push(name);
                    this._processFieldMessages(message, prefix);
                    prefix.pop();
                }
            }, this);
        } else {
            $H(messages).each(function(pair) {
                if (Object.isString(pair.value)) {
                    this._processFieldMessage(prefix, pair.key, pair.value);
                } else {
                    prefix.push(pair.key);
                    this._processFieldMessages(pair.value, prefix);
                    prefix.pop();
                }
            }, this);
        }
    },

    _addFormMessage: function (type, message, title) {
        Jsw.addStatusMessage(type, message, { 'title': title });
    },

    _processResponseRedirect: function (response) {
        if (response.redirect) {
            if (this._componentElement.noRedirect) {
                document.location.reload();
            } else if (response.postData) {
                Jsw.redirectPost(response.redirect, response.postData, response.target);
            } else {
                Jsw.redirect(response.redirect, null, response.target);
            }
        }
    }

});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.Container = Class.create(Jsw.Component, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._contentAreaId = this._id;

        this._initItems();
    },

    _initItems: function() {
        this._items = this._getConfigParam('items', null);

        if (null != this._items) {
            this._items.each(function(item, index) {
                if (item && ('undefined' != typeof item.componentType)) {
                    // recreate proper object defined by componentType
                    eval('var resultItem = new ' + item.componentType + '(item);');
                    this._items[index] = resultItem;
                }
            }, this);
        }
    },

    _renderItems: function() {
        if (null != this._items) {
            this._items.each(function(item) {
                if (item) {
                    this._renderItem(item);
                }
            }, this);
        }
    },

    _renderItem: function(item) {
        item.setRenderTarget(this._contentAreaId);
        item.render();
    },

    render: function($super) {
        $super();

        this._renderItems();
    },

    getItems: function() {
        return this._items;
    }

});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.ListContainer = Class.create(Jsw.Container, {

    _tag: 'ul',

    _renderItem: function(item) {
        var renderTargetId = null;
        var isEmptyItem = Object.isArray(item) && !item.size();

        if (!isEmptyItem) {
            renderTargetId = this._id + '-item-' + item.getId();
        }

        var cls = this._getConfigParam('itemClass', '');

        if (this._getConfigParam('renderLastItemClass', '') && this._items.last() == item) {
            cls = 'last';
        }

        if (isEmptyItem) {
            cls += ' ' + this._getConfigParam('emptyItemClass', '');
        }

        if (cls) {
            cls = ' class="' + cls + '"';
        }

        $(this._contentAreaId).insert('<li ' + (renderTargetId ? 'id="' + renderTargetId + '"' : '') + cls + '></li>');

        if (!isEmptyItem) {
            item.setRenderTarget(renderTargetId);
            item.render();
        }
    }

});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.namespace('Jsw.layout');

Jsw.layout.TwoColumns = Class.create(Jsw.Container, {

    _initConfiguration: function($super, config) {
        $super(config);
        this._cls = this._getConfigParam('cls', 'two-cols-block clearfix');
        this._columnCls = 'first-col';
    },

    _initComponentElement: function() {
        this._componentElement = new Element('div', {
                'class': this._cls
            }).update(
                '<div id="' + this._contentAreaId + '" class="columns-wrapper">' +
                '</div>'
            );
    },

    _renderItem: function(item) {
        var renderTargetId = this._id + '-item-' + item.getId();
        $(this._contentAreaId).insert(
            '<div class="' + this._columnCls + '"><div class="column-box" id="' + renderTargetId +'"></div></div>'
        );
        item.setRenderTarget(renderTargetId);
        item.render();

        this._columnCls = 'second-col';
    }

});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.Dashboard = Class.create(Jsw.Container, {

    _initConfiguration: function($super, config) {
        $super(config);
        this._buttonsAreaId =this._id + '-buttons-area';
    },

    _initComponentElement: function() {
        this._componentElement = new Element('div', {
                'class': this._cls
            }).update(
                '<ul id="' + this._buttonsAreaId + '" class="d-buttons">' +
                    this._getConfigParam('html', '') +
                '</ul>'
            );
    },

    _renderItem: function(item) {
        var renderTargetId = this._id + '-button-' + item.getId();
        $(this._buttonsAreaId).insert('<li id="' + renderTargetId +'"></li>');
        item.setRenderTarget(renderTargetId);
        item.render();
    }

});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.Panel = Class.create(Jsw.Container, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._title = this._getConfigParam('title', '');
        this._titleClass = this._getConfigParam('titleClass', '');
        this._hideContentTitle = this._getConfigParam('hideContentTitle', this._title);
        this._titleAreaId = this._id + '-title-area';
        this._contentAreaId = this._id + '-content-area';
        this._boxItemsAreaId = this._id + '-box-area';
        this._initBoxItems();
    },

    _initBoxItems: function() {
        this._boxItems = this._getConfigParam('boxItems', null);

        if (null != this._boxItems) {
            this._boxItems.each(function(item, index) {
                if ('undefined' != typeof item.componentType) {
                    // recreate proper object defined by componentType
                    eval('var resultItem = new ' + item.componentType + '(item);');
                    this._boxItems[index] = resultItem;
                }
            }, this);
        }
    },

    _initComponentElement: function($super) {
        $super();

        this._updateComponentElement(
            '<div class="box-area">' +
            this._getTitleHtml() +
            this._getSubTitleHtml() +
                '<div id="' + this._boxItemsAreaId + '"></div>' +
                '<div class="content">' +
                    '<div class="content-area">' +
                        '<div class="content-wrapper" id="' + this._contentAreaId + '">' +
                            this._getConfigParam('html', '') +
                        '</div>' +
                    '</div>' +
                '</div>' +
            '</div>'
        );
    },

    _getTitleHtml: function() {
        return this._title
            ?   '<div class="title ' + (this._titleClass ? this._titleClass : '') + '">' +
                    '<div class="title-area" id="' + this._titleAreaId + '">' +
                        (('-' == this._title) ? '' : '<h3><span>' + this._title + '</span></h3>') +
                    '</div>' +
                '</div>'
            : '';
    },

    _getSubTitleHtml: function() {
        return '';
    },

    render: function($super) {
        $super();

        this._renderBoxItems();
    },

    _renderBoxItems: function() {
        if (null != this._boxItems) {
            this._boxItems.each(function(item) {
                this._renderBoxItem(item);
            }, this);
        }
    },

    _renderBoxItem: function(item) {
        item.setRenderTarget(this._boxItemsAreaId);
        item.render();
    },

    _isHidden: function()
    {
        var rememberedStatus = Jsw.Cookie.get(this._id + '-hidden');
        if (this._idIsRandom || null === rememberedStatus) {
            return this._getConfigParam('collapsed', false);
        }
        return 1 == rememberedStatus;
    },

    _setHidden: function(hidden)
    {
        if (this._getConfigParam('collapsed', false) == hidden) {
            Jsw.Cookie.remove(this._id + '-hidden');
        } else {
            Jsw.Cookie.set(this._id + '-hidden', hidden ? 1 : 0);
        }
    },

    _addEvents: function($super) {
        $super();
        if (this._isHidden()) {
            this.hideContent();
        } else {
            this.showContent();
        }
        this._componentElement.select('#' + this._titleAreaId).each(function(titleAreaElement) {
            Event.observe(titleAreaElement, 'click', this.toggleContent.bindAsEventListener(this));
        }, this);
    },

    _updateTitle: function(title) {
        if (title && ('-' != title)) {
            this._componentElement.down('div.title-area > h3 > span').update(title);
        }
    },

    showContent: function() {
        this._componentElement.removeClassName('hide');
        this._updateTitle(this._hideContentTitle);
        if (!this._idIsRandom) {
            this._setHidden(false);
        }
    },

    hideContent: function() {
        this._componentElement.addClassName('hide');
        this._updateTitle(this._title);
        if (!this._idIsRandom) {
            this._setHidden(true);
        }
    },

    toggleContent: function() {
        this._componentElement.hasClassName('hide')
            ? this.showContent()
            : this.hideContent();
    }

});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.SmallTools = Class.create(Jsw.Container, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._operations = this._getConfigParam('operations', null);
        this._operationsId = this._getConfigParam('operationsId', this._id + '-operations');
        this._cls = this._getConfigParam('cls', 'actions-box');

        if (Object.isArray(this._operations) && (0 == this._operations.size())) {
            this._operations = null;
        }
    },

    _addOperations: function() {
        this._operations.each(function(config) {
            eval('var operation = new ' + config.componentType + '(config);');
            operation.setRenderTarget(this._componentElement.down('.objects-toolbar'));
            operation.render();
        }, this);
        this.addResponsiveButton('toolbar');
    },

    render: function($super) {
        $super();

            var html = '';
            html +='<div id="' + this._operationsId + '" class="objects-toolbar clearfix"></div>';
            this._componentElement.update(html);

        if (this._operations) {
            this._addOperations();
        }

        Jsw.Tooltip.initData(this._componentElement);
    },

    _addEvents: function($super) {
        $super();

        $(document).observe('click', function() {
            this._hideResponsiveButtonBlocks();
        }.bind(this));
    },

    addResponsiveButton: function(name) {
        if (!this._rActionsElement) {
            this._rActionsElement = new Element('div', {"class": "r-actions"}).update('<ul class="r-actions-list"></ul>');
            this._componentElement.insert({top: this._rActionsElement});
        }

        if (this._rActionsElement.down('.r-actions-' + name)) {
            return;
        }

        this._rActionsElement.down('.r-actions-list').insert(
            '<li class="r-actions-item r-actions-' + name + '" onclick="Jsw.getComponent(\'' + this._id +
                '\').onResponsiveButtonClick(event, \'' + name + '\');"><span></span></li>'
        );
    },

    onResponsiveButtonClick: function(event, name) {
        var button = this._componentElement.down('.r-actions-' + name);
        var show = !button.hasClassName('r-actions-item-active');
        this._hideResponsiveButtonBlocks();
        if (show) {
            this._showResponsiveButtonBlocks(name);
        }
        event.stopPropagation();
    },

    _hideResponsiveButtonBlocks: function() {
        $w(this._componentElement.className).each(function(className) {
            if (className.indexOf('r-actions-active') === 0) {
                this._componentElement.removeClassName(className);
            }
        }.bind(this));
        this._componentElement.select('.r-actions-item-active').each(function(item) {
            if (item.hasClassName('r-actions-select')) {
                return;
            }
            item.removeClassName('r-actions-item-active');
        });
    },

    _showResponsiveButtonBlocks: function(name) {
        this._componentElement.down('.r-actions-' + name).addClassName('r-actions-item-active');
        this._componentElement.addClassName('r-actions-active');
        this._componentElement.addClassName('r-actions-active-' + name);
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.CollapsibleBlock = Class.create(Jsw.Container, {
    _initConfiguration: function($super, config) {
        $super(config);

        this._blockAreaId = this._id + '-block';
        this._titleAreaId = this._id + '-title-area';
        this._contentAreaId = this._id + '-content-area';
    },

    _initComponentElement: function($super) {
        $super();

        var containerContentChilds = this._componentElement.childElements();

        this._updateComponentElement(
            '<div class="' + this._cls +  '-block' + (this._getConfigParam('collapsed', true) ? ' hide' : '') + '" id="' + this._blockAreaId + '">' +
                '<div class="' + this._cls +  '-title" id="' + this._titleAreaId + '">' +
                    '<span>' + this._getConfigParam('title', '') +  '</span>' +
                '</div>' +
                '<div class="' + this._cls +  '-content" id="' + this._contentAreaId + '"></div>' +
            '</div>'
        );
    },

    _addEvents: function($super) {
        $super();
        $(this._titleAreaId).down('span').observe('click', this._onTitleClickEvent.bind(this));
    },

    _onTitleClickEvent: function(event) {
        Event.stop(event);
        $(this._blockAreaId).toggleClassName('hide');
    }
});

// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.Collapsible = Class.create(Jsw.Container, {

    _initConfiguration: function($super, config) {
        $super(config);
        this._contentAreaId = this._id + '-content-area';
        this._anchorAreaId = this._id + '-anchor-area';
    },

    _initComponentElement: function($super) {
        $super();

        var containerContentChilds = this._componentElement.childElements();

        this._updateComponentElement(
            '<div class="collapsible-box collapsed">' +
                '<div class="collapsible-anchor" id="' + this._anchorAreaId + '"></div>' +
                '<div class="collapsible-area">' +
                    '<div class="tl"><div class="br"><div class="bl"><div class="tr">' +
                        '<div class="collapsible-content" id="' + this._contentAreaId + '">' +
                            this._getConfigParam('html', '') +
                            //...collapsible elements
                        '</div>' +
                    '</div></div></div></div>' +
                '</div>' +
             '</div>'
        );
    },

    _addEvents: function($super) {
        $super();

        //init collapsed status
        if (this._getConfigParam('collapsed', true)) {
            this.collapse();
        } else {
            this.expand();
        }
        //handle click event on anchor
        this._componentElement.select('.collapsible-anchor').each(function(anchorElement) {
            Event.observe(anchorElement, 'click', this._onAnchorClickEvent.bind(this));
        }, this);
    },

    _onAnchorClickEvent: function(event) {
        if (this._collapsed) {
            this.expand();
        } else {
            this.collapse();
        }
        Event.stop(event);
    },

    _getCollapseBinding: function() {
        if (!this._collapseBinding) {
            this._collapseBinding = this.collapse.bind(this);
        }
        return this._collapseBinding;
    },

    collapse: function() {
        if (this._collapsed) {
            return;
        }
        this._collapsed = true;
        Event.stopObserving(document, 'click', this._getCollapseBinding());
        var content = $(this._contentAreaId).up('.collapsible-box');
        content.removeClassName('expanded');
        content.addClassName('collapsed');
    },

    expand: function() {
        if (!this._collapsed) {
            return;
        }
        this._collapsed = false;
        var content = $(this._contentAreaId).up('.collapsible-box');
        content.removeClassName('collapsed');
        content.addClassName('expanded');
        Event.observe(document, 'click', this._getCollapseBinding());
    }

});

// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.DropdownArea = Class.create(Jsw.Collapsible, {
    _initComponentElement: function($super) {
        $super();
        this._componentElement.down('#' + this._anchorAreaId).update(
            '<h4><span>' + this._getConfigParam('title', '') + '</span></h4>'
        );
    }
});

Jsw.DropdownSplit = Class.create(Jsw.Component, {
    _initConfiguration: function($super, config) {
        $super(config);
        this._cls = this._getConfigParam('cls', 'split');
    }
});

Jsw.Dropdown = Class.create(Jsw.Collapsible, {

    _initConfiguration: function($super, config) {
        $super(config);
        this._valuesAreaId = this._id + '-values-area';
        this.onChange = this._getConfigParam('onChange', this.onChange);
    },

    _initComponentElement: function($super) {
        $super();
        this._componentElement.down('#' + this._contentAreaId).update(
            '<h4><span>' + this._getConfigParam('title', '') + '</span></h4>' +
            '<ul id="' + this._valuesAreaId + '"></ul>'
        );
    },

    _renderItem: function(item) {
        var dropdownItem = new Jsw.DropdownItem(item);

        var valueItem = new Element('a').update(dropdownItem.title.escapeHTML());

        $(this._valuesAreaId).insert(
            new Element('li').update(valueItem)
        );

        valueItem.observe('click', this._onClick.bindAsEventListener(this, dropdownItem));
    },

    _onClick: function(event, item)
    {
        this.onChange(item);
    },

    onChange: function(item) {
        this.setValue(item.value);
    },

    setValue: function(value) {
        this._value = value;
    },

    getValue: function() {
        return this._value;
    }

});

Jsw.DropdownItem = Class.create({

    initialize: function(item) {
        if (Object.isString(item)) {
            this.value = item;
            this.title = item;
        } else {
            Object.extend(this, item);
        }
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.Pathbar = Class.create(Jsw.Container, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._contentAreaId = this._id + '-content-area';
    },

    _initComponentElement: function($super) {
        if ($(this._id)) {
            this._applyTargetId = this._id;
            $super();

            return;
        }

        $super();

        this._updateComponentElement(
            '<ul id="' + this._contentAreaId + '">' +
            '</ul>'
        );
    },

    _renderItem: function(item) {
        var renderTargetId = this._id + '-item-' + item.getId();
        $(this._contentAreaId).insert('<li id="' + renderTargetId +'"></li>');
        item.setRenderTarget(renderTargetId);
        item.render();
        this._renderItemSuffix(item);
    },

    _renderItemSuffix: function(item) {
        var renderTargetId = this._id + '-item-' + item.getId();
        $(renderTargetId).insert("<b>&gt;</b>");
    }

});

Jsw.Pathbar.Item = Class.create(Jsw.Component, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._title = this._getConfigParam('title', '');
        this._href = this._getConfigParam('href', '');
    },

    _initComponentElement: function($super) {
        $super();

        this._componentElement = new Element('a', {
            'href': this._href
        }).update('<span>' + this._title + '</span>');
    },

    getHref: function() {
        return this._href;
    }
});

Jsw.Pathbar.SimpleItem = Class.create(Jsw.Component, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._title = this._getConfigParam('title', '');
    },

    _initComponentElement: function($super) {
        $super();

        this._componentElement = new Element('span');
        this._componentElement.update(this._title);
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.Bar = Class.create(Jsw.Container, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._contentAreaId = this._id + '-content-area';

        // allowed types: static, dynamic
        this._type = this._getConfigParam('type', 'static');
    },

    _initComponentElement: function($super) {
        $super();

        var content = '<ul id="' + this._contentAreaId + '"></ul>';
        if ('navbar' != this._id) {
            content = '<div class="tabs-area">' + content + '</div>';
        }

        this._updateComponentElement(content);
    },

    _renderItems: function() {
        if (null != this._items) {
            var size = this._items.size();
            this._items.each(function(item, i) {
                this._renderItem(item, i, size);
            }, this);
        }
    },

    _renderItem: function(item, i, size) {
        if (0 == i && 'navbar' != this._id && 'classic-mode-navigation' != this._id) {
            var renderTargetId = 'first-tab';
        } else if (size - 1 == i && 'navbar' != this._id && 'classic-mode-navigation' != this._id) {
            var renderTargetId = 'last-tab';
        } else {
            var renderTargetId = this._id + '-item-' + item.getId();
        }
        var containerCls = item.getContainerClass();

        $(this._contentAreaId).insert('<li class="' + containerCls + '" id="' + renderTargetId +"\"></li>");
        item.setRenderTarget(renderTargetId);
        item.render();

        if ('dynamic' == this._type) {
            item.addEventObserver('click', item.switchTab.bindAsEventListener(item));
        }

        if ($('main')) {
            if (!$('main').hasClassName('tabed') && 'navbar' != this._id) {
                $('main').addClassName('tabed');
            }
        }
    }
});

Jsw.bar = {};

Jsw.bar.Tabs = Class.create(Jsw.Bar, {

    _initConfiguration: function($super, config) {
        $super(config);
        this._isResponsive = this._getConfigParam('responsive', true);
    },

    _renderItems: function($super) {
        $super();

        if (this._isResponsive) {
            this._addResponsiveTabs();
        }
    },

    _addResponsiveTabs: function() {
        var element = $(this._id);
        element.select('li a').each(function(el) {
            el.observe('click', function(event) {
                var listItem = el.up('li');
                if (listItem.hasClassName('active') || listItem.id == 'current') {
                    Event.stop(event);
                }
                element.toggleClassName('responsive-tabs-visible');
            });
        });
    },

    switchTab: function(tabId) {
        var activeTab = null;

        this.getItems().each(function(item) {
            if (tabId == item.getTabId()) {
                activeTab = item;
            }

            $(item.getTabId()).hide();
            $(item.getRenderTarget()).removeClassName('active');
        });

        $(tabId).show();
        $(activeTab.getRenderTarget()).addClassName('active');
    },

    _renderItem: function($super, item, i, size) {
        $super(item, i, size);

        var content = item.getTabContent();

        if (content) {
            var tabContentElement = new Element('div', {
                'id': item.getTabId()
            });

            if (!item.isActive()) {
                tabContentElement.setStyle({ 'display': 'none' });
            }

            this._componentElement.up().insert({ bottom: tabContentElement });

            if (Object.isString(content)) {
                tabContentElement.update(content);
            } else {
                content.setRenderTarget(item.getTabId());
                content.render();
            }
        }
    }
});

Jsw.bar.Button = Class.create(Jsw.Button, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._isActive = this._getConfigParam('active', false);
        this._cls = this._getConfigParam('cls', '');
        this._containerCls = this._getConfigParam('containerCls', this._isActive ? 'active' : '');
        this._tabId = this._getConfigParam('tabId', null);
        if (this._tabId) {
            this._id = this._tabId + '-button';
        }
        this.navigationTab = this._getConfigParam('navigationTab', false);
        this._content = this._getConfigParam('content', null);
    },

    _initComponentElement: function($super) {
        $super();

        this._componentElement.update('<span>' + this._title + '</span>');
    },

    getContainerClass: function() {
        return this._containerCls;
    },

    getTabId: function() {
        return this._tabId;
    },

    switchTab: function(event) {
        var bar = Jsw.getComponent(Event.element(event).up('ul').up('div').up('div').id);
        bar.switchTab(this._tabId);
        Event.stop(event);
    },

    getTabContent: function() {
        return this._content;
    },

    isActive: function() {
        return this._isActive;
    }

});

Jsw.bar.Separator = Class.create(Jsw.Component, {
    _tag: 'span',

    _initConfiguration: function($super, config) {
        $super(config);
        this._cls = this._getConfigParam('cls', 'separator');
    },

    _initComponentElement: function($super) {
        $super();
        this._componentElement.update('<span></span>');
    }
});

Jsw.bar.HorizontalSeparator = Class.create(Jsw.Component, {
    _tag: 'span',

    _initConfiguration: function($super, config) {
        $super(config);
        this._wrapperClass = this._getConfigParam('wrapperClass', 'separator');
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.list = {

    COLUMN_SELECTION: {
        cls: 'select',
        headerCls: 'select',
        hideDisabled: false,
        headerRenderer: function(column) {
            return '<input type="checkbox" class="checkbox" name="listGlobalCheckbox"/>';
        },
        renderer: function(item, isDisabled) {
            if (!isDisabled) {
                return '<input type="checkbox" class="checkbox" name="listCheckbox[]" value="' + item.id.toString().escapeHTML().replace(/"/g,'&quot;') + '"/>';
            }

            var html =
                '<div>' +
                    '<span class="checkbox-disabled-wrapper"></span>' +
                    '<input style="z-index: 1;" disabled="disabled" type="checkbox" class="checkbox"/>' +
                '</div>';

            return html;
        }
    },

    COLUMN_ACTIONS: {
        header: '',
        cls: 'min',
        sortable: false,
        renderer: function(item) {
            if (!item.actions || !item.actions.length) {
                return '';
            }
            return '<span class="btn-group list-menu">' +
                '<span class="btn btn-list-menu dropdown-toggle" data-row-id="' + item.id + '">' +
                    '<button type="button">' +
                        '<i class="icon">' +
                            '<img src="' + Jsw.skinUrl + '/icons/16/plesk/menu.png" alt="">' +
                        '</i> ' +
                        '<em class="caret"></em>' +
                    '</button>' +
                '</span>' +
            '</span>';
        }
    },

    ITEMS_UNLIMITED: 100000

};

Jsw.list.AdditionalActions = Class.create(Jsw.Component, {

    _tag: 'div',

    _initConfiguration: function($super, config) {
        $super(config);

        this._operations = this._getConfigParam('operations', null);
        this._cls = this._getConfigParam('cls', 'actions-menu');
        this._titleAddCls = this._getConfigParam('titleAddCls', 'sb-more-actions');
    },

    _initComponentElement: function($super) {
        $super();

        this._componentElement.insert({
            bottom:
                '<div class="popup-box collapsed">' +
                    '<table class="popup-wrapper" cellspacing="0"><tbody><tr>' +
                        '<td class="popup-container">' +
                            '<div class="c1"><div class="c2"><div class="c3"><div class="c4"><div class="c5">' +
                                '<div class="popup-heading">' +
                                    '<div class="heading-area">' +
                                        '<span class="close"></span>' +
                                        '<h4>' +
                                            '<span>' +
                                                this._getConfigParam('title', '') +
                                            '</span>' +
                                        '</h4>' +
                                    '</div>' +
                                '</div>' +
                                '<div class="popup-content">'+
                                    '<div class="popup-content-area">' +
                                        '<ul id="' + this._id + '-operations">' +
                                        '</ul>' +
                                    '</div>' +
                                '</div>' +
                            '</div></div></div></div></div>' +
                        '</td>' +
                    '</tr></tbody></table>' +
                '</div>'
        });
    },

    _addEvents: function($super) {
        $super();

        var context = this;
        $(document.body).observe('click', function() {
            context.collapse();
        });
    },

    enable: function() {
        this._titleButton.enable();
    },

    disable: function() {
        this._titleButton.disable();
    },

    toggle: function() {
        var popup = this._componentElement.down('.popup-box');

        if (popup) {
            popup.toggleClassName('collapsed');
        }

        var button = this._componentElement.down('.' + this._titleAddCls);

        if (button) {
            button.toggleClassName('active');
        }
    },

    collapse: function() {
        var popup = this._componentElement.down('.popup-box');

        if (popup) {
            popup.addClassName('collapsed');
        }

        var button = this._componentElement.down('.' + this._titleAddCls);

        if (button) {
            button.removeClassName('active');
        }
    },

    render: function($super) {
        $super();

        this._titleButton = new Jsw.SmallButton({
            title: this._getConfigParam('title', ''),
            cls: 's-btn',
            addCls: this._titleAddCls,
            renderTo: this._id,
            handler: (function(event) {
                Event.stop(event);
                this.toggle();
            }).bind(this)
        });

        if (!this._operations) {
            return;
        }

        var operationsArea = $(this._id + '-operations');
        this._operations.each(function(config) {
            var liElement = new Element('li');
            operationsArea.insert(liElement);

            eval('var operation = new ' + config.componentType + '(config);');

            var wrapperClass = operation.getWrapperClass();
            if (wrapperClass) {
                liElement.addClassName(wrapperClass);
            }

            operation.setRenderTarget(liElement);
            operation.render();
        }, this);

        if (this._getConfigParam('disabled', false)) {
            this.disable();
        } else {
            this.enable();
        }
    }

});

Jsw.List = Class.create(Jsw.Component, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._listCls = this._getConfigParam('listCls', 'list');
        this._tableId = this._id + '-table';
        this._dataUrl = this._getConfigParam('dataUrl', '');
        this._operations = this._getConfigParam('operations', null);
        this._columns = this._getConfigParam('columns', null);
        this._limitValues = this._getConfigParam('limitValues', [10, 25, 100, Jsw.list.ITEMS_UNLIMITED]);
        this._splitListData(this._getConfigParam('data', { data: null, pathbar: null, state: null, pager: null, locale: null, additional: null }));
        this._rowSelectable = this._isColumnSelectionPresent();
        this._searchFilters = $H(this._getConfigParam('searchFilters', {}));
        this._searchable = this._getConfigParam('searchable', this._searchFilters.size() > 0);
        this._searchOveral = this._getConfigParam('searchOveral', null);
        this._searchExtended = this._getConfigParam('searchExtended', this._searchFilters.size() > 1);
        this._pageable = this._getConfigParam('pageable', true);
        this._disabledSelectHint = this._getConfigParam('disabledSelectHint', '');
        this._clearStatusOnReload = this._getConfigParam('clearStatusOnReload', true);
        this.isDisabledItem = this._getConfigParam('isDisabledItem', function() {
            return false;
        });
        this._onRedraw = this._getConfigParam('onRedraw', null);
        this._getTotalInfo = this._getConfigParam('getTotalInfo', function() {
            return this._locale.recordsTotal.replace('%%total%%', this._pager.totalItemCount);
        });
        this._getRowClass = this._getConfigParam('getRowClass', function() {
            return '';
        });

        if (Object.isArray(this._operations)) {
            this._operations = this._operations.compact();
            if (0 == this._operations.size()) {
                this._operations = null;
            }
        }
    },

    _getSearchOveralField: function()
    {
        if (null === this._searchOveral) {
            this._searchFilters.each(function (pair){
                if(pair.value.overal) {
                    this._searchOveral = pair.key;
                }
            }, this);
            if (null === this._searchOveral && 1 == this._searchFilters.size()) {
                this._searchOveral = this._searchFilters.keys().first();
            }
            if (null === this._searchOveral) {
                this._searchOveral = false;
            }
        }

        return this._searchOveral;
    },

    _initComponentElement: function($super) {
        $super();

        this._updateComponentElement('<div id="' + this._id + '-container"></div>');
        this._initDisablerOverlay();
    },

    _splitListData: function(listData, place) {
        if (!listData || !listData.data) {
            return false;
        }

        var dataLen = listData.data.length;
        if ('before' == place) {
            this._data = listData.data.concat(this._data);
        } else if ('after' == place) {
            this._data = this._data.concat(listData.data);
        } else {
            this._data = listData.data;
        }
        if (listData.state) {
            this._state = listData.state;
        }
        if (listData.pager) {
            this._pager = listData.pager;
        }
        if (listData.locale) {
            this._locale = listData.locale;
        }
        if (listData.pathbar) {
            this._pathbar = listData.pathbar;
        }
        if (listData.additional) {
            this._additionalData = this._additionalData || {};
            this._additionalData = Object.extend(this._additionalData, listData.additional);
        }
        return dataLen;
    },

    _isColumnSelectionPresent: function() {
        for (var index = 0; index < this._columns.length; index++) {
            if (Jsw.list.COLUMN_SELECTION == this._columns[index]) {
                return true;
            }
        }

        return false;
    },

    onHeaderClick: function(dataIndex) {
        this._state.sortField = dataIndex;
        this._state.sortDirection = ('down' == this._state.sortDirection)
            ? 'up'
            : 'down';

        this.reload('/sort-field/' + dataIndex + '/sort-dir/' + this._state.sortDirection);
    },

    updateFilter: function(force) {
        if (!$(this._tableId)) {
            this.checkEmptyList();
            return;
        }
        var filterChanged = false;
        var hasFilter = false;
        this._columns.each(function(column, columnIndex) {
            if (!column.filter || !column.filter.type) {
                return;
            }

            var input;
            if (column.filter.options) {
                if (column.filter.multi) {
                    input = this._componentElement.down('th[data-index="' + column.dataIndex + '"]').select('input[type=checkbox]:checked');
                } else {
                    input = this._componentElement.down('th[data-index="' + column.dataIndex + '"] select');
                }
            } else {
                input = this._componentElement.down('th[data-index="' + column.dataIndex + '"] input');
            }
            if (!input) {
                column.filter.value = '';
                return;
            }

            hasFilter = true;

            var value;
            if (column.filter.multi) {
                value = [];
                input.each(function(el) {
                    value.push(el.value.toLowerCase());
                });
            } else {
                value = input.value.toLowerCase();
            }
            if (value === column.filter.value) {
                return;
            }

            column.filter.value = value;
            filterChanged = true;
        }, this);

        if (!hasFilter || !force && !filterChanged) {
            this.checkEmptyList();
            return;
        }
        var oddEvenRowClass = 'even';
        $(this._tableId).select('tr.odd, tr.even').each(function(row, rowIndex) {
            var cells = row.childElements(),
                match = true;

            this._columns.each(function(column, columnIndex) {
                var value = this._data[rowIndex][column.dataIndex];
                if (cells[columnIndex]._filtered) {
                    if (column.noEscape) {
                        cells[columnIndex].innerHTML = value;
                    } else {
                        cells[columnIndex].innerHTML = value.escapeHTML();
                    }
                    delete cells[columnIndex]._filtered;
                }

                if (!match || !column.filter || !column.filter.type || '' === column.filter.value) {
                    return;
                }

                if (column.filter.type == 'date') {
                    if (new Date(value.replace(/ /g,'T')) < new Date(column.filter.value.replace(/ /g,'T'))) {
                        match = false;
                    }
                    return;
                }

                if (column.filter.options) {
                    if (column.filter.multi) {
                        if (column.filter.value.indexOf(value.toLowerCase()) == -1) {
                            match = false;
                        }
                    } else {
                        if (value.toLowerCase() != column.filter.value) {
                            match = false;
                        }
                    }
                    return;
                }

                var pos = value.toLowerCase().indexOf(column.filter.value);

                if (pos == -1 || column.filter.startsWith && pos !== 0) {
                    match = false;
                    return;
                }

                if (column.noEscape) {
                    cells[columnIndex].innerHTML = value.substr(0, pos)
                        + '<b class="search-result-label">'
                        + value.substr(pos, column.filter.value.length)
                        + '</b>'
                        + value.substr(pos + column.filter.value.length);
                } else {
                    cells[columnIndex].innerHTML = value.substr(0, pos).escapeHTML()
                        + '<b class="search-result-label">'
                        + value.substr(pos, column.filter.value.length).escapeHTML()
                        + '</b>'
                        + value.substr(pos + column.filter.value.length).escapeHTML();
                }
                cells[columnIndex]._filtered = true;
            }, this);

            if (match) {
                row.removeClassName(oddEvenRowClass);
                oddEvenRowClass = oddEvenRowClass == 'odd' ? 'even' : 'odd';
                row.addClassName(oddEvenRowClass);
                row.show();
            } else {
                row.hide();
            }
        }, this);
        this.checkEmptyList();
    },

    onLimitClick: function(value) {
        this.reload('/items-per-page/' + value);
    },

    onPagerClick: function(page) {
        this.reload('/page/' + page);
    },

    onEnumSearchFilterChange: function(element) {
        this._onSearchClick(Element.up(element, 'form'));
    },

    onMultiEnumSearchFilterChange: function(element) {
        var output = element.up('th').down('input[type=text]');
        var input = element.up('th').select('input[type=checkbox]:checked');
        var total = element.up('th').select('input[type=checkbox]');
        if (input.length == 0) {
            output.value = this._locale.none;
        } else if (input.length == total.length) {
            output.value = '';
        } else {
            var value = [];
            input.each(function(el) {
                value.push(el.value[0].toUpperCase());
            });
            output.value = value.join(', ');
        }
    },

    onDateSearchFilterOpen: function(element) {
        if (!element.hasClassName('open')) {
            return;
        }

        var date = new Date(element.down('input').value);
        if (isNaN(date.getTime())) {
            date = new Date();
        }

        this._dateSearchFieldFromDate(element, date);
    },

    onDateSearchFilterChange: function(element) {
        var date = this._dateSearchFieldToDate(element);

        element.down('input').value = date.getFullYear() + '-' +
            (date.getMonth() + 1 < 10 ? '0' : '') + (date.getMonth() + 1) + '-' +
            (date.getDate() < 10 ? '0' : '') + date.getDate() + ' ' +
            (date.getHours() < 10 ? '0' : '') + date.getHours() + ':' +
            (date.getMinutes() < 10 ? '0' : '') +date.getMinutes();
    },

    onDateSearchFilterModify: function(element, date) {
        this._dateSearchFieldFromDate(element, date);
    },

    _dateSearchFieldFromDate: function(element, date) {
        var elements = element.select('select');
        elements[0].value = date.getHours();
        elements[1].value = date.getMinutes();
        elements[2].value = date.getDate();
        elements[3].value = date.getMonth();
        elements[4].value = date.getFullYear();
    },

    _dateSearchFieldToDate: function(element) {
        var elements = element.select('select');
        return new Date(elements[4].value, elements[3].value, elements[2].value, elements[0].value, elements[1].value);
    },

    onSelectButtonClick: function(event) {
        var globalCheckbox = this._componentElement.select('input[name="listGlobalCheckbox"]').first();
        globalCheckbox.checked = !globalCheckbox.checked;
        this.onListGlobalCheckboxClick(event);
        event.stopPropagation();
    },

    onListGlobalCheckboxClick: function(event) {
        var actionsBox = this._componentElement.select('.actions-box').first();
        var globalCheckbox = this._componentElement.select('input[name="listGlobalCheckbox"]').first();

        if (actionsBox) {
            var selectButton = actionsBox.select('.r-actions-select').first();
            if (globalCheckbox.checked) {
                selectButton.addClassName('r-actions-item-active');
            } else {
                selectButton.removeClassName('r-actions-item-active');
            }
        }

        this._componentElement.select('input[name="listCheckbox[]"]').each(function(checkbox) {
            if (globalCheckbox.checked) {
                checkbox.up('tr').addClassName('selected');
            } else {
                checkbox.up('tr').removeClassName('selected');
            }
            checkbox.checked = globalCheckbox.checked;
        });
    },

    onPagerButtonClick: function(event) {
        var paging = this._componentElement.select('.paging').first();
        var show = !paging.hasClassName('r-paging-visible');
        if (this._actionBox) {
            this._actionBox._hideResponsiveButtonBlocks();
        }
        if (show) {
            paging.addClassName('r-paging-visible');
        }
        event.stopPropagation();
    },

    _getListHeadersHtml: function() {
        var headerHtml = '',
            filterHtml = '',
            hasFilter = false,
            colspan = 0;

        this._columns.each(function(column) {
            if (colspan) {
                colspan --;
                return;
            }

            if ('function' === typeof column.isVisible) {
                if (!column.isVisible()) {
                    return;
                }
            }

            if (column.headerColspan) {
                colspan = column.headerColspan;
            }

            var data = '';

            var headerCls = '';

            if ('undefined' != typeof column.headerCls) {
                headerCls = column.headerCls;
            }

            var headerParams = {};
            var headerParamsString = '';

            if ('undefined' != typeof column.headerParams) {
                headerParams = $H(column.headerParams);
                headerParams.each(function(param) {
                    headerParamsString = param.key + "='" + param.value + "' ";
                });
            }

            if ('undefined' != typeof column.headerRenderer) {
                data = column.headerRenderer(column);
            } else {
                data = column.header;

                var sortCssClass = '';

                if (this._state.sortField == column.dataIndex) {
                    sortCssClass = ('down' == this._state.sortDirection)
                        ? ''
                        : 'sort-up';

                    headerCls = (headerCls)
                        ? (headerCls + ' ' + 'sort')
                        : 'sort';
                }

                if (column.sortable) {
                    data = '<a class="' + sortCssClass + '" href="#" onclick="Jsw.getComponent(\'' + this._id
                        + '\').onHeaderClick(\'' + column.dataIndex + '\')">' + data + '</a>';
                }
            }

            headerHtml += '<th class="' + headerCls + '"' + (colspan ? 'colspan="' + colspan + '"' : '') + ' ' + headerParamsString + '>' + data + '</th>';

            data = '';
            if (column.filter) {
                hasFilter = true;
                data = this._getSearchFilterBodyHtml(column.dataIndex, column.filter, 'Jsw.getComponent(\'' + this._id + '\').updateFilter();');
            }
            filterHtml += '<th data-index="' + column.dataIndex + '">' + data + '</th>';
        }, this);

        return '<thead>' + (hasFilter ? '<tr class="list-search-filter">' + filterHtml + '</tr>' : '') + '<tr>' + headerHtml + '</tr></thead>';
    },

    _getListDataHtml: function(listData, indexOffset) {
        if ('undefined' == typeof listData) {
            listData = this._data;
        }
        indexOffset = indexOffset || 0;
        if (!listData) {
            return ;
        }

        var html = '';

        listData.each(function(item, index) {
            var rowClass = this._getRowClass(item);
            var oddEvenRowClass = (index + indexOffset) % 2 ? 'even' : 'odd';
            html += '<tr class="' + rowClass + ' ' + oddEvenRowClass + '">';

            this._columns.each(function(column) {
                if ('function' === typeof column.isVisible) {
                    if (!column.isVisible()) {
                        return;
                    }
                }

                var data = '';

                if ('undefined' != typeof column.renderer) {
                    var isDisabled = this.isDisabledItem(item);

                    if (isDisabled && ('undefined' != typeof column.hideDisabled) && column.hideDisabled) {
                        data = '';
                    } else {
                        data = column.renderer(item, isDisabled);
                    }
                } else if ('undefined' != typeof column.dataIndex) {
                    if (column.noEscape) {
                        data = item[column.dataIndex];
                    } else {
                        data = item[column.dataIndex].escapeHTML();
                    }
                }

                var itemCls = '';

                if ('undefined' != typeof column.cls) {
                    itemCls = column.cls;
                }

                html += '<td class="' + itemCls + '">' + data + '</td>';
            }, this);

            html += '</tr>';
        }, this);

        return html;
    },

    _getListHtml: function() {
        return '' +
            this._getPagerHtml() +
            '<div class="' + this._listCls + '">' +
                '<table width="100%" cellspacing="0" id="' + this._tableId + '">' +
                    this._getListHeadersHtml() +
                    this._getListDataHtml() +
                '</table>' +
            '</div>' +
            this._getPagerHtml() +
            '<span class="empty-list">' + this._locale.noEntriesFound + '</span>';
    },

    checkEmptyList: function() {
        var isEmpty = this.isListEmpty();
        this._componentElement.select('.empty-list').invoke('toggle', isEmpty);
        this._componentElement.select('.paging').invoke('toggle', !isEmpty);
        var listSelector = this._listCls.split(' ').reduce(function(previousValue, currentValue) {
            if (currentValue !== '') {
                previousValue += '.' + currentValue;
            }
            return previousValue;
        }, '');
        this._componentElement.select(listSelector).invoke('toggle', !isEmpty);
    },

    isListEmpty: function() {
        if (!$(this._tableId)) {
            return 0 == this._data.length;
        }
        return 0 == $(this._tableId).select('tr.odd,tr.even').filter(Element.visible);
    },

    _getPathbarHtml: function() {
        if (!this._pathbar) {
            return '';
        }

        return '<div id="' + this._id + '-pathbar"></div>';
    },

    _getPagerHtml: function() {
        if (!this._pageable) {
            return '';
        }
        var totalRecords = this._getTotalInfo();

        var html =
            '<div class="paging">' +
                '<div class="paging-area">' +
                    '<span class="paging-info"  onclick="Jsw.getComponent(\'' + this._id +
                        '\').onPagerButtonClick(event);">' + totalRecords + '</span>' +
                    '<span class="paging-view">' + this._locale.numberOfItemPerPage + ': ' +
                        this._getLimitValuesHtml() +
                    '</span>';

        if (this._pager.pageCount > 1) {
            html += '<span class="paging-nav">' + this._locale.pages + ': ' + this._getPagesItemsHtml() + '</span>';
        }

        html += '</div></div>';

        return html;
    },

    _getLimitValuesHtml: function() {
        var html = '';

        this._limitValues.each(function(limitValue) {
            var limitValueTitle = (Jsw.list.ITEMS_UNLIMITED == limitValue)
                ? this._locale.allItems
                : limitValue;

            if (this._pager.itemCountPerPage != limitValue) {
                html += '<a href="#" onclick="Jsw.getComponent(\'' + this._id +
                    '\').onLimitClick(' + limitValue + ');">' + limitValueTitle + '</a> ';
            } else {
                html += '<span>' + limitValueTitle + '</span> ';
            }
        }, this);

        return html;
    },

    _getPagesItemsHtml: function() {
        var html = '';

        if (this._pager.first != this._pager.current) {
            html += '<a href="#" onclick="' + this._getPageItemLink(this._pager.first) + '">'
                + this._locale.firstPage + '</a> ';
        } else {
            html += '<span>' + this._locale.firstPage + '</span> ';
        }

        if (this._pager.previous) {
            html += '<a href="#" onclick="' + this._getPageItemLink(this._pager.previous) + '">&lt;&lt;</a> ';
        } else {
            html += '<span>&lt;&lt;</span> ';
        }

        $H(this._pager.pagesInRange).values().each(function(page) {
            if (page != this._pager.current) {
                html += '<a href="#" onclick="' + this._getPageItemLink(page) + '">' + page + '</a> ';
            } else {
                html += page + ' ';
            }
        }, this);

        if (this._pager.next) {
            html += '<a href="#" onclick="' + this._getPageItemLink(this._pager.next) + '">&gt;&gt;</a> ';
        } else {
            html += '<span>&gt;&gt;</span> ';
        }

        if (this._pager.last != this._pager.current) {
            html += '<a href="#" onclick="' + this._getPageItemLink(this._pager.last) + '">'
                + this._locale.lastPage + '</a> ';
        } else {
            html += '<span>' + this._locale.lastPage + '</span> ';
        }

        return html;
    },

    _getPageItemLink: function(page) {
        return "Jsw.getComponent('" + this._id + "').onPagerClick(" + page + ");";
    },

    _getSearchFiltersHtml: function() {
        if (!this._searchable) {
            return '';
        }

        var searchFilterHtml = '';

        this._searchFilters.each(function(pair) {
            var filterName = pair.key;
            var filterConfig = pair.value;

            var filterTitle = filterConfig.title;
            var filterTitleHtml = '';
            if (filterTitle) {
                filterTitleHtml = '<span>' + filterTitle + '</span>';
            }

            var filterBodyHtml = this._getSearchFilterBodyHtml(filterName, filterConfig);

            searchFilterHtml +=
                '<li>' +
                    '<div>' +
                        filterTitleHtml +
                        filterBodyHtml +
                    '</div>' +
                '</li>';
        }, this);

        return searchFilterHtml;
    },

    _getSearchFilterBodyHtml: function(filterName, filterConfig, handler) {
        var filterBodyHtml = '';

        if (filterConfig.render) {
            filterBodyHtml = filterConfig.render(filterConfig, handler);
        } else if (filterConfig.type == 'date') {
            filterBodyHtml = this._getSearchFilterHtmlDate(filterName, filterConfig, handler);
        } else if (filterConfig.options) {
            if (filterConfig.multi) {
                filterBodyHtml = this._getSearchFilterHtmlMultiEnum(filterName, filterConfig, handler);
            } else {
                filterBodyHtml = this._getSearchFilterHtmlEnum(filterName, filterConfig, handler);
            }
        } else {
            filterBodyHtml = this._getSearchFilterHtmlText(filterName, filterConfig, handler);
        }

        return filterBodyHtml;
    },

    _getSearchFilterHtmlText: function(filterName, filterConfig, handler) {
        var filterState = $H(this._state.searchFilters).get(filterName);
        var currentValue = filterConfig.value || filterState && filterState.searchText;
        var filterHtml = '<input' +
                ' id="' + this._id + '-search-text-' + filterName + '"' +
                ' name="searchFilter[' + filterName + '][searchText]"' +
                (filterConfig.placeholder ? ' placeholder="' + filterConfig.placeholder + '"' : '') +
                ' type="text"' +
                (handler ? ' onkeyup="' + handler + '"' : '') +
                (currentValue ? ' value="' + currentValue.escapeHTML().replace(/"/g, '&quot;') + '"' : '') +
            '/>';
        return filterHtml;
    },

    _getSearchFilterHtmlEnum: function(filterName, filterConfig, handler) {
        var filterState = $H(this._state.searchFilters).get(filterName);
        var currentValue = filterConfig.value || filterState && filterState.searchText;
        var optionsHtml = '';

        filterOptions = $A(filterConfig.options);

        filterOptions.each(function(item) {
            if ('value' == item.type) {
                optionsHtml += this._getSearchFilterHtmlEnumValue(currentValue, item.value, item.label);
            } else {
                optionsHtml += this._getSearchFilterHtmlEnumGroup(currentValue, item.options, item.label);
            }
        }, this);

        var filterHtml = '<select' +
            ' id="' + this._id + '-type-filter"' +
            ' name="searchFilter[' + filterName + '][searchText]"' +
            ' onchange="' + (handler ? handler : 'Jsw.getComponent(\'' + this._id + '\').onEnumSearchFilterChange(this)') + '"' +
        '>' + optionsHtml + '</select>';

        return filterHtml;
    },

    _getSearchFilterHtmlMultiEnum: function(filterName, filterConfig, handler) {
        var currentValue = filterConfig.value;

        filterOptions = $A(filterConfig.options);

        var value = '';
        var html = '';
        html += '<div class="dropdown">';
        html += '<div class="input-group">';
        html += '<input type="text" readonly class="form-control" ' +
            (filterConfig.placeholder ? ' placeholder="' + filterConfig.placeholder + '"' : '') + 'value="' + value + '">';
        html += '<span class="input-group-btn"><span type="button" class="btn dropdown-toggle">';
        html += '<button type="button"><span class="caret"></span></button></span></span>';
        html += '</div>';
        html += '<ul class="dropdown-menu pull-right" onclick="Event.extend(event).stopPropagation();">';
        if (0 != filterOptions.size()) {
            html += '<li>';
            html += '<div class="dropdown-menu-content checkbox-group">';
            filterOptions.each(function(pair) {
                html += '<label><input type="checkbox" value="' + pair.value + '"' +
                    (!currentValue || currentValue.indexOf(pair.value) != -1 ? ' checked="checked"' : '') +
                    ' onclick="Jsw.getComponent(\'' + this._id + '\').onMultiEnumSearchFilterChange(this);' + handler + '""> ' + pair.label + '</label>';
            }, this);
            html += '</div>';
            html += '</li>';
        }
        html += '</ul>';
        html += '</div>';

        return html;
    },

    _getSearchFilterHtmlEnumValue: function(currentValue, value, label)
    {
        var selected = currentValue == value ? 'selected="selected"' : '';
        var ret = '<option value="' + value.escapeHTML().replace(/"/g, '&quot;') + '"' + selected + '>' + label.escapeHTML() + '</option>';
        return ret;
    },

    _getSearchFilterHtmlEnumGroup: function(currentValue, options, label)
    {
        var ret = '';
        ret += '<optgroup label="' + label.escapeHTML().replace(/"/g, '&quot;') + '">';
        $A(options).each(function(item) {
            if ('value' == item.type) {
                ret += this._getSearchFilterHtmlEnumValue(currentValue, item.value, item.label);
            } else {
                ret += this._getSearchFilterHtmlEnumGroup(currentValue, item.options, item.label);
            }
        }, this);
        ret += '</optgroup>';
        return ret;
    },

    _getSearchFilterHtmlDate: function(filterName, filterConfig, handler) {
        var i, ret = '';

        ret += '<div class="dropdown">';
        ret += '<div class="input-group" onclick="Jsw.getComponent(\'' + this._id + '\').onDateSearchFilterOpen(this.up(\'.dropdown\'));">';
        ret += '<input type="text" class="form-control" readonly=""' +
                    (filterConfig.placeholder ? ' placeholder="' + filterConfig.placeholder + '"' : '') +
                '/>';
        ret += '<span class="input-group-btn"><span class="btn dropdown-toggle" type="button">';
        ret += '<button type="button"><span class="caret"></span></button></span></span>';
        ret += '</div>';
        ret += '<ul class="dropdown-menu" onclick="Event.extend(event).stop();">';
        ret += '<li>';
        ret += '<div class="filter-date-form">';
        ret += '<div class="form-row">';

        ret += '<div class="inline-fields-group">';
        ret += '<select>';
        for (i = 0; i < 24; i++) {
            ret += '<option value="' + i + '">' + (i < 10 ? '0' : '') + i + '</option>';
        }
        ret += '</select>';
        ret += ' : ';
        ret += '<select>';
        for (i = 0; i < 60; i++) {
            ret += '<option value="' + i + '">' + (i < 10 ? '0' : '') + i + '</option>';
        }
        ret += '</select>';
        ret += '</div>';

        ret += '<div class="inline-fields-group">';
        ret += '<select>';
        for (i = 1; i < 32; i++) {
            ret += '<option value="' + i + '">' + (i < 10 ? '0' : '') + i + '</option>';
        }
        ret += '</select>';
        ret += ' ';
        ret += '<select>';
        for (i = 0; i < 12; i++) {
            ret += '<option value="' + i + '">' + this._locale['month' + (i + 1)] + '</option>';
        }
        ret += '</select>';
        ret += ' ';
        ret += '<select>';
        for (i = 2000; i <= (new Date()).getFullYear(); i++) {
            ret += '<option value="' + i + '">' + i + '</option>';
        }
        ret += '</select>';
        ret += '</div>';

        ret += '<div class="inline-fields-group">';
        ret += '<span class="btn"><button type="button" onclick="this.up(\'.dropdown\').toggleClassName(\'open\');Jsw.getComponent(\'' + this._id + '\').onDateSearchFilterOpen(this.up(\'.dropdown\'));Jsw.getComponent(\'' + this._id + '\').onDateSearchFilterChange(this.up(\'.dropdown\'));' + handler + '">' + this._locale.apply + '</button></span>';
        ret += '<span class="btn"><button type="button" onclick="this.up(\'.dropdown\').toggleClassName(\'open\');this.up(\'.dropdown\').down(\'input\').value = \'\';Jsw.getComponent(\'' + this._id + '\').onDateSearchFilterOpen(this.up(\'.dropdown\'));' + handler + '">' + this._locale.clear + '</button></span>';
        ret += '</div>';

        ret += '</div>';
        ret += '<div class="form-row filter-actions-row">';
        ret += '<div class="inline-fields-group">';
        ret += '<a class="toggler" href="#" onclick="Jsw.getComponent(\'' + this._id + '\').onDateSearchFilterModify(this.up(\'.dropdown\'), new Date(new Date().getTime() - 3600 * 1000));' + (handler) + '; return false;">' + this._locale.hourAgo + '</a> ';
        ret += '<a class="toggler" href="#" onclick="Jsw.getComponent(\'' + this._id + '\').onDateSearchFilterModify(this.up(\'.dropdown\'), new Date(new Date().getTime() - 86400 * 1000));' + (handler) + '; return false;">' + this._locale.prevDay + '</a>';
        ret += '</div>';
        ret += '</div>';
        ret += '</div>';
        ret += '</li>';
        ret += '</ul>';
        ret += '</div>';

        return ret;
    },

    _addSearchHandlers: function() {
        if (!this._searchable) {
            return;
        }

        var context = this;

        if (this._searchExtended) {
            this._componentElement.select('.search-control .s-btn').each(function(element) {
                element.observe('click', function() {
                    this.up('.actions-box').toggleClassName('actions-box-search-show');
                    Jsw.Cookie.set(context._id + '-search-show', this.up('.actions-box').hasClassName('actions-box-search-show'));
                    context._hideItemsNotSelectedWarning();
                    return false;
                });
            });
        }

        if (this._searchExtended) {
            var searchLink = this._componentElement.select('.sb-search').first();
            var form = searchLink.up('form');
            searchLink.observe('click', function(event) {
                context._onSearchClick(form);
                Event.stop(event);
            });
            form.observe('submit', function(event) {
                context._onSearchClick(form);
                Event.stop(event);
            });


            var resetSearchLink = this._componentElement.select('.sb-show-all').first();
            resetSearchLink.observe('click', function(event) {
                context._onResetSearchClick();
                Event.stop(event);
            });
        }

        if (this._getSearchOveralField()) {
            this._componentElement.select('.quick-search-box form em').each(function(element) {
                element.observe('click', function(event) {
                    context._onSearchClick(element.up('form'));
                    event.preventDefault();
                });
            });
            this._componentElement.select('.quick-search-box form').each(function(element) {
                element.observe('submit', function(event) {
                    context._onSearchClick(element);
                    Event.stop(event);
                });
            });
        }
    },

    _onSearchClick: function(form) {
        this.reload('?' + form.serialize());
    },

    _onResetSearchClick: function() {
        this.reload('/reset-search/true/');
    },

    _addSelectionHandlers: function() {
        var context = this;
        var selectButton;

        var actionsBox = this._componentElement.select('.actions-box').first();
        if (actionsBox) {
            selectButton = new Element('li', {"class": "r-actions-item r-actions-select"})
                .update('<span></span>')
                .observe('click', this.onSelectButtonClick.bindAsEventListener(this));
            this._componentElement.down('.actions-box .r-actions-list').insert({top: selectButton});
        }

        var globalCheckbox = this._componentElement.select('input[name="listGlobalCheckbox"]').first();
        globalCheckbox.observe('click', this.onListGlobalCheckboxClick.bind(this));

        this._componentElement.select('input[name="listCheckbox[]"]').each(function(checkbox) {
            checkbox.observe('click', function() {
                if (checkbox.checked) {
                    checkbox.up('tr').addClassName('selected');
                } else {
                    checkbox.up('tr').removeClassName('selected');
                    globalCheckbox.checked = false;
                    if (selectButton) {
                        selectButton.removeClassName('r-actions-item-active');
                    }
                }
            });
        });

        $(document).observe('click', function(event) {
            if (event.findElement('.objects-toolbar')) {
                return;
            }

            context._hideItemsNotSelectedWarning();
        });
        $(document).observe('touchstart', function() {
            list._hideItemsNotSelectedWarning();
        });
    },

    _addPathbar: function() {
        if (!this._pathbar) {
            return;
        }

        eval('this._pathbarComponent = new ' + this._pathbar.componentType + '(this._pathbar);');
        this._pathbarComponent.setRenderTarget(this._id + '-pathbar');
        this._pathbarComponent.render();
    },

    disable: function() {
        this._disablerOverlay.show();
        Jsw.clonePosition(this._disablerOverlay, this._componentElement);
    },

    enable: function() {
        this._disablerOverlay.hide();
    },

    getSelectedItemsIds: function() {
        var itemsIds = new Array();

        this._componentElement.select('input[name="listCheckbox[]"]').each(function(checkbox) {
            if (checkbox.checked) {
                itemsIds.push(checkbox.value);
            }
        });

        return itemsIds;
    },

    getSelectedItems: function() {
        var ids = [];
        var selectedItems = [];

        this.getSelectedItemsIds().each(function(id) {
            ids.push(id);
        });

        this._data.each(function(dataItem) {
            var itemIndex = ids.indexOf(dataItem.id);
            if (itemIndex < 0) {
                return;
            }

            selectedItems.push(dataItem);
        });

        return selectedItems;
    },

    checkNonEmptySelection: function() {
        if (0 == this.getSelectedItemsIds().length) {
            this._showItemsNotSelectedWarning();
            return false;
        }
        this._hideItemsNotSelectedWarning();
        return true;
    },

    execLongGroupOperation: function(params, event) {
        var itemId;
        params.onSuccess = function() {
            var progressBar = Jsw.getComponent('asyncProgressBarWrapper');
            progressBar.removePreparingItem(itemId);
            progressBar.update();
        };

        params.beforeSendRequest = function(sendRequest) {
            var beginOffset = event.target.cumulativeOffset();
            itemId = Jsw.getComponent('asyncProgressBarWrapper').fly(beginOffset,
                params.taskName,
                function(){
                    sendRequest();
                });
        };

        this.execGroupOperation(params);
    },

    execGroupOperation: function(params) {
        var context = this;

        var ids = $H();
        var count = 0;

        var idsParamName = params.submitVarName
            ? params.submitVarName
            : 'ids';

        var selectedItems = params.selectedItems ? params.selectedItems : this.getSelectedItemsIds();
        selectedItems.each(function(id) {
            ids.set(idsParamName + '[' + count + ']', id);
            count++;
        });

        if (params.checkSelection) {
            if (!params.checkSelection()) {
                return;
            }
        } else if (0 == count) {
            this._showItemsNotSelectedWarning();
            return ;
        } else {
            this._hideItemsNotSelectedWarning();
        }

        var sendRequestHandler = params.submitHandler
            ? params.submitHandler
            : function(url, ids) {
                new Ajax.Request(Jsw.prepareUrl(url), {
                    method: 'post',
                    parameters: ids,
                    reloading: false,

                    onSuccess: function (transport) {
                        try {
                            var status = transport.responseText.evalJSON();
                        } catch (e) {
                            Jsw.showInternalError(transport.responseText);
                            return;
                        }
                        if (status.redirect) {
                            Jsw.redirect(status.redirect);
                        } else if (!status.noReload) {
                            this.reloading = true;
                            context.reload();
                        }

                        if (context._clearStatusOnReload) {
                            Jsw.clearStatusMessages();
                        }
                        $A(status.statusMessages).each(function(message) {
                            Jsw.addStatusMessage(message.status, message.content);
                        });

                        if (params.onSuccess) {
                            params.onSuccess(status);
                        }
                    },

                    onCreate: function() {
                        context.disable();
                    },

                    onComplete: function() {
                        if (!this.reloading) {
                            context.enable();
                        }
                    },

                    onFailure: function(req) {
                        if (504 == req.status) {
                            Jsw.addStatusMessage('error', context._locale.timeoutMessage);
                        } else {
                            Jsw.showInternalError(req.responseText);
                        }

                        context.enable();
                    }
                });
            };

        var sendRequest = function() {
            if (params.beforeSendRequest) {
                params.beforeSendRequest(function(){
                    sendRequestHandler(params.url, ids);
                });
            } else {
                sendRequestHandler(params.url, ids);
            }
        };

        var skipConfirmation = params.skipConfirmation;
        var mouseEvent = params.mouseEvent;

        if (mouseEvent && !skipConfirmation) {
            mouseEvent.preventDefault();
            skipConfirmation = mouseEvent.shiftKey;
        }

        if (skipConfirmation) {
            sendRequest();
        } else {
            Jsw.messageBox.show({
                type: Jsw.messageBox.TYPE_YESNO,
                buttonTitles: {
                    yes: this._locale.messageBoxButtonYes,
                    no: this._locale.messageBoxButtonNo,
                    wait: this._locale.messageBoxButtonWait
                },
                text: params.getConfirmOnGroupOperation
                    ? params.getConfirmOnGroupOperation()
                    : params.locale.confirmOnGroupOperation,
                subtype: params.subtype,
                needAttention: params.needAttention ? params.needAttention : false,
                needAttentionText: params.needAttentionText ? params.needAttentionText : '',
                needAttentionBlockSubmit: params.needAttentionBlockSubmit ? params.needAttentionBlockSubmit : false,
                onYesClick: sendRequest,

                isAjax: params.isAjax,
                requestUrl: params.requestUrl,
                requestParams: ids,
                loadingTitle: params.loadingTitle
            });
        }
    },

    _showItemsNotSelectedWarning: function() {
        this._hideItemsNotSelectedWarning();
        var element = this._componentElement.down('items-not-selected-warning');
        if (element) {
            element.show();
        } else {
            this._componentElement.down('.actions-box').insert({ top:
                '<div class="actions-msg-container" id="items-not-selected-warning"><span class="list-actions-msg"><span>' +
                this._locale.itemsNotSelected + '</span></span></div>'
            });
        }
    },

    _hideItemsNotSelectedWarning: function() {
        var element = this._componentElement.down('.actions-msg-container');
        if (element) {
            element.hide();
        }
    },

    render: function($super) {
        $super();

        if (this._columns.indexOf(Jsw.list.COLUMN_ACTIONS) != -1) {
            this._contextMenu = new Jsw.ListContextMenu({
                renderTo: document.body,
                list: this
            });
        }

        if (!this._data) {
            this.reload();
            return ;
        }

        this.redraw();
    },

    _addEvents: function() {
        $(document).observe('click', function () {
            var paging = this._componentElement.select('.paging').first();
            if (paging) {
                paging.removeClassName('r-paging-visible');
            }
        }.bind(this));
    },

    reload: function(urlParams, place) {
        urlParams = urlParams || '';

        if (!this._dataUrl) {
            return;
        }

        var reloadUrl = this._dataUrl;
        var parameters = {};
        if ('string' == typeof urlParams && urlParams) {
            var splitUrl = reloadUrl.split('?', 2);
            var splitParams = urlParams.split('?', 2);
            reloadUrl = splitUrl[0].concat(splitParams[0]);
            parameters = Object.extend(
                (splitUrl[1] || '').toQueryParams(),
                (splitParams[1] || '').toQueryParams()
            );
        }

        if (this._request) {
            this._request.abort();
        }

        this._request = new Ajax.Request(Jsw.prepareUrl(reloadUrl), {
            parameters: parameters,
            method: 'get',
            onSuccess: this._onReloadSuccess.bind(this, place),
            onFailure: this._onReloadFailure.bind(this),
            onException: this._onReloadException.bind(this),
            onCreate: this._onReloadCreate.bind(this),
            onComplete: this._onReloadComplete.bind(this)
        });
        return this._request;
    },

    _onReloadSuccess: function(place, transport) {
        if ('' == transport.responseText) {
            //:INFO: sometimes happens in FF if you are go to other page during request
            return;
        }

        try {
            var data = transport.responseText.evalJSON();
        } catch (e) {
            Jsw.showInternalError(transport.responseText);
            return;
        }

        var dataLen = this._splitListData(data, place);
        if (false === dataLen) {
            this.processReloadError(data);
        } else {
            this.redraw(place, dataLen);
        }
    },

    _onReloadFailure: function(transport) {
        Jsw.showInternalError(transport.responseText);
    },

    _onReloadException: function(transport, exception) {
        Jsw.showInternalError(exception + "\n" + transport.responseText);
    },

    _onReloadCreate: function(transport) {
        if (this._clearStatusOnReload) {
            Jsw.clearStatusMessages();
        }
        this.disable();
    },

    _onReloadComplete: function() {
        this._request = null;
        this.enable();
    },

    _addDisabledCheckboxesHints: function() {
        var checkboxes = this._componentElement.select('input[type="checkbox"][disabled]');

        checkboxes.each(function(checkbox) {
            new Jsw.Tooltip.Instance(checkbox.previous(), {text: this._disabledSelectHint });
        }, this);
    },

    redrawPartial: function(place, dataLen) {
        if (0 == dataLen) {
            return;
        }

        if ('before' == place) {
            $(this._tableId).down('thead').insert({
                after: this._getListDataHtml(this._data.slice(0, dataLen))
            });
        } else if ('after' == place) {
            $(this._tableId).insert({
                bottom: this._getListDataHtml(this._data.slice(-dataLen))
            });
        }

        Jsw.Tooltip.initData(this._componentElement);
        this.updateFilter(true);
        if (this._onRedraw) {
            this._onRedraw();
        }
    },

    redraw: function(place, dataLen) {
        if (place && $(this._tableId)) {
            this.redrawPartial(place, dataLen);
            return;
        }

        this._componentElement.down().replace(
            '<div id="' + this._id + '-container">' +
                this._getPathbarHtml() +
                this._getListHtml() +
            '</div>'
        );

        if (this._operations || this._searchable) {
            this._actionBox = new Jsw.SmallTools({
                operationsId: this._id + '-operations',
                renderTo: this._componentElement.down(),
                renderMode: 'top',
                operations: this._getOperations()
            });
        }

        if (this._searchable) {
            this._addSearchTools();
        }

        if (this._rowSelectable && this._pager.totalItemCount > 0) {
            this._addSelectionHandlers();
        }
        if (this._contextMenu) {
            this._contextMenu.onRedraw();
        }

        this._addPathbar();
        this._addSearchHandlers();

        if (this._disabledSelectHint) {
            this._addDisabledCheckboxesHints();
        }

        this._addResponsiveHtml();

        this._initDropdowns();
        Jsw.Tooltip.initData(this._componentElement);
        this.updateFilter(true);
        if (this._onRedraw) {
            this._onRedraw();
        }
    },

    _initDropdowns: function() {
        var dropdown;
        this._dropdowns = this._dropdowns || [];
        while (dropdown = this._dropdowns.pop()) {
            Jsw.DropdownManager.unregister(dropdown);
        }

        this._componentElement.select('.dropdown .input-group').each(function(el) {
            this._dropdowns.push(Jsw.DropdownManager.register(el,
                function() {
                    return el.up().hasClassName('open');
                },
                function() {
                    el.up().addClassName('open');
                },
                function() {
                    el.up().removeClassName('open');
                }
            ));
        }, this);
    },

    _addSearchTools: function() {
        if (this._state.forceShowSearch) {
            Jsw.Cookie.set(this._id + '-search-show', 'true');
        }

        if (
            this._searchable &&
            this._searchExtended &&
            'true' == Jsw.Cookie.get(this._id + '-search-show')
        ) {
            this._actionBox._componentElement.addClassName('actions-box-search-show');
        }

        var quickSearchBoxEl = new Element('div', {'class': 'quick-search-box'})
            .observe('click', function(event) {
                event.stopPropagation();
            });
        this._actionBox._componentElement.down('.objects-toolbar').insert(quickSearchBoxEl);

        if (this._getSearchOveralField()) {
            quickSearchBoxEl.insert(
                '<div class="search-field">' +
                    '<form>' +
                        this._getSearchFilterBodyHtml(this._getSearchOveralField(), this._searchFilters.get(this._getSearchOveralField())) +
                        '<em><span></span></em>' +
                    '</form>' +
                '</div>'
            );
        }

        if (this._searchExtended) {
            quickSearchBoxEl.insert(
                '<span class="search-control">' +
                    '<a class="s-btn sb-search-show" href="#">' +
                        '<i><i><i><span>' + this._locale.showSearch + '</span></i></i></i>' +
                    '</a>' +
                    '<a class="s-btn sb-search-hide" href="#">' +
                        '<i><i><i><span>' + this._locale.hideSearch + '</span></i></i></i>' +
                    '</a>' +
                '</span>'
            );

            this._actionBox._componentElement.insert(
                '<div class="search-box">' +
                    '<form>' +
                        '<ul>' +
                            this._getSearchFiltersHtml() +
                        '</ul>' +
                        '<a class="s-btn sb-search" href="#">' +
                            '<i><span>' + this._locale.buttonSearch + '</span></i>' +
                        '</a>' +
                        '<a class="s-btn sb-show-all" href="#">' +
                            '<i><span>' + this._locale.buttonResetSearch + '</span></i>' +
                        '</a>' +
                        '<input type="image" style="border: 0pt none ; height: 0pt; width: 0pt; position: absolute; left: -9999px;" src="' + Jsw.skinUrl + '/images/blank.gif">' +
                    '</form>' +
                '</div>'
            );
            this._actionBox._componentElement.down('.search-box').observe('click', function(event) {
                event.stopPropagation();
            });
        }

        this._actionBox.addResponsiveButton('search');
    },

    processReloadError: function(data) {
        Jsw.showInternalError('Unable to load list data.');
    },

    hasSelectedItems: function(callback) {
        var selected = this.getSelectedItemsIds();

        if (0 == selected.length) {
            this._showItemsNotSelectedWarning();
            return false;
        } else {
            this._hideItemsNotSelectedWarning();
        }

        if (callback) {
            callback.bind(this)();
        }

        return true;
    },

    getItemById: function(itemId) {
        for (var i = 0; i < this._data.length; i++) {
            if (this._data[i].id == itemId) {
                return this._data[i];
            }
        }
    },

    _addResponsiveHtml: function() {
        var list = this;
        var columns = this._componentElement.select('thead th');
        this._componentElement.select('#' + this._tableId + ' tbody tr').each(function(row){
            var cells = row.childElements();
            for (var i = 0; i < cells.length; i++) {
                var element = cells[i];
                var columnName = columns[i].innerHTML.strip().stripTags();
                var columnNameHtml = '<span class="r-visible">' + columnName + '</span>';

                list._addResponsiveHtmlToButtons(element, columnNameHtml);

                list._addResponsiveHtmlToImages(element, columnNameHtml);

                list._addResponsiveHtmlToIcons(element, columnNameHtml);

                list._addResponsiveHtmlToNumbers(element, columnName)
            }
        });
    },

    _addResponsiveHtmlToButtons: function(element, columnNameHtml) {
        var buttons = element.select('a.s-btn');
        buttons.each(function(button) {
            var tooltip = button.previous('.tooltipData');
            if (!button.down('span').innerHTML && tooltip) {
                button.down('span').innerHTML = '<span class="r-visible">' + tooltip.innerHTML + '</span>';
            }
        });
        if (buttons.length == 1 && !buttons[0].down('span').innerHTML) {
            buttons[0].down('span').innerHTML = columnNameHtml;
        }
    },

    _addResponsiveHtmlToImages: function(element, columnNameHtml) {
        var images = element.select('a img');
        images.each(function(image) {
            var text = '';
            var tooltip = image.up().previous('.tooltipData');
            if (!tooltip) {
                if (images.length != 1) {
                    return;
                }
                text = columnNameHtml;
            } else {
                text = tooltip.innerHTML;
            }
            if (!image.up('.b-indent-icon') || !image.up('a').innerHTML.replace(image.up('.b-indent-icon').outerHTML, '').strip()) {
                image.wrap('i', {'class' : 'icon'});
                image.up().insert({after: ' <span class="r-visible">' + text + '</span>'});
                image.up('a').addClassName('i-link');
            }
        });
    },

    _addResponsiveHtmlToIcons: function(element, columnNameHtml) {
        var icons = element.select('span.b-indent-icon');
        icons.each(function(icon) {
            var tooltip = icon.select('.tooltipData');
            if (tooltip.length > 0 && !icon.up().innerHTML.replace(icon.outerHTML, '').strip()) {
                icon.down('img').insert({after: ' <span class="r-visible">' + tooltip[0].innerHTML + '</span>'});
            }
        });
        if (icons.length == 1 && !icons[0].down('span.r-visible') && !icons[0].up().innerHTML.replace(icons[0].outerHTML, '').strip()) {
            icons[0].down('img').insert({after: columnNameHtml});
        }
    },

    _addResponsiveHtmlToNumbers: function(element, columnName) {
        var number = element.innerHTML;
        var columnNameHtml = '<span class="r-visible">' + columnName + ': </span>';
        if ('-' == number || (!isNaN(parseFloat(number)) && isFinite(number))) {
            element.insert({top: columnNameHtml});
        }
        var links = element.select('a');
        if (
            links.length == 1 &&
            ('-' == links[0].innerHTML || (!isNaN(parseFloat(links[0].innerHTML)) && isFinite(links[0].innerHTML)))
        ) {
            element.insert({top: columnNameHtml});
        }
    },

    checkSyncStatus: function(statusElementId, url, onFinishCallback, randomId, options) {
        //list was reloaded - stop the check of sync status for old list elements
        if (this._randomId != randomId) {
            return;
        }

        var context = this;
        options = $H({
            timeout: 5000,
            progressStatus: 'started'
        }).merge($H(options));
        new Ajax.Request(url, {
            method: 'get',
            parameters: {},
            onSuccess: function(transport) {
                var result = transport.responseText.evalJSON();
                var statusElement = $(statusElementId);
                if (!statusElement) {
                    return;
                }
                if (options.get('progressStatus') == result.status) {
                    setTimeout(function(){
                        context.checkSyncStatus(statusElementId, url, onFinishCallback, randomId, options);
                    }, options.get('timeout'));
                } else {
                    onFinishCallback(statusElement, result);
                }
            }
        });
    },

    _getOperations: function() {
        var operations = this._operations || [];
        if (!this._additionalData || !this._additionalData.operations || !this._additionalData.operations.length) {
            return operations;
        }
        var deleteButtonIndex = this._getDeleteButtonIndex();
        var args = [deleteButtonIndex, 0];
        if (deleteButtonIndex !== 0 && operations[deleteButtonIndex - 1].componentType !== 'Jsw.bar.Separator') {
            args.push({componentType: 'Jsw.bar.Separator'});
        }
        args = args.concat(this._additionalData.operations);
        if (deleteButtonIndex !== operations.length) {
            args.push({componentType: 'Jsw.bar.Separator'});
        }
        operations.splice.apply(operations, args);
        return operations;
    },

    _getDeleteButtonIndex: function() {
        if (!this._operations) {
            return 0;
        }
        var deleteButtonIndex = this._operations.length;
        this._operations.forEach(function(el, i) {
            if (el.addCls === 'sb-remove-selected') {
                deleteButtonIndex = i;
            }
        });
        return deleteButtonIndex;
    }
});

// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.DynamicSubForm = Class.create(Jsw.Component, {

    _initConfiguration: function($super, config) {
        $super(config);
        var getDynamicContent = this._getConfigParam('getDynamicContent', null);
        if (getDynamicContent) {
            this._getDynamicContent = getDynamicContent.bind(this);
        }
        var prepareDynamicContent = this._getConfigParam('prepareDynamicContent', null);
        if (prepareDynamicContent) {
            this._prepareDynamicContent = prepareDynamicContent.bind(this);
        }
        var bindDynamicContent = this._getConfigParam('bindDynamicContent', null);
        if (bindDynamicContent) {
            this._bindDynamicContent = bindDynamicContent.bind(this);
        }
        var insertDynamicContent = this._getConfigParam('insertDynamicContent', null);
        if (insertDynamicContent) {
            this._insertDynamicContent = insertDynamicContent.bind(this);
        }
        var onUpdateDynamic = this._getConfigParam('onUpdateDynamic', null);
        if (onUpdateDynamic) {
            this._onUpdateDynamic = onUpdateDynamic.bind(this);
        }
        var onInitDynamic = this._getConfigParam('onInitDynamic', null);
        if (onInitDynamic) {
            this._onInitDynamic = onInitDynamic.bind(this);
        }
    },

    _addEvents: function($super) {
        $super();
        var dynamicElements = this._componentElement.select('.dynamicSubFormContent');
        if (0 == dynamicElements.size()) {
            this._addEmptyContent();
        } else {
            dynamicElements.each(function(element, index) {
                this._bindDynamicContent(element, 0 == index);
            }, this);
        }
        this._onInitDynamic();
        this._onUpdateDynamic();
    },

    _addEmptyContent: function() {
        var element = this._prepareDynamicContent(this._getDynamicContent());
        this._insertDynamicContent(element);
        this._bindDynamicContent(element, true);
    },

    _getDynamicContent: function() {
        var dynamicElement = this._componentElement.down('.dynamicSubFormTemplate').cloneNode(true);
        dynamicElement.removeClassName('dynamicSubFormTemplate').addClassName('dynamicSubFormContent').show();
        return dynamicElement;
    },

    _prepareDynamicContent: function(content, value) {
        return content;
    },

    _insertDynamicContent: function(content) {
        var dynamicElements = this._componentElement.select('.dynamicSubFormContent');
        if (0 == dynamicElements.size()) {
            this._componentElement.insert({top : content});
        } else {
            dynamicElements.last().insert({after : content});
        }
    },

    _bindDynamicContent: function(content, isFirstElement) {
    },

    _onInitDynamic: function() {
    },

    _onUpdateDynamic: function() {
    },

    deleteContent: function(content) {
        content.remove();
        this._onUpdateDynamic();
    },

    addContent: function(value) {
        var content = this._prepareDynamicContent(this._getDynamicContent(), value);
        this._insertDynamicContent(content);
        this._bindDynamicContent(content, false);
        this._onUpdateDynamic();
    }

});

Jsw.AddRemoveDynamicSubForm = Class.create(Jsw.DynamicSubForm, {
    _initConfiguration: function($super, config) {
        $super(config);
        this._addButtonId = this._getConfigParam('addButtonId', '');
        this._addButtonTitle = this._getConfigParam('addButtonTitle', '');
        this._removeButtonId = this._getConfigParam('removeButtonId', '');
        this._removeButtonTitle = this._getConfigParam('removeButtonTitle', '');
    },

    _onInitDynamic: function() {
        $(this._addButtonId).replace('<div id="' + this._addButtonId + '" class="text-value"></div>');
        new Jsw.SmallButton({
            id: 'dynamicSubFormContentAddButton-' + this._id,
            title: this._addButtonTitle,
            addCls: 'sb-item-add dynamicSubFormContentAddButton',
            handler: this.addContent.bind(this),
            disabled: this._isAddButtonDisabled(),
            renderTo: this._addButtonId
        });
    },

    _isAddButtonDisabled: function() {
        return false;
    },

    _bindDynamicContent: function(content, isFirstElement) {
        if (!isFirstElement) {
            var wrapperId = this._initRemoveButtonWrapper(content);
            new Jsw.SmallButton({
                id: wrapperId,
                title: this._removeButtonTitle,
                addCls: 'sb-item-remove dynamicSubFormContentRemoveButton',
                handler: this.deleteContent.bind(this, content),
                renderTo: wrapperId
            });
        }
        return content;
    },

    _initRemoveButtonWrapper: function(content) {
        var wrapperId = this._removeButtonId + '-' + this._getRandomNumber();
        content.select('.field-value input, .field-value select').last().insert({
            after: '<span id="' + wrapperId + '" class="' + this._removeButtonId + '"></span>'
        });
        return wrapperId;
    },

    _prepareDynamicContent : function(content) {
        var newId = Math.floor(1000000*Math.random());

        var nameRegExp = new RegExp("(name=.*?\\[" + this._id + "\\]\\[)dynamicSubFormTemplate(\\])", "g");
        var idRegExp = new RegExp("(id=.*?\\-" + this._id + "-)dynamicSubFormTemplate(-)", "g");

        content = content.update(content.innerHTML
            .replace(nameRegExp, '\$1c' + newId +'\$2')
            .replace(idRegExp, '\$1c' + newId +'\$2')
        );

        return content;
    },

    _onUpdateDynamic: function() {
        var childs = this._componentElement.select('.dynamicSubFormContent');
        if (0 < childs.size()) {
            childs.each(function(child, i) {
                if (0 == i) {
                    child.select('label').last().show();
                } else {
                    child.select('label').last().hide();
                }
            });
            $$('label[for="' + this._addButtonId + '"]').first().hide();
        } else {
            $$('label[for="' + this._addButtonId + '"]').first().show();
        }
    },

    addContent: function($super, event) {
        $super();
        Event.stop(event);
    },

    deleteContent: function($super, content, event) {
        $super(content);
        Event.stop(event);
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.Box = Class.create(Jsw.Component, {
    _tag: 'div',

    _initConfiguration: function($super, config) {
        $super(config);
    },

    _initComponentElement: function($super) {
        $super();

        this._componentElement.update(
            this._getConfigParam('html', '')
        );
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.Gauge = Class.create(Jsw.Component, {
    _tag: 'span',

    _initConfiguration: function($super, config) {
        $super(config);
        this._cls = this._getConfigParam('cls', 'gauge-wrapper f9 not_empty');
    },

    _initComponentElement: function($super) {
        $super();

        this.setProgress(this._getConfigParam('value', ''));
    },

    setProgress: function(value)
    {
        this._componentElement.update(
            '<span class="gauge-container">' +
                '<span style="width: ' + value + '%" class="gauge-filled"></span>' +
            '</span>'
        );
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.Cookie = {
    get: function(name) {
        var cookies = document.cookie.split("; ");
        for (var i = 0; i < cookies.length; i++) {
            var crumbs = cookies[i].split("=");
            if (name == crumbs[0]) {
               return unescape(crumbs[1]);
            }
        }
        return null;
    },

    set: function(name, value, expires, path) {
        var cookie = name + "=" + escape(value) + "; ";

        if (('undefined' != typeof expires) && expires) {
            cookie += 'expires=' + expires + '; '
        }

        if (('undefined' != typeof path) && path) {
            cookie += "path=" + path + '; ';
        }

        document.cookie = cookie;
    },

    setPermanent: function(name, value, path) {
        var date = new Date();
        date.setTime(date.getTime()+(365*24*60*60*1000));
        var expires = date.toGMTString();
        this.set(name, value, expires, path);
    },

    remove: function(name, path) {
        var cookie = name + "=; expires=Fri, 31 Dec 1999 23:59:59 GMT;";

        if (('undefined' != typeof path) && path) {
            cookie += "path=" + path + '; ';
        }

        document.cookie = cookie;
    }
};
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.Tooltip = {
    showTimeoutStatus: true,    //show timeout
    showTimeout: 0.55,            //show timeout
    minDelta: 5,                //minimum viewport delta
    xOffsetLeft: -5,            //horisonatl offset from cursor
    xOffsetRight: 5,            //horisonatl offset from cursor
    yOffsetTop: 1,                //vertical offset from cursor
    yOffsetBottom: 13,            //vertical offset from cursor

    current: null,

    initData: function(contentElement) {
        var elements;

        if ('undefined' != typeof contentElement) {
            elements = contentElement.select('.tooltipData');
        } else {
            elements = $$('.tooltipData');
        }

        elements.each(function(tooltipData) {
            Jsw.Tooltip.init(tooltipData.parentNode, {element: tooltipData});
        });
    },

    init: function(element, config) {
        return new Jsw.Tooltip.Instance(element, config);
    },

    set: function(tooltip) {
        if (Jsw.Tooltip.current && Jsw.Tooltip.current !== tooltip) {
            Jsw.Tooltip.hide();
        }
        if (Jsw.Tooltip.current === tooltip) {
            return;
        }
        Jsw.Tooltip.current = tooltip;
        Element.observe(tooltip._element, 'mousemove', Jsw.Tooltip._onMouseMove);
        Element.observe(tooltip._element, 'mouseout', Jsw.Tooltip._onMouseOut);

        Jsw.Tooltip.show();
    },

    show: function() {
        Jsw.Tooltip.showCancel();
        Jsw.Tooltip.hideCancel();
        if (Jsw.Tooltip.showTimeoutStatus) {
            Jsw.Tooltip.showTask = new PeriodicalExecuter(Jsw.Tooltip.showFinish, Jsw.Tooltip.showTimeout);
        } else {
            Jsw.Tooltip.showFinish();
        }
    },

    showCancel: function() {
        if (Jsw.Tooltip.showTask) {
            Jsw.Tooltip.showTask.stop();
            Jsw.Tooltip.showTask = null;
        }
    },

    showFinish: function() {
        Jsw.Tooltip.showCancel();
        var tooltipElement = Jsw.Tooltip._fetchTooltipElement();
        var tooltip = Jsw.Tooltip.current;
        if (tooltip._config.text) {
            tooltipElement.down('span').update(tooltip._config.text);
        } else
        if(tooltip._config.element) {
            tooltipElement.down('span').update(tooltip._config.element.innerHTML);
        }
        tooltipElement.show();
        Jsw.Tooltip.update();
    },

    hide: function() {
        Jsw.Tooltip.showCancel();
        if (!Jsw.Tooltip.current)
            return;
        var tooltip = Jsw.Tooltip.current;
        Jsw.Tooltip.current = null;
        var tooltipElement = Jsw.Tooltip._fetchTooltipElement();
        tooltipElement.hide();
        Element.stopObserving(tooltip._element, 'mousemove', Jsw.Tooltip._onMouseMove);
        Element.stopObserving(tooltip._element, 'mouseout', Jsw.Tooltip._onMouseOut);
        Jsw.Tooltip.hideTask = new PeriodicalExecuter(Jsw.Tooltip.hideFinish, Jsw.Tooltip.showTimeout);
    },

    hideCancel: function() {
        if (Jsw.Tooltip.hideTask) {
            Jsw.Tooltip.hideTask.stop();
            Jsw.Tooltip.hideTask = null;
        }
    },

    hideFinish: function() {
        Jsw.Tooltip.showTimeoutStatus = true;
    },

    update: function() {
        if (!Jsw.Tooltip.current)
            return;
        var tooltipElement = Jsw.Tooltip._fetchTooltipElement();
        var position = Jsw.Tooltip._fetchTooltipPosition(tooltipElement);
        Element.setStyle(tooltipElement, {
            top: position.y + 'px',
            left: position.x + 'px'
        });
    },

    _onMouseOut: function(event) {
        Jsw.Tooltip.hide();
    },

    _onMouseMove: function(event) {
        Jsw.Tooltip.tooltipX = Event.pointerX(event);
        Jsw.Tooltip.tooltipY = Event.pointerY(event);
        Jsw.Tooltip.update();
    },

    _fetchTooltipElement: function() {
        if (!Jsw.Tooltip._tooltipElement) {
            Jsw.Tooltip._tooltipElement = $$('.tooltip').first();
        }

        return Jsw.Tooltip._tooltipElement;
    },

    _fetchTooltipPosition: function(tooltipElement) {
        var x = Jsw.Tooltip.tooltipX;
        var y = Jsw.Tooltip.tooltipY;

        var tDim = Element.getDimensions(tooltipElement);
        var vDim = document.viewport.getDimensions();
        var vScr = document.viewport.getScrollOffsets();

        var freeRight = vDim.width + vScr.left - Jsw.Tooltip.tooltipX;
        var freeLeft = Jsw.Tooltip.tooltipX - vScr.left;
        var freeTop = Jsw.Tooltip.tooltipY - vScr.top;
        var freeBottom = vDim.height + vScr.top - Jsw.Tooltip.tooltipY;

        //apply better x
        if( freeRight > tDim.width + Jsw.Tooltip.minDelta + Jsw.Tooltip.xOffsetRight) {
            x = Jsw.Tooltip.tooltipX + Jsw.Tooltip.xOffsetRight;
        } else
        if( freeLeft > tDim.width + Jsw.Tooltip.minDelta + Jsw.Tooltip.xOffsetLeft) {
            x = Jsw.Tooltip.tooltipX - tDim.width - Jsw.Tooltip.xOffsetLeft;
        } else {
            x = Jsw.Tooltip.tooltipX - (tDim.width + Jsw.Tooltip.xOffsetLeft) / 2;
        }

        //apply better y
        if (freeBottom > tDim.height + Jsw.Tooltip.minDelta + Jsw.Tooltip.yOffsetBottom) {
            y = Jsw.Tooltip.tooltipY + Jsw.Tooltip.yOffsetBottom;
        } else
        if( freeTop > tDim.height + Jsw.Tooltip.minDelta + Jsw.Tooltip.yOffsetTop) {
            y = Jsw.Tooltip.tooltipY - tDim.height - Jsw.Tooltip.yOffsetTop;
        } else {
            y = Jsw.Tooltip.tooltipY - (tDim.height + Jsw.Tooltip.yOffsetTop) / 2;
        }
        if (x < 0) {
            x = Jsw.Tooltip.minDelta;
        }

        return { x: x, y: y };
    }

};

Event.observe(window, 'load', function() {
    Jsw.Tooltip.initData();
});

Jsw.Tooltip.Instance = Class.create({

    initialize: function(element, config) {
        this._element = element;
        this._config = config;
        //observe events
        Event.stopObserving(this._element, 'mouseover');
        Event.observe(this._element, 'mouseover', this.set.bind(this));
    },

    set: function() {
        Jsw.Tooltip.set(this);
    },

    setText: function(text) {
        this._config.text = text;
    }
});

Jsw.AjaxTooltip = {
    windowId: 'ajaxTooltipWindow',
    delay: 0.55,
    _isInitialized: false,
    _currentTooltip: null,

    _init: function(cls) {
        if (this._isInitialized) {
            return ;
        }

        this._cls = cls;
        this._initWindowElement();
        this._initWindowEvents();
        this._isInitialized = true;
    },

    _initWindowElement: function($super) {
        $(document.body).insert({
            top: '<div id="' + this.windowId + '" class="' + this._cls + '" style="display: none; z-index: 10000"></div>'
        });

        $(this.windowId).update(
            '<table cellspacing="0" class="popup-wrapper"><tbody><tr><td class="popup-container">' +
                '<div class="c1"><div class="c2"><div class="c3"><div class="c4"><div class="c5">' +
                    '<div class="popup-heading">' +
                        '<div class="heading-area">' +
                            '<span class="arrow"></span>' +
                            '<span class="close" id="' + this.windowId + '-close' + '"></span>' +
                            '<h4><span id="' + this.windowId + '-title' + '"></span></h4>' +
                        '</div>' +
                    '</div>' +
                    '<div class="popup-content">' +
                        '<div id="' + this.windowId + '-content' + '" class="popup-content-area"></div>' +
                    '</div>' +
                '</div></div></div></div></div>' +
            '</td></tr></tbody></table>'
        ).setStyle({marginTop: 0}); // TODO Need remove this hack when all popup boxes will use AjaxTooltip component and hardcoded offset will be removed in css
    },

    _initWindowEvents: function() {
        $(this.windowId).observe('mouseover', this._onWindowMouseOver.bind(this));
        $(this.windowId).observe('mouseout', this._onWindowMouseOut.bind(this));
        $(this.windowId + '-close').observe('click', this._onCloseClick.bind(this));
        $(document.body).observe('click', this._onCloseClick.bind(this));
        $(this.windowId).observe('click', function (event) {
            event.stopPropagation();
        });
    },

    _onWindowMouseOver: function() {
        this._showWindow();
    },

    _onWindowMouseOut: function() {
        if (this._currentTooltip.getPlacement() === '') {
            $(this.windowId).hide();
        }
    },

    _onCloseClick: function() {
        $(this.windowId).hide();
    },

    set: function(tooltip) {
        this._init(tooltip.getCls());
        var title = tooltip.getTitle();
        var titleElement = $(this.windowId + '-title');
        if (false === title) {
            $(this.windowId + '-title').update('');
            titleElement.up('.popup-heading').hide();
        } else {
            $(this.windowId + '-title').update(title);
            titleElement.up('.popup-heading').show();
        }
        $w('left right top bottom').each(function (className){
            $(this.windowId).removeClassName(className);
        }, this);
        $(this.windowId).addClassName(tooltip.getPlacement());
        $(this.windowId).down('.heading-area .arrow').toggle(['left', 'right', 'bottom'].indexOf(tooltip.getPlacement()) != -1);
        this._currentTooltip = tooltip;
        this.updateContent(tooltip);
        this._showWindow(tooltip);
    },

    isSet: function (tooltip) {
        var element = $(this.windowId);
        return element && element.visible() && this._currentTooltip == tooltip;
    },

    unset: function () {
        var element = $(this.windowId);
        if (element) {
            element.hide();
        }
    },

    updateContent: function(tooltip) {
        if (this._currentTooltip == tooltip) {
            $(this.windowId + '-content').update(
                (tooltip.getPlacement() == 'top' ? '<span class="arrow"></span>' : '') +
                tooltip.getContent()
            );
        }
        this._updatePosition();
    },

    _showWindow: function() {
        $(this.windowId).show();
        this._updatePosition();
    },

    _updatePosition: function()
    {
        var element = $(this.windowId),
            elementWidth = element.getWidth(),
            elementHeight = element.getHeight(),
            headingElementHeight = element.down('.heading-area').getHeight(),
            tooltipElement = this._currentTooltip.getTargetElement(),
            tooltipElementHeight = tooltipElement.getHeight(),
            tooltipElementWidth = tooltipElement.getWidth(),
            offsetLeft = document.viewport.getScrollOffsets().left,
            offsetTop = document.viewport.getScrollOffsets().top,
            elementRight = tooltipElement.cumulativeOffset().left + elementWidth,
            viewportRight = document.viewport.getWidth() + document.viewport.getScrollOffsets().left;

        switch (this._currentTooltip.getPlacement()) {
            case 'top':
                offsetTop -= elementHeight;
                offsetLeft -= (elementWidth - tooltipElementWidth) / 2;
                break;
            case 'bottom':
                offsetTop += tooltipElementHeight;
                offsetLeft -= (elementWidth - tooltipElementWidth) / 2;
                break;
            case 'left':
                offsetTop -= (headingElementHeight - tooltipElementHeight) / 2;
                offsetLeft -= elementWidth;
                break;
            case 'right':
                offsetTop -= (headingElementHeight - tooltipElementHeight) / 2;
                offsetLeft += tooltipElementWidth;
                break;
        }
        if (elementRight + offsetLeft > viewportRight) {
            offsetLeft -= elementRight + offsetLeft - viewportRight + 10;
        }

        Jsw.clonePosition(element, tooltipElement, {offsetLeft: offsetLeft, offsetTop: offsetTop, setWidth: false, setHeight: false });
    }
};

Jsw.AjaxTooltip.Instance = Class.create(Jsw.Component, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._targetElement = $(this._getConfigParam('target', ''));
        this._title = this._getConfigParam('title', '');
        this._waitMsg = this._getConfigParam('waitMsg', '');
        this._url = this._getConfigParam('url', '');
        this._cls = this._getConfigParam('cls', 'popup-box');
        this._placement = this._getConfigParam('placement', '');

        this._content = '<div class="ajax-loading">' + this._waitMsg + '</div>';
        this._contentLoaded = false;
        this._delayedExecuter = null;
    },

    _initComponentElement: function($super) {
        this._initTargetEvents();
    },

    _initTargetEvents: function() {
        if (this._placement !== '') {
            this._targetElement.observe('click', function (event) {
                event.stop();
                if (Jsw.AjaxTooltip.isSet(this)) {
                    Jsw.AjaxTooltip.unset();
                } else {
                    Jsw.AjaxTooltip.set(this);
                }
            }.bind(this));
        } else {
            this._targetElement.observe('mouseover', this.set.bind(this));
            this._targetElement.observe('mouseout', this.unset.bind(this));
        }
    },

    _loadContent: function() {
        var context = this;
        new Ajax.Request(Jsw.prepareUrl(this._url), {
            method: 'get',
            onSuccess: function(transport) {
                if ('' == transport.responseText) {
                    return;
                }

                context._content = transport.responseText;
                Jsw.AjaxTooltip.updateContent(context);
            }
        });

        this._contentLoaded = true;
    },

    setText: function(text)
    {
        this._contentLoaded = true;
        this._content = text;
    },

    set: function() {
        var context = this;
        this._delayedExecuter = new PeriodicalExecuter(function(pe) {
            Jsw.AjaxTooltip.set(context);
            pe.stop();
            this._delayedExecuter = null;
        }, Jsw.AjaxTooltip.delay);
    },

    unset: function() {
        if (this._delayedExecuter) {
            this._delayedExecuter.stop();
            this._delayedExecuter = null;
        }
    },

    getTitle: function() {
        return this._title;
    },

    getContent: function() {
        if (!this._contentLoaded) {
            this._loadContent();
        }

        return this._content;
    },

    getTargetElement: function() {
        return this._targetElement;
    },

    getCls: function() {
        return this._cls;
    },

    getPlacement: function() {
        return this._placement;
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.ModalDialogBox = Class.create(Jsw.Component, {
    _initConfiguration: function($super, config) {
        $super(config);

        this._screenDisablerId = this._getConfigParam('screenDisablerId', 'screenDisabler');

        if (!$(this._screenDisablerId)) {
            $(document.body).insert({
                top: '<div id="' + this._screenDisablerId + '" class="main-disabled-block" style="display: none;"></div>'
            });
        }

        this._screenDisabler = $(this._screenDisablerId);

        this._renderTargetId = this._getConfigParam('renderTo', 'modalDialogBox');

        if ($(this._renderTargetId)) {
            $(this._renderTargetId).remove();
        }

        this._screenDisabler.insert({ after: '<div id="' + this._renderTargetId + '"></div>' });
    },

    _makeCentered: function() {
        var windowElement = this._componentElement.down();
        var viewportTopOffset = document.viewport.getScrollOffsets().top;
        var windowTopOffset = document.viewport.getHeight() / 2 - windowElement.getHeight() / 2;

        if (windowTopOffset > 0) {
            windowElement.setStyle({ top: (viewportTopOffset + windowTopOffset) + 'px' });
        }
    },

    show: function($super) {
        this._screenDisabler.show();
        $super();
        this._makeCentered();
    },

    hide: function($super) {
        $super();

        this._screenDisabler.hide();
    }

});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.PopupForm = Class.create(Jsw.ModalDialogBox, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._popupContentAreaId = this._id + '-popup-content-area';
        this._titleAreaId = this._id + '-title-area';
        this._hintAreaId = this._id + '-hint-area';
        this._hint1AreaId = this._id + '-hint1-area';
        this._boxAreaId = this._id + '-box-area';
        this._contentAreaId = this._id + '-content-area';

        this._actionButtonsId = this._id + '-action-buttons';
        this._leftActionButtonsAreaId = this._id + '-left-action-buttons-area';
        this._rightActionButtonsAreaId = this._id + '-right-action-buttons-area';

        this._titleCls = this._getConfigParam('titleCls', '');
        this._isRemoved = false;
    },

    _initComponentElement: function($super) {
        $super();
        this._updateComponentElement(
            '<table class="popup-wrapper" cellspacing="0"><tbody><tr><td class="popup-container">' +
                '<div class="c1"><div class="c2"><div class="c3"><div class="c4"><div class="c5">' +
                    '<div class="popup-heading">' +
                        '<div class="heading-area">' +
                            '<h2 class="' + this._titleCls + '"><span id="' + this._titleAreaId + '">' +
                                this._getConfigParam('title', '') +
                            '</span></h2>' +
                        '</div>' +
                    '</div>'+
                    '<div class="popup-content">' +
                        '<div class="popup-content-area" id="' + this._popupContentAreaId + '">' +
                            this._getContentArea() +
                        '</div>' +
                    '</div>' +
                '</div></div></div></div></div>' +
            '</td></tr><tr/></tbody></table>'
        );
        this._screenDisabler.show();
        this._makeCentered();
    },

    _getContentArea: function() {
        return '' +
            '<p id="' + this._hint1AreaId + '"></p>' +
            '<span id="' + this._hintAreaId + '"></span>' +
            this._getBoxArea() +
            this._getButtonsArea();
    },

    _getBoxArea: function() {
        return '' +
            '<div class="form-box" id="' + this._boxAreaId + '">' +
                '<div class="box-area">' +
                    '<div class="content">' +
                        '<div class="content-area" id="' + this._contentAreaId + '">' +
                        '</div>' +
                    '</div>' +
                '</div>' +
            '</div>';
    },

    _getButtonsArea: function() {
        return '' +
            '<div class="btns-box" id="' + this._actionButtonsId + '">' +
                '<div class="box-area">' +
                    '<div class="form-row">' +
                        '<div class="field-name" id="' + this._leftActionButtonsAreaId + '"> </div>' +
                        '<div class="field-value" id="' + this._rightActionButtonsAreaId + '"> </div>' +
                    '</div>' +
                '</div>' +
            '</div>';
    },

    _makeCentered: function() {
        var viewportTopOffset = document.viewport.getScrollOffsets().top;
        this._componentElement.setStyle({ top: (viewportTopOffset + 110) + 'px' });
    },

    setBoxType: function(type) {
        $(this._boxAreaId).className = type;
        if ('list-box' == type) {
            $(this._actionButtonsId).addClassName('no-separator');
            $(this._actionButtonsId).addClassName('simple-box');
        }
        if ('form-box' == type) {
            $(this._actionButtonsId).removeClassName('no-separator');
            $(this._actionButtonsId).removeClassName('simple-box');
        }
        if ('fm-box' == type) {
            $(this._boxAreaId).className = 'list-box';
            $(this._actionButtonsId).addClassName('no-separator');
        }
    },

    setTitleType: function(cls) {
        $(this._titleAreaId).parentNode.className = cls;
    },

    setTitle: function(text) {
        $(this._titleAreaId).update(text);
    },

    setHint: function(text) {
        if ('' == text) {
            $(this._hintAreaId).hide();
        } else {
            $(this._hintAreaId).update(text);
            $(this._hintAreaId).show();
        }
    },

    setHint1: function(text) {
        if ('' == text) {
            $(this._hint1AreaId).hide();
        } else {
            $(this._hint1AreaId).update(text);
            $(this._hint1AreaId).show();
        }
    },

    remove: function() {
        this._isRemoved = true;
        $(this._renderTargetId).remove();
    },

    addRightButton: function(title, handler, isDefault, isAction, params) {
        var button = this._createButton(title, handler, isDefault, isAction, params);
        $(this._rightActionButtonsAreaId).insert(button);
        return button;
    },

    addLeftButton: function(title, handler, isDefault, isAction, params) {
        var button = this._createButton(title, handler, isDefault, isAction, params);
        $(this._leftActionButtonsAreaId).insert(button);
        return button;
    },

    removeRightButtons: function() {
        $(this._rightActionButtonsAreaId).update(' ');
    },

    removeLeftButtons: function() {
        $(this._leftActionButtonsAreaId).update(' ');
    },

    resizeList: function() {
        if (this._isRemoved) {
            return;
        }

        var minHeigh = 150;
        var list = $(this._contentAreaId).down('table');
        var listContainer = $(this._contentAreaId).down('.list');

        var bodyHeight = (Prototype.Browser.IE)
            ? $(document.documentElement).getHeight()
            : $(document.body).getHeight();

        var buttonsHeight = $(this._actionButtonsId).getHeight();
        var top = Position.cumulativeOffset(list)[1];
        var height = list.getHeight();
        var newHeight = bodyHeight - top - buttonsHeight - 100; // 100px below dialog

        if (newHeight > height) {
            listContainer.style.height = '';
            listContainer.removeClassName('with-scroll');
            return;
        }

        if (newHeight < minHeigh) {
            newHeight = minHeigh;
        }

        listContainer.style.height = newHeight + 'px';
        listContainer.style.overflowY = 'auto';
        listContainer.style.overflowX = 'hidden';
        listContainer.addClassName('with-scroll');
    },

    _createButton: function(title, handler, isDefault, isAction, params) {
        params = (typeof params !== 'undefined') ? params : {};

        var buttonContainer = new Element('span', params);
        buttonContainer.addClassName('btn');
        if (isAction) {
            buttonContainer.addClassName('action');
        }

        buttonContainer.update(
            '<button value="" type="' + (isDefault ? 'submit' : 'button') + '">' +
                title +
            '</button>'
        );
        buttonContainer.down('button').observe(
            'click',
            this._onClick.bindAsEventListener(this, handler.bind(this))
        );

        return buttonContainer;
    },

    _updateButton: function(element, config) {
        $H(config).each(function(pair) {
            switch (pair.key) {
            case 'title':
                element.down('button').update(pair.value);
                break;
            case 'disabled':
                element.down('button').disabled = pair.value ? true : false;
                pair.value ? Element.addClassName(element, 'disabled')
                           : Element.removeClassName(element, 'disabled');
                break;
            }
        });
    },

    _onClick: function(event, handler) {
        Event.stop(event);
        handler(event);
    },

    _addEvents: function($super) {
        $super();

        if ($(this._hintAreaId)) {
            $(this._hintAreaId).hide();
        }
        if ($(this._hint1AreaId)) {
            $(this._hint1AreaId).hide();
        }
    },

    _clearMessages: function() {
        var contentElement = $(this._popupContentAreaId);

        ['.msg-error', '.msg-info', '.msg-warning'].each(function(msgClass) {
            contentElement.select(msgClass).each(function(messageElement) {
                messageElement.remove();
            });
        });
    },

    _addErrorMessage: function(message) {
        this._addStatusMessage('error', message);
    },

    _addStatusMessage: function(status, message) {
        $(this._popupContentAreaId).insert(
            {
                top:
                    '<div class="msg-box msg-' + status + '">' +
                        '<div>' +
                            '<div>' +
                                '<div>' +
                                    '<div>' +
                                        '<div>' +
                                            '<div class="msg-content">' +
                                                message +
                                            '</div>' +
                                        '</div>' +
                                    '</div>' +
                                '</div>' +
                            '</div>' +
                        '</div>' +
                    '</div>'
            }
        );
    },

    _userError: function(error) {
        Jsw.clearStatusMessages();
        Jsw.addStatusMessage('error', error);
        this._close();
    },

    _internalError: function(error) {
        Jsw.clearStatusMessages();
        Jsw.addStatusMessage('error', 'Internal error: ' + error);
        this._close();
    }

});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.AjaxPopupForm = Class.create(Jsw.PopupForm, {
    _initConfiguration: function($super, config) {
        $super(config);

        this._url = this._getConfigParam('url');
    },

    _initComponentElement: function($super) {
        $super();

        this._componentElement.down('.popup-content-area').update('<div class="ajax-loading">' + this.lmsg('waitMsg') + '</div>');
        new Ajax.Request(Jsw.prepareUrl(this._url), {
            method: 'get',
            onSuccess: function(transport) {
                this._componentElement.down('.popup-content-area').update(transport.responseText);
                (function () {
                    this._componentElement.down('form').writeAttribute('action', Jsw.prepareUrl(this._url));
                    var cancelBtn = Jsw.getComponent('btn-cancel');
                    cancelBtn.removeEventObserver('click', cancelBtn._handler);
                    cancelBtn._handler = function () {
                        this.hide();
                    }.bind(this);
                    cancelBtn.addEventObserver('click', cancelBtn._handler);
                }).bind(this).defer();
            }.bind(this)
        });
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.messageBox = {

    TYPE_OK: 'TYPE_OK',
    TYPE_YESNO: 'TYPE_YESNO',

    _messageBox: null,

    show: function(config) {
        if (!Jsw.messageBox._messageBox) {
            Jsw.messageBox._messageBox = config.isAjax ? new Jsw.AjaxMessageBox(config) : new Jsw.MessageBox(config);
        } else {
            Jsw.messageBox._messageBox.initialize(config);
        }

        Jsw.messageBox._messageBox.show();
    }
};

Jsw.MessageBox = Class.create(Jsw.ModalDialogBox, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._type = this._getConfigParam('type', Jsw.messageBox.TYPE_YESNO);
        this._text = this._getConfigParam('text', '');
        this._subtype = this._getConfigParam('subtype', null);
        this._description = this._getConfigParam('description', '');
        this._descriptionWrapperTag = this._getConfigParam('descriptionWrapperTag', 'p');
        this._buttonTitles = this._getConfigParam('buttonTitles', null);

        this._onYesClick = this._getConfigParam('onYesClick', null);
        this._onNoClick = this._getConfigParam('onNoClick', null);
        this._onOkClick = this._getConfigParam('onOkClick', null);
        this._needAttention = this._getConfigParam('needAttention', false);
        this._needAttentionText = this._getConfigParam('needAttentionText', '');
        this._needAttentionBlockSubmit = this._getConfigParam('needAttentionBlockSubmit', false);

        if (Jsw.messageBox.TYPE_YESNO == this._type) {
           if (this._onYesClick) {
               this._onYesClickHandler = this._onYesClick.bindAsEventListener(this);
           } else {
               this._onYesClickHandler = this._defaultOnButtonClick.bindAsEventListener(this);
           }
        }
    },

    _getDescriptionCode: function() {
        var descriptionCode = '';
        if (Object.isArray(this._description)) {
            this._description.each(function(item) {
                descriptionCode += '<' + this._descriptionWrapperTag + '>' + item + '</' + this._descriptionWrapperTag +'>';
            })
        } else {
            descriptionCode += '<' + this._descriptionWrapperTag + '>' + this._description + '</' + this._descriptionWrapperTag + '>';
        }
        return descriptionCode;
    },

    _getNeedAttentionCode: function() {
        var needAttentionCode = '';
        if (this._needAttention) {
           needAttentionCode = '<hr>';
           if (this._needAttentionBlockSubmit) {
               needAttentionCode += '<p><span class="b-indent"><span class="b-indent-icon"><input type="checkbox" class="checkbox" id="needAttentionConfirmationCheckbox"></span><label for="needAttentionConfirmationCheckbox">' + this._needAttentionText + '</label></span></p>';
           } else {
               needAttentionCode += '<p class="hint-warning">' + this._needAttentionText + '</p>';
           }
           needAttentionCode += '<hr>';
        }
        return needAttentionCode;
    },

    _initComponentElement: function($super) {
        $super();

        var descriptionCode = this._getDescriptionCode();
        var needAttentionCode = this._getNeedAttentionCode();

        var contentHtml =
            '<div class="confirmation-box">' +
                '<table cellspacing="0"><tr><td>' +
                    '<div class="c1"><div class="c2"><div class="c3"><div class="c4"><div class="c5">' +
                        '<div class="confirmation-msg' + (this._subtype ? ' mw-' + this._subtype : '') + '">' +
                            '<h3>' + this._text + '</h3>' +
                            descriptionCode + needAttentionCode +
                            '<div class="btns-container">';

        if (Jsw.messageBox.TYPE_YESNO == this._type) {
            var buttonDefault = this._getConfigParam('buttonDefault', 'no');
            contentHtml += '<span class="btn' + ('yes' == buttonDefault ? ' action' : '') + '"><button type="submit" value="">' + this._buttonTitles.yes + '</button></span>';
            contentHtml += '<span class="btn' + ('no' == buttonDefault ? ' action' : '') + '"><button type="submit" value="">' + this._buttonTitles.no + '</button></span>';
        }

        if (Jsw.messageBox.TYPE_OK == this._type) {
            contentHtml += '<span class="btn action"><button type="submit" value="">' + this._buttonTitles.ok + '</button></span>';
        }

        contentHtml +=      '</div>' +
                        '</div>' +
                    '</div></div></div></div></div>' +
                '</td></tr></table>' +
            '</div>';

        this._updateComponentElement(contentHtml);

        this._componentElement.hide();
    },

    _disableYesButton: function() {
        if (Jsw.messageBox.TYPE_YESNO == this._type) {
            this._componentElement.select('.btn').first().addClassName('disabled');
            var buttonYes = this._componentElement.select('button').first();
            buttonYes.disable();
            Event.stopObserving(buttonYes, 'click', this._onYesClickHandler);
        }
    },

    _enableYesButton: function(button) {
        if (Jsw.messageBox.TYPE_YESNO == this._type) {
           this._componentElement.select('.btn').first().removeClassName('disabled');
           var buttonYes = this._componentElement.select('button').first();
           buttonYes.enable();
           Event.observe(buttonYes, 'click', this._onYesClickHandler);
        }
    },

    _addEvents: function($super) {
        $super();

        // add default behavior - hide dialog
        this._componentElement.select('button').each(function(button) {
            Event.observe(button, 'click', this._defaultOnButtonClick.bindAsEventListener(this));
        }, this);

        if (Jsw.messageBox.TYPE_YESNO == this._type) {
            if (this._onYesClick) {
                var buttonYes = this._componentElement.select('button').first();
                Event.observe(buttonYes, 'click', this._onYesClickHandler);
            }

            if (this._onNoClick) {
                var buttonNo = this._componentElement.select('button').last();
                Event.observe(buttonNo, 'click', this._onNoClick.bindAsEventListener(this));
            }

           if (this._needAttention && this._needAttentionBlockSubmit) {
                var confirmationCheckbox = this._componentElement.select('input').last();
                var top = this;
                Event.observe(confirmationCheckbox, 'click',
                              function() { if ($F(confirmationCheckbox)) {top._enableYesButton()} else {top._disableYesButton()}} );
           }
        }

        if (Jsw.messageBox.TYPE_OK == this._type) {
            if (this._onOkClick) {
                var buttonOk = this._componentElement.select('button').first();
                Event.observe(buttonOk, 'click', this._onOkClick.bindAsEventListener(this));
            }
        }
    },

    _addTooltips: function() {
    },

    _defaultOnButtonClick: function() {
        this.hide();
    },

    show: function($super) {
        $super();
        this._componentElement.select('.action').first().select('button').first().focus();
        if (this._needAttention && this._needAttentionBlockSubmit) {
           this._disableYesButton();
        }
    }

});

Jsw.AjaxMessageBox = Class.create(Jsw.MessageBox, {
    _initConfiguration: function($super, config) {
        $super(config);
        this._requestUrl = this._getConfigParam('requestUrl', '');
        this._requestMethod = this._getConfigParam('requestMethod', 'post');
        this._requestParams = this._getConfigParam('requestParams', '');
        this._contentContainerId = this._getConfigParam('contentContainerId', this._id + 'contentContainer');
        this._confirmationCheckboxId = this._getConfigParam('confirmationCheckboxId', this._id + 'confirmationCheckbox');
        this._loadingTitle = this._getConfigParam('loadingTitle', '');
    },

    _getDescriptionCode: function() {
        return '';
    },

    _getNeedAttentionCode: function($super) {
        var needAttentionCode = $super();
        return '<div id="' + this._contentContainerId + '"></div>' + needAttentionCode;
    },

    _initComponentElement: function($super) {
        $super();
    },

    _showSpinner: function() {
        if (Jsw.messageBox.TYPE_YESNO == this._type) {
            this._componentElement.select('button').first().update('<span class="wait">' + this._buttonTitles.wait + '</span>');
        }
    },

    _hideSpinner: function(button) {
        if (Jsw.messageBox.TYPE_YESNO == this._type) {
            this._componentElement.select('button').first().update(this._buttonTitles.yes);
        }
    },

    show: function($super) {
        $super();
        if (!this._requestUrl) {
            return;
        }

        new Ajax.Request(Jsw.prepareUrl(this._requestUrl), {
            method: this._requestMethod,
            parameters: this._requestParams,
            onCreate: this._onCreate.bind(this),
            onSuccess: this._onSuccess.bind(this),
            onFailure: this._onFailure.bind(this)
        });
    },

    _onCreate: function() {
        this._disableYesButton();
        this._showSpinner();
    },

    _onSuccess: function(transport) {
        this._hideSpinner();

        var result = transport.responseText.evalJSON();

        var content = result.content;
        var contentCode = '';
        if (Object.isArray(content)) {
            if (content.length > 0) {
                contentCode = '<ul class="ul">';
                content.each(function(item) {
                    contentCode += '<li>' + item + '</li>';
                })
                contentCode += '</ul>';
            }
        } else {
            contentCode = content;
        }

        var descriptionCode = '';
        if (result.description) {
            descriptionCode = '<p><span class="hint-warning">' + result.description + '</span></p>';
        }

        var confirmationCode = '';
        if (result.confirmation) {
            confirmationCode = '<p><span class="b-indent">' +
                '<span class="b-indent-icon">' +
                    '<input type="checkbox" class="checkbox" id="' + this._confirmationCheckboxId + '"/>' +
                '</span>' +
                '<label for="' + this._confirmationCheckboxId + '">' + result.confirmation + '</label>' +
            '</span></p>';
        }

        $(this._contentContainerId).update('' + contentCode + descriptionCode + confirmationCode + '');

        var checkboxes = this._componentElement.select('input[type="checkbox"]');
        var top = this;
        checkboxes.each(function(checkbox) {
            Event.stopObserving(checkbox, 'click');
            Event.observe(checkbox, 'click',
                function() {
                    var enableYesButton = true;
                    top._componentElement.select('input[type="checkbox"]').each(function(confirmationCheckbox) {
                        if (!$F(confirmationCheckbox)) {
                            enableYesButton = false;
                        }
                    });
                    if (enableYesButton) {
                        top._enableYesButton()
                    } else {
                        top._disableYesButton()}
                }
            );
        });

        if (0 == checkboxes.length) {
            this._enableYesButton();
        }
    },

    _onFailure: function() {
        this._hideSpinner();
        this._enableYesButton();
    }

});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.Popup = Class.create(Jsw.ModalDialogBox, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._popupContentAreaId = this._id + '-popup-content-area';
        this._titleAreaId = this._id + '-title-area';
        this._actionButtonsId = this._id + '-action-buttons'
        this._rightActionButtonsAreaId = this._id + '-right-action-buttons-area';

        this._contentHeight = this._getConfigParam('contentHeight', null);
        this._closeButtonEnabled = this._getConfigParam('closeButtonEnabled', false);
        this._popupCls = this._getConfigParam('popupCls', 'popup-panel');
        this._titleCls = this._getConfigParam('titleCls', '');
        this._buttons = this._getConfigParam('buttons', []);
        this._onShow = this._getConfigParam('onShow', function(){});
    },

    _initComponentElement: function($super) {
        $super();
        var closeButton = '';
        if (this._closeButtonEnabled) {
            closeButton = '<span class="close" id="' + this._id + '-close"></span>';
        }
        var contentExtraStyle = '';
        if (this._contentHeight) {
            contentExtraStyle = ' style="height:' + this._contentHeight + 'px"';
        }
        this._updateComponentElement(
            '<div class="' + this._popupCls + '"><table class="popup-wrapper" cellspacing="0"><tbody><tr><td class="popup-container">' +
                '<div class="c1"><div class="c2"><div class="c3"><div class="c4"><div class="c5">' +
                    '<div class="popup-heading">' +
                        '<div class="heading-area">' +
                            closeButton +
                            '<h2 class="' + this._titleCls + '"><span id="' + this._titleAreaId + '">' +
                                this._getConfigParam('title', '') +
                            '</span></h2>' +
                        '</div>' +
                    '</div>'+
                    '<div class="popup-content">' +
                        '<div class="popup-content-area" id="' + this._popupContentAreaId + '"' + contentExtraStyle + '>' +
                            this._getContentArea() +
                        '</div>' +
                    '</div>' +
                '</div></div></div></div></div>' +
            '</td></tr><tr/></tbody></table></div>'
        );
    },

    _getContentArea: function() {
        var buttonsArea = '';
        if (this._buttons.size() > 0) {
            buttonsArea = this._getButtonsArea();
        }
        return '' +
            '<form>' +
                this._getConfigParam('content', '') +
                buttonsArea +
            '</form>';
    },

    _getButtonsArea: function() {
        return '' +
            '<div class="btns-box" id="' + this._actionButtonsId + '">' +
                '<div class="box-area">' +
                    '<div class="form-row">' +
                        '<div class="single-row">' +
                            '<div class="field-value" id="' + this._rightActionButtonsAreaId + '"> </div>' +
                        '</div>' +
                    '</div>' +
                '</div>' +
            '</div>';
    },

    _addEvents: function($super) {
        $super();

        var context = this;

        this._buttons.each(function(buttonDesc) {
            var buttonId = '';
            if ('undefined' != typeof buttonDesc['id']) {
                buttonId = ' id="' + buttonDesc['id'] + '" ';
            }
            if ('undefined' == typeof buttonDesc['class']) {
                buttonDesc['class'] = '';
            }
            var buttonDisabled = '';
            if ('undefined' != typeof buttonDesc['disabled'] && buttonDesc['disabled']) {
                buttonDisabled = 'disabled="disabled"';
            }
            var buttonContainer = new Element('span', { 'class': 'btn ' + buttonDesc['class'] });
            buttonContainer.update('<button ' + buttonId + ' value="" type="button" ' + buttonDisabled + '>' + buttonDesc['title'] + '</button>');
            buttonContainer.down('button').observe(
                'click',
                buttonDesc['handler'].bindAsEventListener(this, context)
            );
            $(context._rightActionButtonsAreaId).insert(buttonContainer);
        });

        if (this._closeButtonEnabled) {
            Event.observe($(this._id + '-close'), 'click', this._onCloseClick.bindAsEventListener(this));
        }

        this.show();
    },

    _onCloseClick: function() {
        this.hide();
    },

    show: function($super) {
        $super();
        this._onShow();
    }

});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.DoubleListSelector = Class.create(Jsw.Component, {
    _initConfiguration: function($super, config) {
        $super(config);
        this._cls = 'doubleListSelect';
        this._name = this._getConfigParam('name', '');
        this._list = this._getConfigParam('list', $A());
        this._dataUrl = this._getConfigParam('dataUrl', null);
        this._selectedMarked = 0;
        this._unselectedMarked = 0;
        this._prevSelectedItem = -1;
        this._isSearchable = this._getConfigParam('isSearchable', false);
        this._isLarge = this._getConfigParam('isLarge', false);
    },

    _initList: function() {
        var elements = {};
        this._list.each(function(element, index) {
            element.marked = false;
            if ('undefined' === typeof element.selected) {
                element.selected = false;
            }

            this._initListItem(element, index, true);
            this._initListItem(element, index, false);
            elements[element.id] = element.selected;
        }, this);
        this._initInputElement(elements);
    },

    _initComponentElement: function() {
        this._componentElement = $(this._applyTargetId);
        this._componentElement.addClassName('double-list-select');
        this._componentElement.addClassName('dls-icons-1');
        if (this._isLarge) {
            this._componentElement.addClassName('dls-large');
        }

        var searchControlUnselected = this._isSearchable ? this._getSearchControl('unselected') : '';
        var searchControlSelected = this._isSearchable ? this._getSearchControl('selected') : '';
        var ajaxLoading = null === this._dataUrl ? ''
            : '<div class="ajax-loading" style="display: none;">' + this._locale.loadingTitle + '</div>';

        var listHtml =
            '<div class="dls-first-box">' +
                searchControlUnselected +
                '<h4><span>' + this._locale.unselectedTitle + '</span></h4>' +
                '<div  id="' + this._id + '-container-unselected" class="dls-box-area">' + ajaxLoading + '<ul id="' + this._id + '-unselected"></ul></div>' +
            '</div>' +
            '<div class="dls-second-box">' +
                 searchControlSelected +
                '<h4><span>' + this._locale.selectedTitle +'</span></h4>' +
                '<div id="' + this._id + '-container-selected" class="dls-box-area">' + ajaxLoading + '<ul id="' + this._id + '-selected"></ul></div>' +
            '</div>' +
            '<div id="' + this._id + '-controls" class="dls-controls">' +
                '<span id="' + this._id + '-controls-select" class="btn disabled">' +
                    '<button type="button" id="'+ this._id +'-submitSelect" onclick="return false;"><span class="dls-add">&gt;&gt;</span></button>' +
                '</span>' +
                '<span id="' + this._id + '-controls-unselect" class="btn disabled">' +
                    '<button type="button" id="'+ this._id +'-submitUnselect" onclick="return false;"><span class="dls-remove">&lt;&lt;</span></button>' +
                '</span>' +
            '</div>';

        this._updateComponentElement(listHtml);
        this._initList();
    },

    _initListItem: function(element, index, isSelected) {
        var container = null;
        var isHidden = false;
        if (isSelected) {
            container = $(this._id + '-selected');
            isHidden = !element.selected;
        } else {
            container = $(this._id + '-unselected');
            isHidden = element.selected;
        }

        var item = new Element('div', {
            'class': 'dls-item-block'
        })
        .insert('<b>' + element.title.escapeHTML() + '</b>');

        if (element.description) {
            item.insert('<span>' + element.description + '</span>');
        }

        if (element.icons && element.icons.length) {
            var itemIcons = new Element('span', {
                'class': 'dls-icons'
            });

            element.icons.each(function(icon) {
                itemIcons
                .insert('<i class="icon"><img src="' + Jsw.skinUrl + icon.src + '" title="' + icon.title + '"></i>');
            }, this);

            item.insert(itemIcons);
        }

        var listItem = new Element('li', {
            'id': this._id + '-' + index + '-' + (isSelected ? 'selected' : 'unselected') + '-item'
        })
        .insert(item);


        container.insert(listItem);
        var context = this;
        listItem.observe('click', function(event) {
            context._toggleItem(index, isSelected, event);
        });
        if (isHidden) {
            listItem.hide();
        }
    },

    _initInputElement: function(elements) {
        var inputElement = $(this._id + '-elements');
        if (!inputElement) {
            inputElement = new Element('input', {
                'id': this._id + '-elements',
                'name': this._name,
                'type': 'hidden'
            });
            this._componentElement.insert(inputElement);
        }
        inputElement.setValue(JSON.stringify(elements));
    },

    _getSearchControl: function(columnId) {
        var html =
            '<div class="dls-search">' +
                '<input id="' + this._id + '-search-' + columnId + '" class="search-input search-empty" type="text" autocomplete="off"' +
                    ' value="' + this._locale.searchTitle + '"' +
                    ' onfocus="Jsw.getComponent(\'' + this._id + '\').onFocus(this)"' +
                    ' onblur="Jsw.getComponent(\'' + this._id + '\').onBlur(this)"' +
                    ' onkeyup="Jsw.getComponent(\'' + this._id + '\').onToggleSearch(\'' + columnId + '\', this.value);">' +
                '<span id="' + this._id + '-search-button-' + columnId + '" class="search-button icon-search"' +
                    ' onmousedown="Jsw.getComponent(\'' + this._id + '\').onResetSearch(\'' + columnId + '\');">' +
                '</span>' +
            '</div>';
        return html;
    },

    _addEvents: function() {
        $(this._id + '-controls-select').observe('click', this._onSubmitSelect.bind(this));
        $(this._id + '-controls-unselect').observe('click', this._onSubmitUnselect.bind(this));
    },

    _toggleItem: function(index, isSelected, event) {
        if (this._list[index].marked) {
            this._unmarkItem(index, isSelected, event);
        } else {
            this._markItem(index, isSelected, event);
        }
    },

    _markItem: function(index, isSelected, event) {
        if (('undefined' != typeof event) && event.shiftKey && (-1 != this._prevSelectedItem)) {
            var startIndex = Math.min(index, this._prevSelectedItem);
            var finishIndex= Math.max(index, this._prevSelectedItem);
            for (i = startIndex; i < finishIndex; i++) {
                this._markItem(i, isSelected);
            }
        }

        this._prevSelectedItem = index;

        this._list[index].marked = true;
        $(this._id + '-' + index + '-' + (isSelected ? 'selected' : 'unselected') + '-item').addClassName('marked');
        this._updateSelectControls(isSelected, true);
    },

    _unmarkItem: function(index, isSelected, event) {
        this._list[index].marked = false;
        $(this._id + '-' + index + '-' + (isSelected ? 'selected' : 'unselected') + '-item').removeClassName('marked');
        this._updateSelectControls(isSelected, false);
    },

    _onSubmitSelect: function() {
        this._list.each(function(element, index) {
            if (element.marked && !element.selected && $(this._id + '-' + index + '-unselected-item').visible()) {
                this._unmarkItem(index, false);
                element.selected = true;
                this._updateElement(element);
                $(this._id + '-' + index + '-unselected-item').hide();
                $(this._id + '-' + index + '-selected-item').show();
            }
        }, this);

        this.onChange();
    },

    _onSubmitUnselect: function() {
        this._list.each(function(element, index) {
            if (element.marked && element.selected && $(this._id + '-' + index + '-selected-item').visible()) {
                this._unmarkItem(index, true);
                element.selected = false;
                this._updateElement(element);
                $(this._id + '-' + index + '-selected-item').hide();
                $(this._id + '-' + index + '-unselected-item').show();
            }
        }, this);

        this.onChange();
    },

    _updateElement: function(element) {
        var elements = JSON.parse($(this._id + '-elements').value);
        elements[element.id] = element.selected;
        $(this._id + '-elements').value = JSON.stringify(elements);
    },

    onChange: function() {},

    onToggleSearch: function(columnId, searchString) {
        var isSelected = (columnId === 'selected');
        searchString = searchString.strip().toLowerCase();

        if (searchString.length) {
            this._toggleSearchButtonIcon(columnId, true);
            this._list.each(function(element, index) {
                if (isSelected !== element.selected) {
                    return;
                }
                var item = $(this._id + '-' + index + '-' + columnId + '-item');
                if (this._isSearchMatched(element, searchString)) {
                    if (!item.visible() && element.marked) {
                        this._updateSelectControls(isSelected, true);
                    }
                    item.show();
                } else {
                    if (item.visible() && element.marked) {
                        this._updateSelectControls(isSelected, false);
                    }
                    item.hide();
                }
            }, this);
        } else {
            this._toggleSearchButtonIcon(columnId, false);
            this._showAllItems(columnId);
        }
    },

    _isSearchMatched: function(element, searchString) {
        var searchIndex = 'undefined' === typeof element.searchIndex
            ? element.title
            : element.searchIndex;

        return -1 !== searchIndex.toLowerCase().indexOf(searchString);
    },

    onFocus: function(element) {
        if (this._locale.searchTitle === element.value) {
            element.value = '';
            element.removeClassName('search-empty');
        }
    },

    onBlur: function(element) {
        if ('' === element.value) {
            this._resetSearchControl(element);
        }
    },

    onResetSearch: function(columnId) {
        this._showAllItems(columnId);
        var element = $(this._id + '-search-' + columnId);
        this._resetSearchControl(element);
        this._toggleSearchButtonIcon(columnId, false);
    },

    _showAllItems: function(columnId) {
        var isSelected = (columnId === 'selected');
        this._list.each(function(element, index) {
            if (isSelected === element.selected) {
                var item = $(this._id + '-' + index + '-' + columnId + '-item');
                if (!item.visible() && element.marked) {
                    this._updateSelectControls(isSelected, true);
                }
                item.show();
            }
        }, this);
    },

    _resetSearchControl: function(element) {
        element.value = this._locale.searchTitle;
        element.addClassName('search-empty');
    },

    _toggleSearchButtonIcon: function(columnId, isActive) {
        $(this._id + '-search-button-' + columnId).toggleClassName('search-button-clear', isActive);
    },

    _updateSelectControls: function(isSelected, setMarked) {
        var counter = isSelected ? this._selectedMarked : this._unselectedMarked;
        var controlId = isSelected ? 'unselect' : 'select';

        setMarked ? counter++ : counter--;
        $(this._id + '-controls-' + controlId).toggleClassName('disabled', !counter);

        if (isSelected) {
            this._selectedMarked = counter;
        } else {
            this._unselectedMarked = counter;
        }
    },

    isEmpty: function() {
        return !this._list.any(function(element) { return element.selected; });
    },

    reload: function(params) {
        params = params || '';
        if (!this._dataUrl) {
            return;
        }

        new Ajax.Request(Jsw.prepareUrl(this._dataUrl + params), {
            method: 'get',
            onSuccess: this._onReloadSuccess.bind(this),
            onFailure: this._onReloadFailure.bind(this),
            onException: this._onReloadException.bind(this),
            onCreate: this._onReloadCreate.bind(this),
            onComplete: this._onReloadComplete.bind(this)
        });
    },

    _onReloadSuccess: function(transport) {
        if (!transport.responseText) {
            //:INFO: sometimes happens in FF if you are go to other page during request
            return;
        }

        try {
            var data = transport.responseText.evalJSON();
        } catch (e) {
            Jsw.showInternalError(transport.responseText);
            return;
        }

        if (data.list) {
            this._list = $A(data.list);
        } else if (data.status) {
            Jsw.clearStatusMessages();
            $A(data.statusMessages).each(function(message) {
                Jsw.addStatusMessage(message.status, message.content);
            }.bind(this));
        } else {
            Jsw.showInternalError('Unable to load list data.');
        }

        this._initList();
    },

    _onReloadFailure: function(transport) {
        Jsw.showInternalError(transport.responseText);
    },

    _onReloadException: function(transport, exception) {
        Jsw.showInternalError(exception + "\n" + transport.responseText);
    },

    _onReloadCreate: function(transport) {
        this._list = $A();
        this._componentElement.select('.dls-box-area').each(function(listArea) {
            listArea.select('ul').first().update();
            listArea.select('.ajax-loading').first().show();
        });
    },

    _onReloadComplete: function() {
        this._componentElement.select('.dls-box-area').each(function(listArea) {
            listArea.select('.ajax-loading').first().hide();
        });
    }
});

// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.EnhancedDoubleListSelector = Class.create(Jsw.DoubleListSelector, {
    _initComponentElement: function() {
        this._componentElement = $(this._applyTargetId);
        this._componentElement.addClassName('edls');

        var searchControlUnselected = this._isSearchable ? this._getSearchControl('unselected') : '';
        var searchControlSelected = this._isSearchable ? this._getSearchControl('selected') : '';

        var listHtml = '' +
            '<div class="edls-wrap">' +
                '<div class="edls-box edls-box-first">' +
                    '<div class="edls-header">' +
                        '<div class="edls-header-title">' + this._locale.unselectedTitle + '</div>' +
                    '</div>' +
                    '<div class="edls-box-wrap">' +
                        searchControlUnselected +
                        '<div class="edls-box-body">' +
                            '<ul class="edls-list" id="' + this._id + '-unselected"></ul>' +
                            '<div class="edls-list-empty" style="display: none;"><span>' + this._locale.unselectedEmpty + '</span></div>' +
                            '<div class="edls-ajax-loading" style="display: none;"><span class="ajax-loading">' + this._locale.loadingTitle + '</span></div>' +
                        '</div>' +
                    '</div>' +
                '</div>' +
                '<div class="edls-control">' +
                    '<div class="edls-control-wrap">' +
                        '<div class="edls-control-body">' +
                            '<div class="edls-control-text">' +
                                '<div class="edls-control-text-none">' + this._locale.controlTextNone + '</div>' +
                                '<div class="edls-control-text-first">' +
                                    this._locale.controlTextFirst.replace('%checked%', '<b>' + this._locale.controlChecked.replace('%count%', '<span class="edls-count">0</span>') + '</b>') +
                                '</div>' +
                                '<div class="edls-control-text-second">' +
                                    this._locale.controlTextSecond.replace('%checked%', '<b>' + this._locale.controlChecked.replace('%count%', '<span class="edls-count">0</span>') + '</b>') +
                                '</div>' +
                            '</div>' +
                            '<div class="edls-control-indicator"><i></i></div>' +
                        '</div>' +
                    '</div>' +
                '</div>' +
                '<div class="edls-box edls-box-second">' +
                    '<div class="edls-header">' +
                        '<div class="edls-header-title">' + this._locale.selectedTitle + '</div>' +
                    '</div>' +
                    '<div class="edls-box-wrap">' +
                        searchControlSelected +
                        '<div class="edls-box-body">' +
                            '<ul class="edls-list" id="' + this._id + '-selected"></ul>' +
                            '<div class="edls-list-empty" style="display: none;"><span>' + this._locale.selectedEmpty + '</span></div>' +
                            '<div class="edls-ajax-loading" style="display: none;"><span class="ajax-loading">' + this._locale.loadingTitle + '</span></div>' +
                        '</div>' +
                    '</div>' +
                '</div>' +
            '</div>';

        this._updateComponentElement(listHtml);
        this._initList();
    },

    _initList: function($super) {
        $super();

        this._fixListZebra();
    },

    _fixListZebra: function() {
        [$(this._id + '-unselected'), $(this._id + '-selected')].each(function(list) {
            var count = 0;
            list.select('.edls-item').each(function(el) {
                if (el.visible()) {
                    el.addClassName(count % 2 ? 'odd' : 'even');
                    el.removeClassName(count % 2 ? 'even' : 'odd');
                    count++;
                }
            });
            list.next('.edls-list-empty')[count ? 'hide' : 'show']();
        });
    },

    _getSearchControl: function(columnId) {
        var html =
            '<div class="edls-search">' +
                '<span class="edls-check"><input type="checkbox" value="" class="checkbox"></span>' +
                '<span class="edls-search-control">' +
                    '<input type="text" value="" autocomplete="off" class="search-input search-empty"' +
                        ' id="' + this._id + '-search-' + columnId + '"' +
                        ' onfocus="Jsw.getComponent(\'' + this._id + '\').onFocus(this)"' +
                        ' onblur="Jsw.getComponent(\'' + this._id + '\').onBlur(this)"' +
                        ' onkeyup="Jsw.getComponent(\'' + this._id + '\').onToggleSearch(\'' + columnId + '\', this.value);"' +
                        '>' +
                    '<input type="image" src="' + Jsw.skinUrl + '/images/search-input.png" class="search-button"' +
                        ' id="' + this._id + '-search-button-' + columnId + '"' +
                        ' onmousedown="Jsw.getComponent(\'' + this._id + '\').onResetSearch(\'' + columnId + '\');"' +
                        ' onclick="return false;"' +
                        '>' +
                '</span>' +
            '</div>';

        return html;
    },

    _toggleSearchButtonIcon: function(columnId, isActive) {
        var inputIcon = $(this._id + '-search-button-' + columnId);
        inputIcon.toggleClassName('search-button-clear', isActive);
        inputIcon.src = (isActive)
            ? Jsw.skinUrl + '/images/clear-search.png'
            : Jsw.skinUrl + '/images/search-input.png';
    },

    onFocus: function(element) {
        element.removeClassName('search-empty');
    },

    _resetSearchControl: function(element) {
        element.value = '';
        element.addClassName('search-empty');
    },

    _initListItem: function(element, index, isSelected) {
        var container = null;
        var isHidden = false;
        if (isSelected) {
            container = $(this._id + '-selected');
            isHidden = !element.selected;
        } else {
            container = $(this._id + '-unselected');
            isHidden = element.selected;
        }

        var itemCheckbox = new Element('input', {
            'type': 'checkbox',
            'class': 'checkbox',
            'value': ''
        });

        var item = new Element('div', {
            'class': 'edls-item-wrap'
        })
        .insert(new Element('span', {'class': 'edls-check'}).insert(itemCheckbox))
        .insert('<span class="edls-text">' + this._getItemText(element) + '</span>');

        var listItem = new Element('li', {
            'id': this._id + '-' + index + '-' + (isSelected ? 'selected' : 'unselected') + '-item',
            'class': 'edls-item'
        })
        .insert(item);

        container.insert(listItem);
        var context = this;
        listItem.observe('click', function(event) {
            context._toggleItemSelection(index, isSelected, event);
        });
        itemCheckbox.observe('click', function(event) {
            event.stopPropagation();
            context._toggleItemCheckbox(itemCheckbox, itemCheckbox.checked);
        });
        if (isHidden) {
            listItem.hide();
        }
    },

    _getItemText: function(element, highlight) {
        var itemIcons = '';
        if (element.icons && element.icons.length) {
            element.icons.each(function(icon) {
                itemIcons += '<i class="icon"><img src="' + Jsw.skinUrl + icon.src + '" title="' + icon.title + '"></i>';
            });
            itemIcons += ' ';
        }
        var itemText = element.title.escapeHTML();
        if (highlight) {
            var resultPos = itemText.indexOf(highlight);
            if (resultPos !== -1) {
                itemText = itemText.substr(0, resultPos) +
                    '<b class="search-result-label">' +
                        itemText.substr(resultPos, highlight.length) +
                    '</b>' +
                    itemText.substr(resultPos + highlight.length);
            }
        }

        return itemIcons + itemText;
    },

    onToggleSearch: function(columnId, searchString) {
        var isSelected = (columnId === 'selected');
        searchString = searchString.strip().toLowerCase();

        if (searchString.length) {
            this._toggleSearchButtonIcon(columnId, true);
            this._list.each(function(element, index) {
                var item = $(this._id + '-' + index + '-' + columnId + '-item');
                if (this._isSearchMatched(element, searchString)) {
                    item.down('.edls-text').update(this._getItemText(element, searchString));
                    if (isSelected === element.selected) {
                        item.show();
                    }
                } else {
                    item.down('.edls-text').update(this._getItemText(element));
                    var checkbox = item.down('.edls-check input');
                    if (item.visible() && checkbox.checked) {
                        this._toggleItemCheckbox(checkbox, false);
                    }
                    item.hide();
                }
            }, this);
        } else {
            this._toggleSearchButtonIcon(columnId, false);
            this._showAllItems(columnId);
        }
    },

    _showAllItems: function(columnId) {
        var isSelected = (columnId === 'selected');
        this._list.each(function(element, index) {
            var item = $(this._id + '-' + index + '-' + columnId + '-item');
            item.down('.edls-text').update(this._getItemText(element));
            if (isSelected === element.selected) {
                item.show();
            }
        }, this);
    },

    _toggleItemSelection: function(index, isSelected, event, batchMode) {
        event.preventDefault();
        this._list[index].selected = !isSelected;
        this._updateElement(this._list[index]);
        $(this._id + '-' + index + '-' + (isSelected ? 'selected' : 'unselected') + '-item').hide();
        $(this._id + '-' + index + '-' + (isSelected ? 'unselected' : 'selected') + '-item').show();
        this._toggleItemCheckbox($(this._id + '-' + index + '-' + (isSelected ? 'selected' : 'unselected') + '-item').down('.edls-check input'), false);
        if (!batchMode) {
            this._fixListZebra();
            this.onChange();
        }
    },

    _toggleItemCheckbox: function(checkbox, value) {
        checkbox.checked = value;

        var side = checkbox.up('.edls-box-first') ? 'first' : 'second';
        var count = checkbox.up('.edls-box-' + side).select('.edls-list .edls-check input:checked').length;
        if (value) {
            checkbox.up('.edls-item').addClassName('selected');
        } else {
            checkbox.up('.edls-item').removeClassName('selected');
            checkbox.up('.edls-box').down('.edls-search .checkbox').checked = false;
        }
        checkbox.up('.edls')[count ? 'addClassName' : 'removeClassName']('edls-selected-' + side);
        checkbox.up('.edls').down('.edls-control-text-' + side + ' .edls-count').update(count);
    },

    _updateSelectControls: function(isSelected, setMarked) {},

    _addEvents: function() {
        var context = this;
        var componentElement = this._componentElement;

        this._componentElement.select('.edls-box-wrap').each(function(el) {
            el.observe('mouseover', function() {
                componentElement.addClassName('edls-over');
                componentElement.addClassName(this.up('.edls-box-first') ? 'edls-over-first' : 'edls-over-second');
                componentElement.removeClassName(this.up('.edls-box-first') ? 'edls-over-second' : 'edls-over-first');
            });
            el.observe('mouseleave', function() {
                if (!componentElement.hasClassName('edls-selected-first') && !componentElement.hasClassName('edls-selected-second')) {
                    componentElement.removeClassName('edls-over');
                    componentElement.removeClassName('edls-over-first');
                    componentElement.removeClassName('edls-over-second');
                }
            });
        });

        this._componentElement.observe('mouseleave', function() {
            this.removeClassName('edls-over');
            this.removeClassName('edls-over-first');
            this.removeClassName('edls-over-second');
        });

        this._componentElement.select('.edls-box .edls-search .edls-check input').each(function(element) {
            element.observe('click', function() {
                var value = this.checked;
                this.up('.edls-box').select('.edls-list .edls-check input').each(function(checkbox) {
                    if (value && checkbox.up('.edls-item').visible()) {
                        context._toggleItemCheckbox(checkbox, true);
                    } else {
                        context._toggleItemCheckbox(checkbox, false);
                    }
                });
            });
        });

        this._componentElement.select('.edls-control-wrap').first().observe('click', function(event) {
            var isSelected;
            if (componentElement.hasClassName('edls-over-first')) {
                isSelected = false;
            } else if (componentElement.hasClassName('edls-over-second')) {
                isSelected = true;
            } else {
                return;
            }

            context._list.each(function(element, index) {
                if (element.selected === isSelected) {
                    var item = $(context._id + '-' + index + '-' + (isSelected ? 'selected' : 'unselected') + '-item');
                    if (item.hasClassName("selected")) {
                        context._toggleItemSelection(index, isSelected, event, true);
                    }
                }
            });
            context._fixListZebra();
            context.onChange();
        });
    },

    _onReloadCreate: function() {
        this._list = $A();
        this._componentElement.select('.edls-box').each(function(listArea) {
            listArea.select('ul').first().update();
            listArea.select('.edls-ajax-loading').first().show();
            listArea.select('.edls-list-empty').first().hide();
        });
    },

    _onReloadComplete: function() {
        this._componentElement.select('.edls-box').each(function(listArea) {
            listArea.select('.edls-ajax-loading').first().hide();
        });
    }
});

// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.ImageSelector = Class.create(Jsw.Component, {
    _initConfiguration: function($super, config) {
        $super(config);
        var list = this._getConfigParam('list', {});
        this._list = Object.isArray(list) ? $H() : $H(list);
        var captions = this._getConfigParam('captions', {});
        this._captions = Object.isArray(captions) ? $H() : $H(captions);
        this._name = this._getConfigParam('name', '');
        this._value = this._getConfigParam('value', null);

        this._currentId = this._id + '-current';
        this._listId = this._id + '-list';
    },

    _initComponentElement: function($super) {
        $super();

        this._updateComponentElement(
            '<div class="' + this._cls + '-area">' +
                '<div id="' + this._currentId + '" class="' + this._cls + '-current">' +
                    '<img/>' +
                    '<p>' + this._captions.get('selectedImage').escapeHTML() + '</p>' +
                '</div>' +
                '<div id="' + this._listId + '" class="' + this._cls + '-select clearfix"></div>' +
            '</div>'
        );

        this._valueElement = new Element('input', {
            'id': this._id + '-value',
            'name': this._name,
            'type': 'hidden',
            'value': null
        });

        this._componentElement.insert(this._valueElement);
    },

    _addEvents: function() {
        this._list.each(function(pair) {
            this._addImage(pair.key, pair.value);
        }, this);

        this.set(this._value);
    },

    _addImage: function(value, image) {
        this._componentElement.select('#' + this._listId).each(function(target) {
            var element = new Element('img', {
                'src': image.url,
                'alt': image.title
            });

            target.insert(element);

            element.observe('click', this._onImageClick.bindAsEventListener(this, value));
        }, this);
    },

    _onImageClick: function(event, value)
    {
        this.set(value);
    },

    set: function(value)
    {
        this._valueElement.value = value;
        var image = this._list.get(value);
        this._componentElement.select('#' + this._currentId + ' img').each(function(target) {
            if (image) {
                target.src = image.url;
                target.alt = image.title;
                target.show();
            } else {
                target.hide();
            }
        }, this);

    }

});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.ToolList = Class.create(Jsw.Container, {

    _initConfiguration: function($super, config) {
        $super(config);
        this._tools = this._getConfigParam('tools', null);
        this._cls = this._getConfigParam('cls', 'tools-list-box');
        this._contentAreaId = this._id + '-tools-list';

        if (Object.isArray(this._tools) && (0 == this._operations.size())) {
            this._operations = null;
        }
    },

    _initComponentElement: function($super) {
        $super();
        this._updateComponentElement(
            '<div id="' + this._id + '-box-area" class="box-area">' +
                '<div id="' + this._id + '-content" class="content">' +
                        '<div id="' + this._id + '-content-area" class="content-area">' +
                            '<ul id="' + this._id + '-tools-list" class="tools-list"></ul>' +
                        '</div>' +
                '</div>' +
            '</div>'
        );
    },

    render: function($super) {
        $super();
        Jsw.Tooltip.initData(this._componentElement);
    }
});

Jsw.toollist = {};

Jsw.toollist.Panel = Class.create(Jsw.Container, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._contentAreaId = this._id + '-tools-list';
        this._image = this._getConfigParam('image', '');
        this._title = this._getConfigParam('title', '');
    },

    _initComponentElement: function($super) {
        var attributes = { 'class': 'tools-item' };
        var forcedId = this._getConfigParam('id', null);
        if (forcedId) {
            attributes.id = forcedId;
        }

        this._componentElement = new Element('li', attributes);
        this._componentElement.update(new Element('div', {
                'class': 'tool-block'
            }).insert(
                '<span class="tool-icon">'+
                    '<img src="' + this._image + '"/>'+
                '</span>'+
                '<span class="tool-name">' + this._title + '</span>'
            ).insert(new Element('ul', {
                'id': this._id + '-tools-list',
                'class': 'tool-info' })
            )
        );
    }
});

Jsw.toollist.Item = Class.create(Jsw.Component, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._handler = this._getConfigParam('handler', false);
        if (Object.isString(this._handler)) {
            eval('this._handler = ' + this._handler);
        }
        this._href = this._getConfigParam('href', '#');
        this._target = this._getConfigParam('target', null);
        this._title = this._getConfigParam('title', '');
        this._description = this._getConfigParam('description', '');
        this._disabled = this._getConfigParam('disabled', false);
        this._attention = this._getConfigParam('attention', false);
    },

    _initComponentElement: function($super) {
        if (this._disabled) {
            href = '#';
        } else {
            href = this._href;
        }

        if (this._attention) {
            this._title = new Element('span', {
                'class': 'hint-attention'
            }).update(this._title);
        }

        this._componentElement = new Element('li', {
            'id': this._getConfigParam('id', null)
        }).update(new Element('a', {
            'href': href,
            'target': this._target
        }).update(this._title));

        if (this._handler && !this._disabled) {
            var handler = this._handler;
            this._componentElement.observe('click', function(e) {
                e.preventDefault();
                handler.call(this, e);
            });
        }
    }
});

Jsw.toollist.Button = Class.create(Jsw.Component, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._handler = this._getConfigParam('handler', false);
        if (Object.isString(this._handler)) {
            eval('this._handler = ' + this._handler);
        }
        this._href = this._getConfigParam('href', '#');
        this._target = this._getConfigParam('target', null);
        this._image = this._getConfigParam('image', '');
        this._disabledImage = this._getConfigParam('disabledImage', this._image);
        this._title = this._getConfigParam('title', '');
        this._description = this._getConfigParam('description', '');
        this._disabled = this._getConfigParam('disabled', false);
    },

    _initComponentElement: function($super) {
        var attributes = { 'class': 'tools-item' };
        var forcedId = this._getConfigParam('id', null);
        if (forcedId) {
            attributes.id = forcedId;
        }

        this._componentElement = new Element('li', attributes);

        cls = 'tool-block';
        if (this._disabled) {
            cls += ' tool-block-disabled';
            href = '#';
            image = this.getImagePath(this._disabledImage);
        } else {
            href = this._href;
            image = this.getImagePath(this._image);
        }
        this._componentElement.update(new Element('a', {
                'class': cls,
                'href': href,
                'target': this._target
            }).insert(
                '<span class="tool-icon">'+
                    '<img src="' + image + '"/>'+
                '</span>'+
                '<span class="tool-name">' + this._title + '</span>'+
                '<span class="tool-info">' + this._description + '</span>'
            )
        );

        if (this._handler && !this._disabled) {
            this._componentElement.observe('click', this._handler);
        }
    },

    _addTooltips: function() {
        // don't show tooltips, 'cause we've inline descriptions
    },

    getImagePath: function(path) {
         return Jsw.skinUrl + "/" + path;
    }
});

// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.CustomButton =  Class.create(Jsw.toollist.Button, {
    getImagePath: function(path) {
        return path;
    }
});

Object.extend(Form.Element.Methods, {
    disable: function(element) {
        element = $(element);
        element.disabled = 'disabled';
        element.addClassName('disabled');
        return element;
    },

    enable: function(element) {
        element = $(element);
        element.disabled = false;
        element.removeClassName('disabled');
        return element;
    }
});

Element.addMethods();
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.PasswordMeter = Class.create(Jsw.Component, {

    _initConfiguration: function($super, config) {
        $super(config);
        this._passwordElement = $(this._getConfigParam('observe', null));
        this._passwordElement.observe('keyup', this._onChange.bind(this));
        this._passwordElement.observe('plesk:passwordGenerated', this._onChange.bind(this));
        this._passwordElement.observe('blur', this._onBlur.bind(this));
        this._requiredStrength = this._getConfigParam('strength', -1);
        this._tag = 'span';
        this._cls = 'password-strength';
    },

    _initComponentElement: function($super) {
        $super();

        this._hintContainer = new Element('span', {cls: 'hint-inline hint-info'});
        this._hint = new Element('span');
        this._hint.insert('(?)');
        this._hintContainer.insert(this._hint);

        this._progress = new Element('i');
        this._componentElement.insert(this._progress);

        this._verdict = new Element('b');
        this._componentElement.insert(this._verdict);
    },

    render: function($super) {
        $super();

        if (!this._tooltip) {
            this._componentElement.insert({'after':this._hintContainer});
            this._tooltip = new Jsw.AjaxTooltip.Instance({
                    title: this._locale['title'],
                    waitMsg: '',
                    url: '',
                    target: this._hint
                });
        }
        this._onChange();
    },

    setProgress: function(value)
    {
        this._progress.writeAttribute('style', 'width: ' + value + '%');
    },

    _onBlur: function() {
        var password = this._passwordElement.value;
        if (!password.empty()) {
            var result = this._applyRules(password);
            this._updateError(result.score);
        }
    },

    _onChange: function() {
        var result = this._applyRules(this._passwordElement.value);
        this._updateVisibility();
        this._updateProgress(result.score);
        this._updateHint(result.unusedRules);
        this._updateVerdict(result.score);
        this._updateColor(result.score);
    },

    _updateVisibility: function() {
        if (this._passwordElement.value === '') {
            this._componentElement.hide();
            this._hintContainer.hide();
        } else {
            this._componentElement.show();
            this._hintContainer.show();
        }
    },

    _applyRules: function(passwd)
    {
        var unusedRules = new Array();
        var sum = 0;
        $H(this.rules).each(function(pair) {
            var mark = pair.value(passwd);
            if (mark < 0) {
                unusedRules.push({rule: pair.key, value: -mark});
            } else {
                sum += mark;
            }
        });
        return {score: sum, unusedRules: unusedRules};

    },

    _updateError: function(score)
    {
        var rowElement = this._passwordElement.up('.form-row');
        if (!rowElement) {
            return;
        }
        if (score <= this._requiredStrength) {
            rowElement.addClassName('error');
            var errorHint = '<span class="error-hint">' + this._locale['errorHint'] + '</span>';
            rowElement.down('.field-errors').update(errorHint);
            rowElement.down('.field-errors').show();
        } else {
            rowElement.removeClassName('error');
            rowElement.down('.field-errors').update();
            rowElement.down('.field-errors').hide();
        }
    },

    _verdictClasses: {
        verdictNone: 'verdictNone',
        verdictVeryWeak: 'password-strength-very-weak',
        verdictWeak: 'password-strength-weak',
        verdictMediocre: 'password-strength-medium',
        verdictStrong: 'password-strength-strong',
        verdictStronger: 'password-strength-very-strong'
    },

    _updateColor: function(score)
    {
        var verdict = this._getVerdict(score);
        var newClass = this._verdictClasses[verdict];
        if (this._oldClass == newClass ) {
            return;
        }
        if (this._oldClass) {
            this._componentElement.removeClassName(this._oldClass);
        }
        this._componentElement.addClassName(newClass);
        this._oldClass = newClass;
    },

    _updateHint: function(unusedRules)
    {
        var description = '';
        if (unusedRules.length) {
            description =  this._locale['description'] + '<br/><ul>'
            for(var i=0; i < unusedRules.length && i < 3; ++i) {
                description += "<li>" +  this._locale[unusedRules[i].rule] + "</li>";
            }
            description += "</ul>";
        } else {
            description += this._locale['yourPasswordIsStrong'];
        }

        this._tooltip.setText(description);
    },

    _updateVerdict: function(score)
    {
        this._verdict.update(this._locale[this._getVerdict(score)])
    },

    _updateProgress: function(score)
    {
        if (score > 45) {
            score = 45;
        }
        var value = ((score - 3) / 42) * 100;
        this.setProgress(value);
    },

    _getVerdict: function(score) {
        if(score < 1) {
            return "verdictNone"
        }
        else if(score < 16)
        {
           return "verdictVeryWeak"
        }
        else if (score > 15 && score < 25)
        {
            return "verdictWeak"
        }
        else if (score > 24 && score < 35)
        {
            return "verdictMediocre"
        }
        else if (score > 34 && score < 45)
        {
            return "verdictStrong"
        }
        return "verdictStronger"
    },

    rules: {
        passwordTooShort: function(passwd) {
            if (passwd.length<5) {
                return -1;
            }
            return 0;
        },
        passwordLength: function(passwd) {
            // PASSWORD LENGTH
            if (passwd.length<5)                         // length 4 or less
            {
                return 3;
            }
            else if (passwd.length>4 && passwd.length<8) // length between 5 and 7
            {
                return 6;
            }
            else if (passwd.length>7 && passwd.length<16)// length between 8 and 15
            {
                return 12;
            }
            else           // length 16 or more
            {
                return 18;
            }
            return -1;
        },
        lettersLowerCase: function(passwd) {
            if (passwd.match(/[a-z]/))                              // [verified] at least one lower case letter
            {
                return 1;
            }
            return -1;
        },
        lettersUpperCase: function(passwd) {
            if (passwd.match(/[A-Z]/))                              // [verified] at least one upper case letter
            {
                return 5;
            }
            return -1;
        },
        numbers1: function(passwd) {
            if (passwd.match(/\d+/))                                 // [verified] at least one number
            {
                return 5;
            }
            return -1;
        },
        numbers3: function (passwd) {
            if (passwd.match(/(.*[0-9].*[0-9].*[0-9])/))             // [verified] at least three numbers
            {
                return 5;
            }
            return -1;
        },
        specialChar1: function(passwd) {
            if (passwd.match(/[!@#$%^&*?_~]/))            // [verified] at least one special character
            {
                return 5;
            }
            return -1;
        },
        specialChar2: function(passwd) {
            // [verified] at least two special characters
            if (passwd.match(/(.*[!@#$%^&*?_~].*[!@#$%^&*?_~])/))
            {
                return 5;
            }
            return -1;
        },
        comboUpperAndLower: function(passwd) {
            if (passwd.match(/([a-z].*[A-Z])|([A-Z].*[a-z])/))        // [verified] both upper and lower case
            {
                return 2;
            }
            return -1;
        },
        comboLettersAndNumbers: function(passwd) {
            if (passwd.match(/([a-zA-Z])/) && passwd.match(/([0-9])/)) // [verified] both letters and numbers
            {
                return 2;
            }
            return -1;
        },
        comboLettersNumbersSpecial: function(passwd) {
            // [verified] letters, numbers, and special characters
            if (passwd.match(/([a-zA-Z0-9].*[!@#$%^&*?_~])|([!@#$%^&*?_~].*[a-zA-Z0-9])/))
            {
                return 2;
            }
            return -1;
        }
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.PasswordGenerator = Class.create(Jsw.Component, {

    _initConfiguration: function($super, config) {
        $super(config);
        this._passwordElement = $(this._getConfigParam('password', null));
        this._passwordConfirmationElement = $(this._getConfigParam('passwordConfirmation', null));
        this._generateButtonElement = $(this._getConfigParam('generateButton', null));
        this._generateButtonElement.observe('click', this._onGeneratePasswordClick.bind(this));
        this._showButtonElement = $(this._getConfigParam('showButton', null));
        this._showButtonElement.observe('click', this._onShowPasswordClick.bind(this));
        this._showPasswordVisible = true;
        this._showPasswordTitle = this._getConfigParam('showPasswordTitle', '');
        this._hidePasswordTitle = this._getConfigParam('hidePasswordTitle', '');
        this._passwordStrength = this._getConfigParam('passwordStrength', '');
        this._tag = 'span';
    },

    _onGeneratePasswordClick: function() {
        var password = this._generatePassword();
        this._passwordElement.value = password;
        if(this._passwordConfirmationElement) {
            this._passwordConfirmationElement.value = password;
        }
        this._passwordElement.fire('plesk:passwordGenerated');
    },

    _onShowPasswordClick: function() {
        if (this._showPasswordVisible) {
            try {
                this._passwordElement.writeAttribute('type', 'text');
            } catch (err) {
                // IE8 doesn't allow to change input type
            }
            if ('text' == this._passwordElement.type) {
                this._showButtonElement.down().update(this._hidePasswordTitle);
                this._showPasswordVisible = !this._showPasswordVisible;
            } else if (Prototype.Browser.IE && 'undefined' != typeof(prompt)) {
                var newPassword;
                if (newPassword = prompt('', this._passwordElement.value)) {
                    this._passwordElement.value = newPassword;
                    if(this._passwordConfirmationElement) {
                        this._passwordConfirmationElement.value = newPassword;
                    }
                }
            }
        } else {
            this._passwordElement.writeAttribute('type', 'password');
            this._showButtonElement.down().update(this._showPasswordTitle);
            this._showPasswordVisible = !this._showPasswordVisible;
        }
    },

    _symbolClasses: {
        upper: new ObjectRange('A', 'Z').entries(),
        lower: new ObjectRange('a', 'z').entries(),
        number: new ObjectRange('0', '9').entries(),
        special: "!@#$%^&*?_~"
    },

    _generatePassword: function() {
        var password = "";
        var symbolClasses = ['upper', 'lower', 'lower', 'lower', 'number', 'number', 'special', 'number'];

        if ('Stronger' == this._passwordStrength) {
            symbolClasses.push('upper', 'upper', 'lower', 'lower', 'lower', 'lower', 'lower', 'lower');
        }

        symbolClasses.sort(function(a, b) {
            return Math.floor(b.length * Math.random()) - Math.floor(a.length * Math.random());
        });
        symbolClasses.each(function(i) {
            password += this._generateSymbol(i);
        }, this);
        return password;
    },

    _generateSymbol: function(symbolClass) {
        var index = Math.floor(this._symbolClasses[symbolClass].length*Math.random());
        return this._symbolClasses[symbolClass][index];
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.Promo = Class.create(Jsw.Container, {
    _tag: 'div',

    _initConfiguration: function($super, config) {
        $super(config);
        this._title = this._getConfigParam('title', '');
        this._rows = this._getConfigParam('rows', 3);
        this._cls = this._getConfigParam('cls', 'p-box home-promo-block');
        this._contentAreaId = this._id + '-content-area';
        this._itemCount = 0;
        this._current = 0;
    },

    _initComponentElement: function($super) {
        $super();
        this._initLayout();
    },

    _initLayout: function() {
        this._componentElement.update(
                '<div class="p-box-tl"><div class="p-box-tr"><div class="p-box-tc"><!----></div></div></div>' +
                '<div class="p-box-ml"><div class="p-box-mr"><div class="p-box-mc">' +
                '<div class="p-box-header">' +
                  '<div class="p-box-header-wrap">' +
                    '<div class="p-box-header-wrap-inner">' +
                      '<div class="p-box-header-nav">' +
                        '<a class="link-01" id="' + this._id + '-prev" href="#"><span>' + this._locale.prev + '</span></a> ' +
                        '<a class="link-01" id="' + this._id + '-next" href="#"><span>' + this._locale.next + '</span></a>' +
                      '</div>' +
                      '<div class="p-box-header-text">' +
                        this._title +
                      '</div>' +
                    '</div>' +
                  '</div>' +
                '</div>' +
                '<div class="p-box-content">' +
                  '<ul class="tools-list" id="' + this._contentAreaId + '">' +
                  '</ul>' +
                '</div>' +
                '</div></div></div>' +
                '<div class="p-box-bl"><div class="p-box-br"><div class="p-box-bc"><!----></div></div></div>'
        );
    },

    _renderItems: function() {
        this._showCurrentItems();
    },

    _onHide: function(item) {
        for (var i=0; i < this._items.length; ++i) {
            if (this._items[i] == item) {
                this._items.splice(i, 1);
                break;
            }
        }

        this._showCurrentItems();
    },

    _addEvents: function() {
        $(this._id + '-next').observe('click', this._onNext.bind(this));
        $(this._id + '-prev').observe('click', this._onPrev.bind(this));
    },

    _onNext: function(event) {
        Event.stop(event);
        this._current += this._rows;
        this._showCurrentItems();
    },

    _onPrev: function(event) {
        Event.stop(event);
        this._current -= this._rows;
        this._showCurrentItems();
    },

    _clampCurrentItem: function () {
        if (this._items.length > this._rows) {
            $(this._id + '-prev').up('div').show();
            $(this._id + '-next').up('div').show();
        } else {
            $(this._id + '-next').up('div').hide();
            $(this._id + '-prev').up('div').hide();
        }

        if (this._current >= this._items.length) {
            this._current = 0;
        } else if (this._current < 0) {
            if (this._rows == 1) {
                this._current = this._items.length - 1;
            } else {
                this._current = this._items.length - this._items.length % this._rows;
            }
        }
    },

    _showCurrentItems: function() {
        if (this._items.length == 0) {
            this.hide();
            return;
        }

        this._clampCurrentItem();

        for (var i=0; i < this._items.length; ++i) {
            var item = this._items[i];
            item.setRenderTarget(this._contentAreaId);
            item.setHideHandler(this._onHide.bind(this));
            item.hide();
            if (i >= this._current && i < this._current + this._rows) {
                item.render();
                item.show();
            }
        }
    }
});


Jsw.Promo.Item = Class.create(Jsw.Component, {

    _tag: 'li',

    _initConfiguration: function($super, config) {
        $super(config);

        this._text = this._getConfigParam('text', '');
        this._title = this._getConfigParam('title', '');
        this._buttonUrl = this._getConfigParam('buttonUrl', '');
        this._buttonText = this._getConfigParam('buttonText', '');
        this._buttonTarget = this._getConfigParam('buttonTarget', '');
        this._hideUrl = this._getConfigParam('hideUrl', '');
        this._hideText = this._getConfigParam('hideText', '');
        this._iconUrl = this._getConfigParam('iconUrl', '');
        this._cls = "tools-item tools-item-active";
    },

    render: function($super) {
        this._componentElement.update(
            '<a class="tool-block" href="' + this._buttonUrl + '" target="' + this._buttonTarget + '">' +
                '<span class="tool-icon"><img src="' + this._iconUrl + '"></span>' +
                '<span class="tool-name">' + this._title.escapeHTML() + '</span>' +
                '<span class="tool-info">' + this._text.escapeHTML() + '</span>' +
            '</a>' +
            '<div class="tool-actions">' +
                '<a href="' + this._buttonUrl + '" class="btn" target="' + this._buttonTarget + '">' + this._buttonText.escapeHTML() + '</a>' +
                '<a href="#" class="link-02" id="' + this._id + '-hide"><span>' + this._hideText.escapeHTML() + '</span></a>' +
            '</div>'
        );
        $super();
    },

    setHideHandler: function (handler) {
        this._hideHandler = handler;
    },

    _onClose: function(event)
    {
        Event.stop(event);
        this._hideHandler(this);
        this._componentElement.remove();
        if (this._hideUrl) {
            new Ajax.Request(this._hideUrl, { method: 'post' });
        }
        return false;
    },

    _addEvents: function() {
        var el = $(this._id + '-hide');
        if (el) {
            el.observe('click', this._onClose.bind(this));
        }
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.namespace('Jsw.FileSharing');

Jsw.FileSharing = {
    trimLastSlash: function(str) {
        while (str[str.length-1] == '/') {
            str = str.substring(0, str.length-1);
        }
        return str;
    }
};
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.UpgradeFailureNotification = Class.create(Jsw.Component, {

    updateInterval: 5,

    _initConfiguration: function($super, config) {

        $super(config);
        this._isBootstrapRunning = this._getConfigParam('isBootstrapRunning');
        this._bootstrapExecutionUrl = this._getConfigParam('bootstrapExecutionUrl');
        this._bootstrapStatusUrl = this._getConfigParam('bootstrapStatusUrl');
        this._upgradeFailedMessage = this._getConfigParam('upgradeFailedMessage');
        this._bootstrapInProgressMessage = this._getConfigParam('bootstrapInProgressMessage');
        this._bootstrapLinkTitle = this._getConfigParam('bootstrapLinkTitle');
    },

    _initComponentElement: function($super) {
        $super();

        this._componentElement.update(
            '<div class="msg-box msg-warning">' +
            '<div><div><div><div><div>' +
            '<div class="msg-content" id="execute-bootstrap-message">' +
                (this._isBootstrapRunning ?
                    '<span class="ajax-loading">' + this._bootstrapInProgressMessage + '</span>' :
                    this._upgradeFailedMessage + ' <a id="execute-bootstrap-link" href="#">' + this._bootstrapLinkTitle +'</a>') +
            '</div>' +
            '</div></div></div></div></div>' +
            '</div>'
        );
    },

    _addEvents: function($super) {
        $super();
        if (this._isBootstrapRunning) {
            this._scheduleUpdateStatus();
        } else {
            $('execute-bootstrap-link').observe('click', this._executeBootstrapper.bind(this));
        }
    },

    _executeBootstrapper: function() {
        new Ajax.Request(Jsw.prepareUrl(this._bootstrapExecutionUrl), {
            method: 'post',
            onCreate: this._onCreateExecute.bind(this),
            onSuccess: this._scheduleUpdateStatus.bind(this),
            onFailure: this._scheduleUpdateStatus.bind(this)
        });
    },

    _onCreateExecute: function() {
        $('execute-bootstrap-message').update('<span class="ajax-loading">' + this._bootstrapInProgressMessage + '</span>');
    },

    _scheduleUpdateStatus: function() {
        this._statusUpdate.bind(this).delay(this.updateInterval);
    },

    _statusUpdate: function() {
        new Ajax.Request(Jsw.prepareUrl(this._bootstrapStatusUrl), {
            method: 'get',
            onSuccess: this._scheduleUpdateStatus.bind(this),
            onFailure: this._scheduleUpdateStatus.bind(this),
            on0: this._scheduleUpdateStatus.bind(this)
        });
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.namespace('Jsw.CustomDescription');

Jsw.CustomDescription.PopupForm = Class.create(Jsw.PopupForm, {
    _initConfiguration: function($super, config) {
        $super(config);
        this._hint = this._getConfigParam('hint', '');
        this._value = this._getConfigParam('value', '');
        this._handler = this._getConfigParam('handler', null);
        this._sendButtonId = this._getConfigParam('sendButtonId', 'btn-send');
        this._cancelButtonId = this._getConfigParam('cancelButtonId', 'btn-cancel');
    },

    render: function($super) {
        $super();

        this.setBoxType('form-box');
        this.setTitle(this._locale.popupTitle);
        this.setTitleType(this._getConfigParam('titleCls', 'pp-edit-description'));

        $(this._contentAreaId).update(
            '<p>' + this._hint + '</p>' +
            '<textarea id="' + this._id + '-description" class="js-auto-resize" rows="4" maxlength="255" cols="80">' +
                this._value + '</textarea>'
        );

        this.addOkButton();
        this.addCancelButton();
    },

    addOkButton: function() {
        this.addRightButton(this._locale.button.ok, this._onOkClick, true, true, {id: this._sendButtonId} );
    },

    addCancelButton: function() {
        this.addRightButton(this._locale.button.cancel, this._onCancelClick, false, false, {id: this._cancelButtonId} );
    },

    _onOkClick: function() {
        this._handler($(this._id + '-description').value);
        this.hide();
    },

    _onCancelClick: function() {
        this.hide();
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.namespace('Jsw.ConfirmationPopupManager');

Jsw.ConfirmationPopupManager.PopupForm = Class.create(Jsw.PopupForm, {
    _sendButtonTitle: '',

    _initConfiguration: function($super, config) {
        $super(config);

        this._prepareUrl = this._getConfigParam('prepareUrl', '');
        this._handlerUrl = this._getConfigParam('handlerUrl', '');
        this._ids = this._getConfigParam('ids', '');
        this._formListItemsAreaId = this._id + '-form-list-items';
        this._formListAreaId = this._id + '-form-list';
        this._formBoxAreaId = this._id + '-form-box';
        this._sendButtonId = this._getConfigParam('sendButtonId', 'btn-send');
        this._cancelButtonId = this._getConfigParam('cancelButtonId', 'btn-cancel');
        this._formDescriptionId =  this._id + '-form-desc';
        this._longtask = this._getConfigParam('longtask', false);
        this._autoload = this._getConfigParam('autoload', true);
    },

    render: function($super) {
        $super();

        this.setBoxType('form-box');
        this._setTitle();

        $(this._contentAreaId).update(
            this._getHeadDescription() +
            '<form method="post" action="" enctype="application/x-www-form-urlencoded" id="' + this._id + '-form">' +
            '<div class="box" id="' + this._formBoxAreaId + '"></div>' +
            '<div class="list" id="' + this._formListAreaId + '"></div>' +
            '</form>' +
            this._getBottomDescription()
        );

        var form = $(this._id + '-form');
        form._formSubmit = form.submit;
        form.submit = this._onSubmit.bind(this);
        form.observe('submit', this._onSubmitEvent.bind(this));

        $(this._formBoxAreaId).insert('<div class="ajax-loading">' + this._locale.loading + '</div>');

        this._addButtons();

        if (this._autoload) {
            this._renderPreparePopup();
        }
    },

    reload: function() {
        $(this._formListAreaId).update('');
        $(this._formBoxAreaId).update('<div class="ajax-loading">' + this._locale.loading + '</div>');
        this._preparePopup();
    },

    _addButtons: function() {
        this.addRightButton(this._locale.buttonOk, this._onOkClick, true, true, {id: this._sendButtonId} );
        this.addRightButton(this._locale.buttonCancel, this._onCancelClick, false, false, {id: this._cancelButtonId} );
    },

    _setTitle: function() {
        this.setTitle(this._locale.title);
    },

    _getHeadDescription: function() {
        return '';
    },

    _getBottomDescription: function() {
        return '<p id="' + this._formDescriptionId + '">' + this._locale.description + '</p>';
    },

    _getButtonsArea: function() {
        return '' +
            '<div class="btns-box" id="' + this._actionButtonsId + '">' +
            '<div class="box-area">' +
            '<div class="form-row">' +
            '<div class="single-row">' +
            '<div class="field-value" id="' + this._rightActionButtonsAreaId + '"> </div>' +
            '</div>' +
            '</div>' +
            '</div>' +
            '</div>';
    },

    _onException: function(transport, exception) {
        this._addErrorMessage('Internal error: ' + exception);
        this.enable();
    },

    _onOkClick: function(e) {
        this._onSubmit(e);
    },

    _onCancelClick: function() {
        this.hide();
    },

    _preparePopup: function() {
        var ids = $H();
        var count = 0;

        this._ids.each(function(id) {
            ids.set('ids[' + count + ']', id);
            count++;
        });

        new Ajax.Request(
            Jsw.prepareUrl(this._prepareUrl), {
                method: 'post',
                parameters: ids,
                onSuccess: this._onSuccessPreparePopup.bind(this),
                onException: this._onException.bind(this)
            }
        );
    },

    _renderPreparePopup: function() {
        this._preparePopup();
    },

    _onSubmitEvent: function(event) {
        this._onSubmit();
        Event.stop(event);
        return false;
    },

    _onSuccessResponse: function(response) {
        this.hide();
        Jsw.redirect(response.redirect);
    },

    _onSuccess: function(transport) {
        this._clearMessages();
        try {
            var response = transport.responseText.evalJSON();
            if ('success' == response.status) {
                this._onSuccessResponse(response);
            } else {
                if (response.redirect) {
                    Jsw.redirect(response.redirect);
                    return;
                }
                this._addErrorMessage(response.message);
                this.enable();
            }
        } catch (e) {
            this._addErrorMessage(e.message);
            this._addErrorMessage(
                'Internal error: ' + transport.responseText
            );
            this.enable();
        }
    },

    disable: function() {
        var sendButtonWrapper = $(this._sendButtonId);
        if (sendButtonWrapper) {
            var sendButton = sendButtonWrapper.down('button');
            sendButton.disabled = true;
            sendButtonWrapper.addClassName('disabled');
            if (!this._sendButtonTitle) {
                this._sendButtonTitle = sendButton.innerHTML;
            }
            sendButton.update('<span class="wait">' + this._locale.loading + '</span>');
        }

        var cancelButtonWrapper = $(this._cancelButtonId);
        if (cancelButtonWrapper) {
            cancelButtonWrapper.down('button').disabled = true;
            cancelButtonWrapper.addClassName('disabled');
        }
    },

    enable: function() {
        var sendButtonWrapper = $(this._sendButtonId);
        if (sendButtonWrapper) {
            sendButton = sendButtonWrapper.down('button');
            sendButton.disabled = false;
            sendButton.update(this._sendButtonTitle);
            sendButtonWrapper.removeClassName('disabled');
        }

        var cancelButtonWrapper = $(this._cancelButtonId);
        if (cancelButtonWrapper) {
            cancelButtonWrapper.down('button').disabled = false;
            cancelButtonWrapper.removeClassName('disabled');
        }
    },

    _onSuccessPreparePopup: function() {
        //should be implemented in child classes
        return true;
    },

    _getLoadingIndicatorItems: function() {
        return [];
    },

    _addLoadingIndicator: function(items) {
        //should be implemented in child classes
    },

    _getAdditionalParams: function(params) {
        //should be implemented in child classes if it necessary
        return params;
    },

    _isValid: function() {
        return true;
    },

    _onSubmit: function(e) {

        this._clearMessages();

        if (!this._isValid()) {
            return;
        }

        var params = $H();
        var count = 0;
        this._ids.each(function(id) {
            params.set('ids[' + count + ']', id);
            count++;
        });
        params = this._getAdditionalParams(params);

        this.disable();
        this._addLoadingIndicator(this._getLoadingIndicatorItems());

        if (this._needFlyEffect()) {
            var context = this;
            var beginOffset = e.target.cumulativeOffset();
            Jsw.getComponent('asyncProgressBarWrapper').fly(beginOffset,
                this._longtask,
                function(){
                    context._sendRequest(params);
                });
        } else {
            this._sendRequest(params);
        }
    },

    _needFlyEffect: function() {
        return (false !== this._longtask);
    },

    _sendRequest: function(params) {
        new Ajax.Request(
            this._handlerUrl,
            {
                method: 'post',
                parameters: params,
                onSuccess: this._onSuccess.bind(this),
                onException: this._onException.bind(this)
            }
        );
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.LookUp = Class.create(Jsw.Component, {
    _initConfiguration: function($super, config) {
        $super(config);

        this._name = this._getConfigParam('name', null);
        this._cls = this._getConfigParam('cls', 'lookup');
        this._data = this._getConfigParam('data', []);
        this._currentValue = this._getConfigParam('value', null);
        this._newItemValue = this._getConfigParam('newItemValue', null);
        this._dataUrl = this._getConfigParam('dataUrl', null);
        this._copyTitleValue = this._getConfigParam('copyTitleValue', false);
        this._limit = this._getConfigParam('limit', this._dataUrl ? 10 : Jsw.list.ITEMS_UNLIMITED);
        this._lookUpParams = this._getConfigParam('lookUpParams', {});

        if (!this._currentValue && this._newItemValue) {
            this._currentValue = this._newItemValue;
        }
    },

    _initComponentElement: function($super) {
        $super();

        this._valueField = new Element('input', {
            'type': 'hidden',
            'name': this._name
        });

        this._componentElement
            .insert(this._valueField);

        this._inputField = new Element('input', {
            'type': 'text',
            'class': 'form-control'
        });

        this._lookUpButton = new Element('span', {'class': 'form-control-icon form-control-icon-action'})
            .insert(new Element('i', {'class': 'icon-form-control-search'}));

        this._lookUpControl = new Element('div', {'class': 'form-control-group'})
            .insert(this._inputField)
            .insert(this._lookUpButton);

        this._dropdownList = new Element('ul', {'class': 'dropdown-menu lookup-dropdown-menu'});

        this._initCustomLookUpComponent();
        if (this._customLookUpComponent) {
            this._dropdownList
                .insert(new Element('li', {'class': 'dropdown-header'})
                    .update(this.lmsg('label'))
            );
            this._dropdownList
                .insert(new Element('li')
                    .insert(new Element('div', {'class': 'dropdown-menu-content'})
                        .insert(this._lookUpControl)
                )
            );
        } else {
            this._lookUpControl.addClassName('f-large-size');
            this._componentElement
                .insert(this._lookUpControl);
        }

        this._emptyElement = new Element('li')
            .insert(new Element('div', {'class': 'dropdown-menu-content'}).update(this.lmsg('nothingFound')));
        this._dropdownList.insert(this._emptyElement);

        this._componentElement
            .insert(this._dropdownList);

        this._updateValue();

        if (0 < this._data.length) {
            this._updateData(this._data);
        }
        if (this._dataUrl && this._limit == Jsw.list.ITEMS_UNLIMITED) {
            this._getDataByUrl();
        }
    },

    _initCustomLookUpComponent: function() {
        if (!this._newItemValue) {
            return;
        }

        this._customLookUpComponent = new Element('div', {'class': 'input-group'}).update(
            '<input type="text" readonly="" class="form-control f-large-size" value="">' +
            '<span class="input-group-btn">' +
                '<span type="button" class="btn dropdown-toggle">' +
                    '<button type="button">' +
                        '<span class="caret"></span>' +
                    '</button>' +
                '</span>' +
            '</span>'
        );
        this._componentElement.insert(this._customLookUpComponent);

        this._dropdownList
            .insert(this._createItem(this._newItemValue))
            .insert(new Element('li', {'class': 'divider'}));
    },

    _getDataByUrl: function(filter) {
        this._emptyElement.down('div').update(this.lmsg('loading'));
        new Ajax.Request(Jsw.prepareUrl(this._dataUrl), {
            method: 'post',
            parameters: Object.extend({
                filter: filter,
                limit: this._limit
            }, this._lookUpParams),
            onSuccess: function(transport) {
                var response = transport.responseText.evalJSON();
                this._emptyElement.down('div').update(this.lmsg('nothingFound'));
                if ('error' == response.status) {
                    return;
                }

                this._data = response.data;
                this._updateData(this._data);
                this._selectResults(filter, response.itemsCount - this._data.length);
            }.bind(this)
        });
    },

    isEmpty: function() {
        return null === this._currentValue;
    },

    getValue: function() {
        return this._currentValue ? this._currentValue.id : null;
    },

    getDisplayValue: function() {
        return this._currentValue ? this._currentValue.title : '';
    },

    _openList: function(showAll) {
        this._componentElement.addClassName('open');
        this._lookUpButton.down('i').removeClassName('icon-form-control-search').addClassName('icon-form-control-clear');
        this._fixDropdownPosition();

        var filter = showAll ? '' : this._inputField.getValue().toLocaleLowerCase();
        if (this._dataUrl && this._limit != Jsw.list.ITEMS_UNLIMITED) {
            this._emptyElement.down('div').update(this.lmsg('loading'));
            if (this._getDataTask) {
                clearTimeout(this._getDataTask);
            }
            this._getDataTask = setTimeout(function() {
                this._getDataByUrl(filter);
            }.bind(this), 250);
        } else {
            this._selectResults(filter);
        }
    },

    _closeList: function() {
        this._updateValue();
        this._componentElement.removeClassName('open');
        this._lookUpButton.down('i').addClassName('icon-form-control-search').removeClassName('icon-form-control-clear');
    },

    _updateValue: function() {
        this._valueField.setValue(this._currentValue ? (this._copyTitleValue ?  this._currentValue.title :  this._currentValue.id) : '');
        this._inputField.setValue(this._currentValue && !(this._newItemValue && this._currentValue.id === this._newItemValue.id) ? this._currentValue.title : '');
        if (this._newItemValue) {
            this._componentElement.down('.input-group input').setValue(this._currentValue ? this._currentValue.title : '');
        }
    },

    _selectResults: function(filter, itemsCount) {
        var itemsFound = 0;
        this._dropdownList.select('li').each(function(item) {
            if (!item._item) {
                return;
            }
            if (this._newItemValue && this._newItemValue.id === item._item.id) {
                if (this._currentValue && this._currentValue.id === this._newItemValue.id) {
                    item.hide();
                    item.next().hide();
                } else {
                    item.show();
                    item.next().show();
                }
                return;
            }
            item.removeClassName('active');
            var itemLink = item.select('a').first();
            var itemData = itemLink.innerHTML.stripTags();
            var pos = itemData.toLowerCase().indexOf(filter);
            if (-1 != pos) {
                itemsFound++;
                if (itemsFound <= this._limit) {
                    item.show();
                    itemData = itemData.substr(0, pos)
                        + '<b class="search-result-label">'
                        + itemData.substr(pos, filter.length)
                        + '</b>'
                        + itemData.substr(pos + filter.length);
                } else {
                    item.hide();
                }
            } else {
                item.hide();
            }
            itemLink.update(itemData);
        }.bind(this));

        this._emptyElement.toggle(!itemsFound);
        if (itemsFound) {
            var firstVisibleItem = this._dropdownList.select('li').find(function(el) { return el.visible() });
            if (firstVisibleItem) {
                firstVisibleItem.addClassName('active');
            }
        }

        itemsFound += itemsCount || 0;

        if (itemsFound > this._limit) {
            this._searchMoreElement.down('div').update(this._getSearchMoreText(itemsFound - this._limit));
            this._searchMoreElement.show();
            this._searchMoreElement.previous().show();
        } else {
            this._searchMoreElement.hide();
            this._searchMoreElement.previous().hide();
        }

        this._fixDropdownPosition();
    },

    _addEvents: function($super) {
        $super();

        if (this._customLookUpComponent) {
            this._customLookUpComponent.observe('click', function(event) {
                event.preventDefault();
                Jsw.Tooltip.hide();
                if (this._componentElement.hasClassName('open')) {
                    this._inputField.blur();
                } else {
                    this._openList(true);
                    this._inputField.focus();
                }
            }.bindAsEventListener(this));
        } else {
            this._inputField.observe('focus', this._inputOnFocus.bindAsEventListener(this));
        }
        this._inputField.observe('paste', this._inputOnPaste.bindAsEventListener(this));
        this._inputField.observe('blur', this._inputOnBlur.bindAsEventListener(this));
        this._inputField.observe('keyup', this._inputOnKeyUp.bindAsEventListener(this));
        this._inputField.observe('keydown', this._inputOnKeyDown.bindAsEventListener(this));
        this._lookUpButton.observe('click', this._lookUpButtonOnClick.bindAsEventListener(this));
    },

    _inputOnFocus: function() {
        this._openList(true);
    },

    _inputOnBlur: function(event) {
        // workaround for Google Chrome
        setTimeout(function() {
            this._closeList();
        }.bind(this), 300);
    },

    _inputOnPaste: function(event) {
        setTimeout(function() {
            this._openList();
            var activeItem = this._dropdownList.select('li.active').first();
            if (activeItem) {
                this._currentValue = activeItem._item;
                this._updateValue();
            }
        }.bind(this), 300);
    },

    _inputOnKeyUp: function(event) {
        if ([Jsw.keyCode.UP_ARROW,  Jsw.keyCode.DOWN_ARROW, Jsw.keyCode.LEFT_ARROW, Jsw.keyCode.RIGHT_ARROW, Jsw.keyCode.ENTER, Jsw.keyCode.ESC].indexOf(event.keyCode) != -1) {
            return;
        }

        this._openList();
    },

    _inputOnKeyDown: function(event) {
        if ([Jsw.keyCode.UP_ARROW,  Jsw.keyCode.DOWN_ARROW].indexOf(event.keyCode) != -1) {
            this._onArrowKeyPressed(event.keyCode);
        }

        if (Jsw.keyCode.ESC == event.keyCode) {
            this._closeList();
        }

        if (Jsw.keyCode.ENTER == event.keyCode) {
            var activeItem = this._dropdownList.select('li.active').first();
            if (activeItem) {
                this._currentValue = activeItem._item;
                this._closeList();
                this._componentElement.fire('component:change');
            } else {
                this._closeList();
                this._openList();
            }
        }
    },

    _onArrowKeyPressed: function(keyCode) {
        var nextItem = null;
        var activeItem = this._dropdownList.select('li.active').first();
        if (!activeItem) {
            nextItem = this._dropdownList.select('li').first();
            while (nextItem && !(nextItem.visible() && nextItem._item)) {
                nextItem = nextItem.next();
            }
        } else if (Jsw.keyCode.DOWN_ARROW == keyCode) {
            nextItem = activeItem.next();
            while (nextItem && !(nextItem.visible() && nextItem._item)) {
                nextItem = nextItem.next();
            }
        } else if (Jsw.keyCode.UP_ARROW == keyCode) {
            nextItem = activeItem.previous();
            while (nextItem && !(nextItem.visible() && nextItem._item)) {
                nextItem = nextItem.previous();
            }
        }

        if (nextItem && nextItem.visible() && nextItem._item) {
            nextItem.addClassName('active');
            if (activeItem) {
                activeItem.removeClassName('active');
            }
        }
    },

    _lookUpButtonOnClick: function(event) {
        event.preventDefault();

        if (this._componentElement.hasClassName('open')) {
            this._closeList();
        } else {
            this._openList(true);
        }
    },

    _itemOnClick: function(event) {
        event.preventDefault();
        this._currentValue = event.target.up('li')._item;
        this._closeList();
        this._componentElement.fire('component:change');
    },

    _itemOnOver: function() {
        this._dropdownList.select('li.active').each(function(element) {
            element.removeClassName('active');
        });
    },

    _createItem: function(item) {
        var listItem = new Element('li', {'class': 'dropdown-menu-list-item'}).insert(
            new Element('a', {'href': '#'}).update(item.title)
        );
        listItem._item = item;
        listItem.observe('click', this._itemOnClick.bindAsEventListener(this));
        listItem.observe('mouseover', this._itemOnOver.bindAsEventListener(this));

        return listItem;
    },

    _getSearchMoreText: function(count) {
        return this.lmsg('moreObjectsAvailable', {count: count});
    },

    _updateData: function(data) {
        this._clearData();

        data.each(function(item) {
            this._dropdownList.insert(this._createItem(item));
        }.bind(this));

        this._addSearchMoreElement();
    },

    _clearData: function() {
        while (this._emptyElement.next()) {
            this._emptyElement.next().remove();
        }
    },

    _addSearchMoreElement: function() {
        this._searchMoreElement = new Element('li')
            .insert(new Element('div', {'class': 'dropdown-menu-content'}));
        this._dropdownList
            .insert(new Element('li', {'class': 'divider'}).hide())
            .insert(this._searchMoreElement.hide());
    },

    _fixDropdownPosition: function() {
        var style = {};
        style[Jsw.isRtl() ? 'right' : 'left'] = null;
        this._dropdownList.setStyle(style);

        var windowWidth = $(document.body).getWidth();
        var width = this._dropdownList.getWidth();
        var offsets = this._dropdownList.cumulativeOffset();
        var delta = (Jsw.isRtl() ? offsets.left : (windowWidth - width - offsets.left))
            - parseInt($$('.page-content')[0].getStyle('padding-left'));

        if (delta < 0) {
            style[Jsw.isRtl() ? 'right' : 'left'] = delta + 'px';
            this._dropdownList.setStyle(style);
        }
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.StatusMessage = Class.create(Jsw.Component, {
    _initConfiguration: function($super, config) {
        $super(config);
        this._type = this._getConfigParam('type', 'error');
        this._cls = this._getConfigParam('cls', 'msg-box msg-' + this._type);
        this._renderTargetId = this._getConfigParam('renderTo', 'main');
        this._renderMode = this._getConfigParam('renderMode', 'top');
        this._title = this._getConfigParam('title', '');
        this._message = this._getConfigParam('message', '');
        this._closable = this._getConfigParam('closable', false);
        this._onClose = this._getConfigParam('onClose', null);
    },

    _initComponentElement: function($super) {
        $super();

        this._updateComponentElement(
            '<div><div><div><div><div>' +
            '<div class="msg-content">' +
            this._renderCloseButton() +
            this._renderMessage() +
            '</div>' +
            '</div></div></div></div></div>'
        );
    },

    _renderMessage: function() {
        var message = '';
        if (this._title) {
            message = '<b>' + this._title + ':</b> ';
        }
        message += this._message;
        return message;
    },

    _renderCloseButton: function() {
        if (!this._closable) {
            return '';
        }
        return '<span class="close"></span>'
    },

    _addEvents: function($super) {
        $super();

        this._componentElement.select('.close').each(function(closeButton) {
            Event.observe(closeButton, 'click', this._onCloseEvent.bind(this));
        }, this);
    },

    _onCloseEvent: function() {
        if (!this._onClose) {
            return;
        }
        this._onClose();
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.Observer = (function(){
    var observers = {};
    var getObservers = function(ns) {
        if ('undefined' == typeof observers[ns]) {
            observers[ns] = [];
        }
        return observers[ns];
    };
    return {
        append: function(callback, ns) {
            getObservers(ns).push(callback);
        },
        appendAndCall: function(callback, ns) {
            getObservers(ns).push(callback);
            callback();
        },
        notify: function(event, ns) {
            getObservers(ns).each(function(callback) {
                callback(event);
            });
        }
    };
})();
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.ResponsiveDropdown = Class.create(Jsw.Container, {

    _initConfiguration: function($super, config) {
        $super(config);
        this._contentAreaId = this._id + '-content-area';
        this._cls = this._getConfigParam('cls', 'dropdown');
        this._onChange = this._getConfigParam('onChange', false);
        this._hasIcons = this._getConfigParam('hasIcons', true);
        this._forceDropdown = this._getConfigParam('forceDropdown', false);
        this._responsiveClass = this._getConfigParam('responsiveClass', false);
        this._headerClass = this._getConfigParam('headerClass', false);
        this._responsiveHeaderClass = this._getConfigParam('responsiveHeaderClass', false);
    },

    _initComponentElement: function($super) {
        $super();

        if (this._forceDropdown || this._items && this._items.size() > 1) {
            this._updateComponentElement(
                '<a class="btn dropdown-toggle" href="#">' +
                '<span>' + this._getConfigParam('title') + '</span>' +
                ' <em class="caret"></em>' +
                '</a>' +
                '<ul id="' + this._contentAreaId + '" class="dropdown-menu' + (this._hasIcons ? ' dropdown-icon-menu' : '') + '"></ul>'
            );
            this._componentElement.addClassName(this._cls);
        } else {
            this._componentElement = new Element('span', {
                id: this._id
            }).update(this._getConfigParam('title'));
        }
    },

    _addEvents: function($super) {
        $super();

        this._componentElement.observe('click', function(event) {
            if ($$('.' + this._headerClass).first().hasClassName('r-show-main-header-navbar')) {
                event.stopPropagation();
            }
        }.bind(this));

        var boxElement = this._componentElement.down('.dropdown-toggle');
        if (boxElement) {
            Jsw.DropdownManager.register(
                boxElement,
                function () {
                    return boxElement.up('.dropdown').hasClassName('open');
                },
                function () {
                    boxElement.up('.dropdown').addClassName('open');
                },
                function () {
                    boxElement.up('.dropdown').removeClassName('open');
                }
            );
        }

        this._addResponsiveEvents();
    },

    _addResponsiveEvents: function() {
        if (this._responsiveClass) {
            var dropdown = this;
            var responsiveElement = $$('.' + this._responsiveClass)[0];
            $(document).observe('click', function() {
                dropdown._hide();
            });

            Event.observe(responsiveElement, 'click', function(event) {
                dropdown._show(responsiveElement);
                event.stopPropagation();
            });
        }
    },

    _hide: function() {
        $$('.' + this._headerClass).first().className = this._headerClass;
        var element = $$('.r-item-active');
        if (element.length === 0) {
            return;
        }
        element[0].removeClassName('r-item-active');

        if (element = $$('.r-page-sidebar-search-active').first()) {
            element.removeClassName('r-page-sidebar-search-active');
        }
    },

    _show: function(el) {
        var needShow = true;
        if (el.hasClassName('r-item-active')) {
            needShow = false;
        }

        this._hide();
        if (needShow) {
            $$('.' + this._headerClass).first().addClassName(this._responsiveHeaderClass);
            el.addClassName('r-item-active');
        }
    },

    _renderItem: function(item) {
        if (!$(this._contentAreaId)) {
            return;
        }
        var dropdownItem = new Jsw.DropdownItem(item);

        var attributes = {
            'href': item.href ? item.href : '#'
        };
        if (item.target) {
            attributes.target = item.target;
        }

        var valueItem = new Element('a', attributes).update(
            (item.iconClass ? '<i class="' + item.iconClass + '"></i>' : '') +
            dropdownItem.title.escapeHTML()
        );
        if (item.description) {
            Jsw.Tooltip.init(valueItem, {text: item.description});
        }

        var liElement = new Element('li');
        if (this._getConfigParam('title') === dropdownItem.title.escapeHTML()) {
            liElement.addClassName('current');
        }
        liElement.appendChild(valueItem);
        $(this._contentAreaId).insert(liElement);

        if (item.disabled) {
            liElement.addClassName('disabled');
            valueItem.observe('click', function(event) {
                event.stop();
            });
        } else if (this._onChange) {
            valueItem.observe('click', this._onChange.bindAsEventListener(this, dropdownItem));
        }
    }

});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.SearchResponsiveDropdown = Class.create(Jsw.ResponsiveDropdown, {

    _initComponentElement: function($super) {
    },

    _addEvents: function($super) {
        this._addResponsiveEvents();
    },

    _addResponsiveEvents: function($super) {
        $super();
        $(this._applyTargetId).observe('click', function(event) {
            if ($$('.' + this._headerClass).first().hasClassName('r-show-top-search')) {
                event.stopPropagation();
            }
        }.bind(this));
    },

    _show: function($super, el) {
        $super(el);
        if ($$('.' + this._headerClass).first().hasClassName(this._responsiveHeaderClass)) {
            $(this._applyTargetId).addClassName('r-page-sidebar-search-active');
        }
    }
});

// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.
Jsw.namespace('Jsw.Task.ProgressBar');

Jsw.Task.ProgressBar = Class.create(Jsw.Container, {

    _initConfiguration: function($super, config) {
        $super(config);

        this.pe = null;
        this._contentAreaId = this._id + '-content-area';
        this._preparingItems = [];
        this._preparingCounter = 0;
        this._deletedIds = [];
    },

    _initComponentElement: function($super) {
        $super();

        var isAsyncProgressBarCollapsed = Jsw.Cookie.get('isAsyncProgressBarCollapsed');

        this._updateComponentElement(
            '<div id="asyncProgressBar" class="async-progress-bar ' + ("true" === isAsyncProgressBarCollapsed ? 'async-progress-bar-collapsed': '') + '"> ' +
                '<div class="async-progress-bar-wrap">' +
                    '<div id="asyncProgressBarTop" class="async-progress-bar-top">' +
                        '<div class="async-progress-bar-control">' +
                            '<a id="asyncProgressBarControlHide" href="#" class="async-progress-bar-control-hide">' + this._locale.progressBarHide +'</a>' +
                            '<a id="asyncProgressBarControlShow" href="#" class="async-progress-bar-control-show">' + this._locale.progressBarShow +'</a>' +
                        '</div>' +
                        '<div class="async-progress-bar-title">' +
                            '<span id="asyncProgressBarTitleTasks" class="async-progress-bar-title-tasks hidden"></span>' +
                            '<span id="asyncProgressBarTitleTasksError" class="async-progress-bar-title-tasks-error hidden"><span>0</span></span>' +
                            '<span id="asyncProgressBarTitleTasksComplete" class="async-progress-bar-title-tasks-complete hidden"><span>0</span></span>' +
                            '<span id="asyncProgressBarTitleTasksWarning" class="async-progress-bar-title-tasks-warning hidden"><span>0</span></span>' +
                            '<a id="asyncProgressBarHideCompletedTasks" class="async-progress-bar-title-tasks-hide hidden" href="#">' + this._locale.hideCompletedTasks + '</a>' +
                        '</div>' +
                    '</div>' +
                    '<div class="async-progress-bar-body">' +
                        '<ul class="async-progress-bar-list" id="' + this._contentAreaId + '">' +
                        '</ul>' +
                    '</div>' +
                '</div>' +
            '</div>'
        );
    },

    addPreparingItem: function(title) {
        var id = "preparing-" + this._preparingCounter;
        var item = new Jsw.Task.ProgressBar.Item({
            errors: [],
            id: id,
            progressTitle: title,
            status: "flying",
            type: "wordpress"
        });
        this._preparingItems.unshift(item);
        this._preparingCounter++;
        this._config['items'].unshift(item);
        return id;
    },

    removePreparingItem: function(id) {
        this._preparingItems = this._preparingItems.filter(function(item) {
            return item.getId() != id;
        });
        this._deletedIds.push(id);
    },

    toggle: function() {
        var element = $('asyncProgressBar');
        element.toggleClassName('async-progress-bar-collapsed');

        Jsw.Cookie.setPermanent(
            'isAsyncProgressBarCollapsed',
            element.hasClassName('async-progress-bar-collapsed'),
            '/'
        );

        this._updateTitle();
    },

    update: function() {
        var context = this;
        new Ajax.Request(Jsw.prepareUrl('/task/task-progress/'), {
            method: 'post',
            onSuccess: function(response) {
                context.removeItemsByIds(context._deletedIds);
                context._deletedIds = [];
                var data = response.responseText.evalJSON();
                context.checkPreviousStatus(data.items);
                context.setItems(data.items);
                context.renderItems();
            }
        });
    },

    getLocale: function() {
        return this._locale;
    },

    renderItems: function() {
        this._initItems();
        this._renderItems();
    },

    _initItems: function($super) {
        $super();

        if (null == this._items) {
            this._items = [];
            this.update();
        }
    },

    removeItemsByIds: function(ids){
        var items = this.getItems();
        for (var i=0; i<ids.length; i++) {
            for (var j=0; j<items.length; j++) {
                if (items[j].getId() === ids[i]) {
                    items[j].getTargetElement().remove();
                    items.splice(j, 1);
                    break;
                }
            }
        }
        this.setItems(items);
        this.renderItems();
    },

    checkPreviousStatus: function(items) {
        var context = this;
        items.each(function(item) {
            this._config['items'].each(function(item) {
                if (this['id'] == item.getId()) {
                    this['isRefreshLinkEnabled'] = item['_isRefreshLinkEnabled'];
                    if (this['status'] != item['_status']) {
                        context.onItemStatusChange(this);
                    }
                    if (('started' != this['status']) && item.isRunning()) {
                        this['isRefreshLinkEnabled'] = true;
                    }
                }
            }, item);
        }, this);
    },

    onItemStatusChange: function(item) {},

    setItems: function(items) {
        items = this._preparingItems.concat(items);
        this._config['items'] = items;
    },

    removeCompletedTask:function()
    {
        var context = this;
        var items = this.getItems();
        var ids = [];
        for (var i=0; i<items.length; i++) {
            if (!items[i].isRunning()) {
                ids.push(items[i].getId());
            }
        }
        if (ids.length > 0) {
            new Ajax.Request(Jsw.prepareUrl('/task/task-remove/'), {
                method: 'post',
                parameters: {'ids[]': ids},
                onSuccess: function(response) {
                    context.removeItemsByIds(ids);
                }
            });
        }
    },

    fly: function(beginOffset, taskName, action)
    {
        if (!Jsw.BrowserFeatures.transition) {
            action();
            return;
        }

        var item = new Element('div', {'class': 'async-progress-bar-floating-item'});
        item.insert(taskName);
        item.setStyle({
            top: beginOffset.top + 'px',
            left: beginOffset.left + 'px'
        });
        $$('body')[0].insert({bottom: item});
        var progressBarComponent = this;
        var progressBarItemId = progressBarComponent.addPreparingItem(taskName);
        progressBarComponent.renderItems();
        var progressBarPreparingItem = $$('.async-progress-bar-preparing-item-begin').first();
        if ($('asyncProgressBar').hasClassName('async-progress-bar-collapsed')) {
            this.toggle();
        }
        setTimeout(function(){
            var progressBarTotalHeight = progressBarPreparingItem.getHeight();
            progressBarPreparingItem.addClassName('async-progress-bar-preparing-item');
            setTimeout(function(){
                progressBarPreparingItem.addClassName('async-progress-bar-preparing-item-end');
                var endOffset = $$('ul.async-progress-bar-list')[0].cumulativeOffset();
                var endScrollOffset = $$('ul.async-progress-bar-list')[0].cumulativeScrollOffset();
                var progressBar = progressBarPreparingItem.firstDescendant();
                var height = progressBar.measure('height');
                var width = progressBar.measure('width');
                item.setStyle({
                    top: (endOffset.top + endScrollOffset.top - progressBarTotalHeight) + 'px',
                    left: endOffset.left + 'px',
                    height: height + 'px',
                    width: width + 'px'
                });
                item.addClassName('async-progress-bar-floating-item-end');
                var transitionEvents = $w('webkitTransitionEnd transitionend msTransitionEnd oTransitionEnd');
                transitionEvents.each(function(ev) {
                    item.observe(ev, function(){
                        transitionEvents.each(function(ev2) {
                            item.stopObserving(ev2);
                        });
                        item.remove();
                        var progressBarItem = Jsw.getComponent(progressBarItemId);
                        progressBarItem.setStatus(progressBarItem.STATUS_PREPARING);
                        var progressBar = progressBarPreparingItem.firstDescendant();
                        progressBar.setStyle({'visibility': 'visible'});
                        action();
                    });
                });
            }, 0);
        }, 0);

        return progressBarItemId;
    },

    _renderItems: function($super) {
        $super();

        this._updateTitle();
        if (this.getItems().length > 0) {
            this._componentElement.removeClassName('hidden');
            this._setPeriodicalExecutor();
        } else {
            this._componentElement.addClassName('hidden');
        }
    },

    _setPeriodicalExecutor: function()
    {
        var context = this;
        if (null == this.pe && this._hasRunningTasks()) {
            this.pe = new PeriodicalExecuter(function() {
                context.update();
                if (!context._hasRunningTasks()) {
                    context.pe.stop();
                    context.pe = null;
                }
            }, 5);
        }
    },

    _hasRunningTasks: function() {
        var tasks = this.getItems();
        if (!tasks) {
            return false;
        }
        for (var i = 0; i < tasks.length; i++) {
            if (tasks[i].isRunning()) {
                return true;
            }
        }
        return false;
    },

    _updateTitle: function() {
        var countRunning = 0;
        var countCompleteError = 0;
        var countComplete = 0;
        var countCompleteWarning = 0;
        var countAll = 0;

        var items = this.getItems();
        for (var i=0; i<items.length; i++) {
            countAll += 1;
            if (items[i].isComplete()) {
                countComplete += 1;
            } else if (items[i].isCompleteWithWarning()) {
                countCompleteWarning += 1;
            } else if (items[i].isCompleteWithError()) {
                countCompleteError += 1;
            } else {
                countRunning += 1;
            }
        }
        var taskRunningElement = $('asyncProgressBarTitleTasks');
        if (countRunning > 0) {
            if (countRunning == countAll) {
                taskRunningElement.update(countRunning + ' ' + this._locale.taskInProgress);
            } else {
                taskRunningElement.update(countRunning);
            }
            $('asyncProgressBar').removeClassName('async-progress-bar-complete');
            taskRunningElement.removeClassName('hidden');
        } else {
            $('asyncProgressBar').addClassName('async-progress-bar-complete');
            taskRunningElement.addClassName('hidden');
        }
        if (countComplete > 0 || countCompleteWarning > 0 || countCompleteError > 0) {
            $('asyncProgressBarHideCompletedTasks').removeClassName('hidden');
        } else {
            $('asyncProgressBarHideCompletedTasks').addClassName('hidden');
        }

        this._updateTaskTitleElement('asyncProgressBarTitleTasksError', countCompleteError);
        this._updateTaskTitleElement('asyncProgressBarTitleTasksWarning', countCompleteWarning);
        this._updateTaskTitleElement('asyncProgressBarTitleTasksComplete',
            $('asyncProgressBar').hasClassName('async-progress-bar-collapsed') && countComplete == countAll
                ? this.lmsg('allTasksCompleted', {'num': countComplete})
                : countComplete
        );
    },

    _updateTaskTitleElement: function(id, title) {
        var element = $(id);

        element.update('<span>' + title + '</span>');
        title == 0 ? element.addClassName('hidden') : element.removeClassName('hidden');
    },

    _renderItem: function(item) {
        var renderTargetId = this._id + '-item-' + item.getId();
        if (!$(renderTargetId)) {
            $(this._contentAreaId).insert({
                top: '<li id="' + renderTargetId +'" class="async-progress-bar-item"></li>'
            });
        }
        item.setRenderTarget(renderTargetId);
        item.setLocale(this.getLocale());
        item.setProgressBarElement(this);
        item.render();
    },

    _addEvents: function($super) {
        $super();

        var context = this;
        $('asyncProgressBarTop').observe('click', function(e) {
            e.preventDefault();
            context.toggle();
        });
        $('asyncProgressBarHideCompletedTasks').observe('click', function(e) {
            e.preventDefault();
            context.removeCompletedTask();
        });
    }
});

Jsw.Task.ProgressBar.Item = Class.create(Jsw.Component, {

    STATUS_COMPLETE: 'done',
    STATUS_ERROR: 'error',
    STATUS_RUNNING: 'started',
    STATUS_NOT_STARTED: 'not_started',
    STATUS_PREPARING: 'preparing',
    STATUS_FLYING: 'flying',

    _initConfiguration: function($super, config) {
        $super(config);

        this._id = this._getConfigParam('id', '');
        this._type = this._getConfigParam('type', '');
        this._status = this._getConfigParam('status', '');
        this._errors = this._getConfigParam('errors', []);
        this._hideErrors = this._getConfigParam('hideErrors', []);
        this._isRefreshLinkEnabled = this._getConfigParam('isRefreshLinkEnabled', false)
            && this._getConfigParam('isRefreshAllowed', true);
        this._progressTitle = this._getConfigParam('progressTitle', '');
        this._progressValue = this._getConfigParam('progressValue', 0);
        this._canCancel = this._getConfigParam('canCancel', true);
        this._referrer = this._getConfigParam('referrer', '');
        this._progressBarElement = {};
    },

    getTargetElement: function() {
        return $(this.getRenderTarget());
    },

    render: function() {
        var element = this.getTargetElement();

        if (this.isComplete()) {
            element.addClassName('async-progress-bar-item-complete');
            element.update(
                '<div class="async-progress-bar-item-wrap">' +
                    '<div class="async-progress-bar-item-msg">' +
                        '<a id="asyncProgressBarItemClose' + this.getId() + '" href="#"><span class="close"></span></a>' +
                        '<div class="async-progress-bar-item-msg-body">' + this.getProgressTitle() + this.getRefreshLink() + '</div>' +
                    '</div>' +
                '</div>'
            );
        } else if (this.isCompleteWithWarning()) {
            element.addClassName('async-progress-bar-item-warning');
            this._updateElementWithErrors(element);
        } else if (this.isCompleteWithError()) {
            element.addClassName('async-progress-bar-item-error');
            this._updateElementWithErrors(element);
        } else if (this.isPreparing() || this.isFlying() || this.isProgressUndefined()) {
            if (!this.isProgressUndefined()) {
                element.addClassName('async-progress-bar-preparing-item-begin');
            }
            element.update(
                '<div class="async-progress-bar-item-wrap" ' + (this.isFlying() ? 'style="visibility: hidden;"' : '') + '>' +
                    '<div class="async-progress-bar-item-heading">' +
                        '<span class="async-progress-bar-item-title">' + this.getProgressTitle() + '</span>' +
                    '</div>' +
                    '<span class="gauge-wrapper indeterminate-progress-bar" title="">' +
                        '<span class="gauge-container"><span id="" class="gauge-filled" style="width: 100%;"></span></span>' +
                    '</span>' +
                '</div>'
            );
        } else {
            element.update(
                '<div class="async-progress-bar-item-wrap">' +
                    '<div class="async-progress-bar-item-heading">' +
                        '<span class="async-progress-bar-item-control">' + this.getCancelButton() + '</span>' +
                        '<span class="async-progress-bar-item-title">' + this.getProgressTitle() + '</span>' +
                    '</div>' +
                    '<span class="gauge-wrapper" title="">' +
                        '<span class="gauge-container"><span id="" class="gauge-filled" style="width: ' + this.getProgressValue() + '%;"></span></span>' +
                    '</span>' +
                    '<div class="async-progress-bar-item-footer">' + this.getProgressValue() + '%</div>' +
                '</div>'
            );
        }

        this._addEvents();
        this._addTooltips();
    },

    setProgressBarElement: function(element) {
        this._progressBarElement = element;
    },

    getProgressBarElement: function() {
        return this._progressBarElement;
    },

    setLocale: function(locale) {
        this._locale = locale;
    },

    getProgressTitle: function() {
        return this._progressTitle;
    },

    getProgressValue: function() {
        return this._progressValue;
    },

    getStatus: function() {
        return this._status;
    },

    setStatus: function(status) {
        this._status = status;
    },

    getRefreshLink: function() {
        return this._isRefreshLinkEnabled && window.location.pathname == this._referrer
            ? '<div><a href="#" id="refreshLink' + this.getId() + '">' + this._locale.refresh + '</a></div>'
            : '';
    },

    hasErrors: function() {
        return this._errors.length > 0;
    },

    getErrors: function() {
        return this._errors;
    },

    getErrorsString: function() {
        var messages = '';
        var errors = this.getErrors();
        for (var i=0; i<errors.length; i++) {
            messages += '<li>' + errors[i].escapeHTML() + '</li>';
        }

        return messages;
    },

    getCancelButton: function() {
        return ''; // PPP-13558
        if (!this._canCancel) {
            return '';
        }
        return '<a id="asyncProgressBarItemCancel' + this.getId() + '" href="#">' + this._locale.cancel + '</a>';
    },

    isComplete: function() {
        return this.STATUS_COMPLETE == this._status && !this.hasErrors();
    },

    isCompleteWithWarning: function() {
        return this.STATUS_COMPLETE == this._status && this.hasErrors();
    },

    isRunning: function() {
        return this.STATUS_RUNNING == this._status || this.STATUS_NOT_STARTED == this._status;
    },

    isPreparing: function() {
        return this.STATUS_PREPARING == this._status;
    },

    isFlying: function() {
        return this.STATUS_FLYING == this._status;
    },

    isProgressUndefined: function() {
        return this._progressValue == -1;
    },

    isCompleteWithError: function() {
        return this.STATUS_ERROR == this._status;
    },

    remove: function() {
        var context = this;
        new Ajax.Request(Jsw.prepareUrl('/task/task-remove/'), {
            method: 'post',
            parameters: {'ids[]': [this.getId()]},
            onSuccess: function(response) {
                context.getProgressBarElement().removeItemsByIds([context.getId()]);
            }
        });
    },

    _updateElementWithErrors: function(element) {
        var errorDetails = (this._hideErrors)
            ? ''
            : '<div class="error-details">' +
                '<ul>' +
                    this.getErrorsString() +
                '</ul>' +
            '</div>' ;

        element.update(
            '<div class="async-progress-bar-item-wrap">' +
                '<div class="async-progress-bar-item-msg">' +
                '<a id="asyncProgressBarItemClose' + this.getId() + '" href="#"><span class="close"></span></a>' +
                    '<div class="async-progress-bar-item-msg-body">' +
                        this.getProgressTitle() +
                        errorDetails +
                        this.getRefreshLink() +
                    '</div>' +
                '</div>' +
            '</div>'
        );
    },

    _addEvents: function() {

        var context = this;
        var buttonClose = $('asyncProgressBarItemClose' + this.getId());
        var buttonCancel = $('asyncProgressBarItemCancel' + this.getId());
        var buttonRefresh = $('refreshLink' + this.getId());

        if (buttonClose) {
            buttonClose.observe('click', function(e) {
                e.preventDefault();
                context.remove();
            });
        }
        if (buttonCancel) {
            buttonCancel.observe('click', function(e) {
                e.preventDefault();
                context.remove();
            });
        }
        if (buttonRefresh) {
            buttonRefresh.observe('click', function(event) {
                Jsw.redirect(Jsw.prepareUrl(window.location.pathname));
                event.preventDefault();
            });
        }
    }
});

Jsw.Task.ProgressBar.OutputPopup = Class.create(Jsw.Popup, {
    initialize: function($super, event, link) {
        Event.extend(event).preventDefault();

        var config = link.readAttribute('data-config').evalJSON();
        this._locale = config.locale;

        var output = link.readAttribute('data-output');
        this._content = '<div class="tree-box" style="height: 400px">' +
            '<p>' + output.escapeHTML().replace(/\n/gm, '<br>') + '</p>' +
            '</div>'

        $super(config);
    },

    _initConfiguration: function($super) {
        $super({
            title: this.lmsg('popupTitle'),
            content: this._content,
            buttons: [{
                title:  this.lmsg('popupClose'),
                handler: function(event, popup) {
                    popup.hide();
                }
            }]
        });
    }
});

// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.namespace('Jsw.ScheduledTasks');
Jsw.ScheduledTasks.OutputPopup = Class.create(Jsw.Task.ProgressBar.OutputPopup, {
    _initConfiguration: function($super, config) {
        var titleMessage = '';
        var titleClass = '';
        if (config.result) {
            titleMessage = this.lmsg('popupDone');
            titleClass = 'hint-ok';
        } else {
            titleMessage = this.lmsg('popupError');
            titleClass = 'hint-failed';
        }
        titleMessage = titleMessage.replace('%%task%%', config.name);
        titleMessage = titleMessage.replace('%%seconds%%', config.seconds);

        this._content = '<div>' +
            '<p><span class="' + titleClass + '"><b>' + titleMessage + '</b></span></p>' +
            '</div>' +
            this._content;

        $super(config);
    }
});

// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.
Jsw.ActiveList = Class.create(Jsw.Component, {
    _addEvents: function() {
        this._componentElement.select('.active-list-item .caption-control').invoke('observe', 'click', function(event) {
            this._toggleItem(event.element().up('.active-list-item'));
        }.bindAsEventListener(this));

        this._componentElement.select('.active-list-item .caption-head-wrap').invoke('observe', 'click', function(event) {
            if (event.findElement('.caption-head-action, .caption-head-widget')) {
                return;
            }

            var item = event.element().up('.active-list-item');
            this._toggleItem(item);
            if (item.hasClassName('active-list-item-collapsed')) {
                return;
            }

            var itemBottom = item.cumulativeOffset().top + item.getHeight();
            var viewportBottom = document.viewport.getScrollOffsets().top + document.viewport.getHeight();
            if (itemBottom + 40 > viewportBottom) {
                scrollToItem(item, 500);
            }
        }.bindAsEventListener(this));

        this._componentElement.select('dropdown-toggle').each(function(element) {
            element.observe('click', function(e){
                Event.stop(e);
                var hadClassName = this.up('.btn-group').hasClassName('btn-group-open');
                $$('.active-list .dropdown-toggle').each(function(elem){
                    elem.up('.btn-group').removeClassName('btn-group-open');
                });
                if (!hadClassName) {
                    this.up('.btn-group').addClassName('btn-group-open');
                }
            });
            $(document.body).observe('click', function() {
                element.up('.btn-group').removeClassName('btn-group-open');
            });
        });

        this._componentElement.select('.a-toolbar-buttons-misc .btn-search').invoke('observe', 'click', function() {
            this.up('.a-toolbar')
                .toggleClassName('a-toolbar-collapsed')
                .toggleClassName('a-toolbar-expanded');
        });

        this._componentElement.select('.a-toolbar-buttons-misc .btn-settings').each(function(element) {
            element.observe('click', function(e){
                Event.stop(e);
                this.up('.a-toolbar-buttons-settings')
                    .toggleClassName('a-toolbar-buttons-settings-inactive')
                    .toggleClassName('a-toolbar-buttons-settings-active');
            });
            $(document.body).observe('click', function() {
                element.up('.a-toolbar-buttons-settings')
                    .addClassName('a-toolbar-buttons-settings-inactive')
                    .removeClassName('a-toolbar-buttons-settings-active');
            });
        });

        this._componentElement.select('.caption-services .close').each(function(element) {
            element.observe('click', function(e){
                Event.stop(e);
                var closeUrl = this.readAttribute('data-close-url');
                this.up('.caption').select('.caption-services').map(Element.show);
                this.up('.caption-services').remove();
                new Ajax.Request(Jsw.baseUrl + closeUrl, { method: 'post' });
            });
        });

        this._initToolbar();
    },

    _initToolbar: function() {
        this._componentElement.select('.a-toolbar-buttons-main').each(function (toolbarEl) {
            var itemEls = toolbarEl.childElements();

            var menuEl = new Element('span', {'class': 'btn-group'}).insert(
                '<span class="btn dropdown-toggle"><button type="button"><i class="icon"><img src="' +
                Jsw.skinUrl + '/icons/16/plesk/menu.png" alt=""></i> <em class="caret"></em></button></span>' +
                '<ul class="dropdown-menu pull-right"></ul>'
            );
            menuEl.observe('click', function (event) {
                event.stopPropagation();
                menuEl.toggleClassName('btn-group-open');

                var dropdownMenu = menuEl.down('.dropdown-menu');
                if (dropdownMenu.visible()) {
                    dropdownMenu.setStyle({
                        right: 0
                    });
                    var offset = dropdownMenu.cumulativeOffset();
                    var left = toolbarEl.cumulativeOffset().left;
                    if (offset.left < left) {
                        dropdownMenu.setStyle({
                            right: (offset.left - left) + 'px'
                        });
                    }
                }
            });
            $(document.body).observe('click', function() {
                menuEl.removeClassName('btn-group-open');
            });
            toolbarEl.insert(menuEl);

            var layout = menuEl.getLayout();
            toolbarEl._menuEl = {
                el: menuEl,
                width: menuEl.getWidth() + layout.get('margin-left') + layout.get('margin-right')
            };
            menuEl.hide();

            toolbarEl._items =[];
            itemEls.each(function (itemEl) {
                var itemElClone = itemEl.clone(true);
                itemElClone.removeClassName('btn');

                var liEl = new Element('li').insert(itemElClone);
                menuEl.down('ul').insert(liEl);

                var layout = itemEl.getLayout();
                toolbarEl._items.push({
                    el: itemEl,
                    elInMenu: liEl,
                    width: itemEl.getWidth() + layout.get('margin-left') + layout.get('margin-right')
                });
            });

        });

        function onWindowResize() {
            $$('.a-toolbar-buttons-main').each(function (toolbarEl) {
                var width = toolbarEl.getWidth();
                width -= toolbarEl._menuEl.width;

                toolbarEl._items.each(function (item) {
                    if (width > item.width) {
                        item.el.show();
                        item.elInMenu.hide();
                        width -= item.width;
                    } else {
                        item.el.hide();
                        item.elInMenu.show();
                        width = -1;
                    }
                });
                if (width == -1) {
                    toolbarEl._menuEl.el.show();
                } else {
                    toolbarEl._menuEl.el.hide();
                }
            });
        }

        onWindowResize();
        Event.observe(window, 'resize', onWindowResize);
    },

    _toggleItem: function(item) {
        item.toggleClassName('active-list-item-collapsed').toggleClassName('active-list-item-expanded');

        var stateCookieName = this.getId() + '-state-collapsed';
        var activeListState = Jsw.Cookie.get(stateCookieName);

        try {
            activeListState = activeListState.evalJSON();
        } catch (e) {
            activeListState = {}
        }

        var stateItemId = item.id.split('-').last();

        if (item.hasClassName('active-list-item-collapsed')) {
            activeListState[stateItemId] = 1;
        } else {
            delete activeListState[stateItemId];
        }

        Jsw.Cookie.setPermanent(stateCookieName, Object.toJSON(activeListState), '/');
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.DirectoryBrowser = Class.create(Jsw.PopupForm, {
    _initConfiguration: function($super, config) {
        $super(config);
        this._pathElementId = this._getConfigParam('pathElementId');
        this._subscriptionId = this._getConfigParam('subscriptionId');
        this._showFiles = this._getConfigParam('showFiles', false);
    },

    render: function($super) {
        $super();

        this.setBoxType('form-box');
        this.setTitle(this._locale.title);

        $(this._contentAreaId).update(
            '<form method="post" id="' + this._id + '-form">' +
                '<div class="single-row">' +
                '<div class="scrollable fm-scrollable" style="height: 300px;">' +
                '<div class="scrollable-wrap">' +
                '<div id="' + this._id + '-files-tree" class="tree"></div>' +
                '</div>' +
                '</div>' +
                '</div>' +
                '</form>'
        );

        this._tree = new Smb.FileManager.Tree({
            applyTo: this._id + '-files-tree',
            data: null,
            dataUrl: '^/smb/file-manager/tree-data/subscriptionId/' + this._subscriptionId,
            showFiles: this._showFiles,
            onNodeClick: this._onTreeNodeClick.bind(this),
            onRootNodeClick: this._onTreeNodeClick.bind(this),
            onReload: function() {
                this.setDirectory('/');
            }
        });

        this._buttonOk = this.addRightButton(this._locale.buttonOk, this._onOkClick, true, true);
        this._buttonCancel = this.addRightButton(this._locale.buttonCancel, this._onCancelClick, false, false);

        if (this._showFiles) {
            this._updateButton(this._buttonOk, {disabled: true});
        }
    },

    _onTreeNodeClick: function() {
        this._updateButton(this._buttonOk, {disabled: this._showFiles && this._tree.getSelectedItemData().isDirectory});
    },

    _onOkClick: function(event) {
        if (event) {
            event.preventDefault();
        }

        var selectedPath = this._tree.getSelectedItemData().path;
        $(this._pathElementId).value = this._showFiles ? selectedPath.substr(1) : selectedPath;
        this.hide();
    },

    _onCancelClick: function() {
        this.hide();
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.DropdownManager = function() {
    var dropdowns = [];

    function closeAllDropdowns() {
        dropdowns.each(function(dropdown) {
            if (dropdown.isOpened()) {
                dropdown.close();
            }
        });
    }

    return {
        register: function (toggler, isOpened, open, close) {
            var dropdown = {
                toggler: toggler,
                isOpened: isOpened,
                open: open,
                close: close,
                handler: function(event) {
                    event.stopPropagation();
                    var oldIsOpened = isOpened();
                    closeAllDropdowns();
                    if (!oldIsOpened) {
                        open(event);
                    }
                }
            };

            dropdowns.push(dropdown);
            dropdown.toggler.observe('click', dropdown.handler);

            if (dropdowns.length > 0) {
                $(document.body).observe('click', closeAllDropdowns);
            }

            return dropdown;
        },

        unregister: function(dropdown) {
            dropdown.toggler.stopObserving('click', dropdown.handler);
            dropdowns = dropdowns.without(dropdown);

            if (dropdowns.length === 0) {
                $(document.body).stopObserving('click', closeAllDropdowns);
            }
        }
    };
}();

// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.ReporterPopup = Class.create(Jsw.PopupForm, {
    _initConfiguration: function($super, config) {
        $super(config);
        this._actionCollectId = this._id + '-action-collect';
        this._actionToSupportId = this._id + '-action-to-support';
        this._sendButtonId = 'btn-send';
        this._cancelButtonId = 'btn-cancel';
        this._supportUrl = this._getConfigParam('supportUrl', '');
    },

    render: function($super) {
        $super();

        this.setBoxType('form-box');
        this.setTitle(this._locale.title);

        this.addRightButton(this._locale.buttonCollect, this._onCollectClick, true, true, {id: this._sendButtonId});
        this.addRightButton(this._locale.buttonCancel, this._onCancelClick, false, false, {id: this._cancelButtonId});
    },

    _initComponentElement: function($super) {
        $super();

        this._componentElement.down('div.content-area').update(
            '<div class="form-row">' +
                '<div class="single-row">' +
                '<div class="field-value">' +
                '<label><input class="radio" type="radio" name="action" id="' + this._actionCollectId + '" checked="checked"> ' + this._locale.actionCollect + this._getTooltip() + '</label>' +
                '</div>' +
                '<div class="field-value">' +
                '<label><input class="radio" type="radio" name="action" id="' + this._actionToSupportId + '"> ' + this._locale.actionToSupport + '</label>' +
                '</div>' +
                '</div>' +
                '</div>' +
                '<a href="#" class="toggler js-show-previous-reports">' + this._locale.showPreviousReports + '</a>' +
                '<a href="#" class="toggler hidden js-hide-previous-reports">' + this._locale.hidePreviousReports + '</a>' +
                '<div id="js-reports"><span class="ajax-loading hidden">' + this._locale.pleaseWait + '</span></div>'
        );
    },

    _onSupportClick: function(close) {
        window.open(this._supportUrl, '_blank');
        this._disableSendButton(this._locale.buttonWait);
        var context = this;
        new Ajax.Request(
            Jsw.prepareUrl('/admin/report/report-usage/'), {
                method: 'post',
                onException: this._onException.bind(this),
                onSuccess: function() {
                    close ? context.hide() : context._enableSendButton(context._locale.buttonToSupport);
                }
            }
        );
    },

    _onCollectClick: function() {
        this._disableSendButton();
        Jsw.AjaxTooltip.unset();
        $(this._contentAreaId).update('<p class="text-center"><span class="ajax-loading">' + this._locale.collecting + this._getTooltip() +'</span></p>');
        this._addTooltips();
        var context = this;
        new Ajax.Request(
            Jsw.prepareUrl('/admin/report/collect/'), {
                method: 'post',
                onException: this._onException.bind(this),
                onSuccess: function(response) {
                    var data = response.responseText.evalJSON();
                    if (context._checkResponseStatus(data)) {
                        Jsw.AjaxTooltip.unset();
                        var link = '<a href="' + Jsw.prepareUrl('/admin/report/download/file/' + encodeURIComponent(data.file)) + '">' + context._locale.downloadLink + '</a>';
                        $(context._contentAreaId).update('<p>' + context.lmsg('collectedInfo', {link: link}) + '</p>');
                        context._enableSendButton(context._locale.buttonSend, context._onSendClick.bind(context, data.file));
                    }
                }
            }
        );
    },

    _onSendClick: function(file) {
        this._disableSendButton(this._locale.buttonSending);
        var context = this;
        new Ajax.Request(
            Jsw.prepareUrl('/admin/report/send/'), {
                method: 'post',
                parameters: {file: file},
                onException: this._onException.bind(this),
                onSuccess: function(response) {
                    var data = response.responseText.evalJSON();
                    if (context._checkResponseStatus(data)) {
                        $(context._contentAreaId).update('<p>' + context.lmsg('sentInfo', {id: data.reportId.escapeHTML()}) + '</p>');
                        context._enableSendButton(context._locale.buttonToSupport, context._onSupportClick.bind(context, false));
                    }
                }
            }
        );
    },

    _onCancelClick: function() {
        this.hide();
    },

    _onShowReportsClick: function(e) {
        e.preventDefault();
        this._componentElement.down('.js-show-previous-reports').addClassName('hidden');
        if (Jsw.getComponent('reports-list') && this._componentElement.down('.list-box')) {
            this._componentElement.down('.list-box').removeClassName('hidden');
            this._componentElement.down('.js-hide-previous-reports').removeClassName('hidden');
            return;
        }
        this._componentElement.down('.ajax-loading').removeClassName('hidden');
        var dialogHeight = this._componentElement.getHeight();
        var list = new Jsw.List({
            id: 'reports-list',
            dataUrl: Jsw.prepareUrl('/admin/report/list-data'),
            pageable: false,
            columns: [
                {
                    header: this._locale.date,
                    dataIndex: 'date'
                }, {
                    header: this._locale.reportId,
                    dataIndex: 'id'
                }
            ],
            onRedraw: function() {
                this._componentElement.down('.js-hide-previous-reports').removeClassName('hidden');
                this._componentElement.down('.ajax-loading').addClassName('hidden');
                var maxHeight = Math.max(document.viewport.getScrollOffsets().top + document.viewport.getHeight() - parseInt(this._componentElement.getStyle('top')) * 1.5 - dialogHeight, 100);
                this._componentElement.down('.list').setStyle({'max-height': parseInt(maxHeight) + 'px'});
            }.bind(this)
        });
        new Jsw.Panel({
            cls: 'list-box',
            renderTo: 'js-reports',
            items: [
                list
            ]
        });
    },

    _onHideReportsClick: function(e) {
        e.preventDefault();
        this._componentElement.down('.list-box').addClassName('hidden');
        this._componentElement.down('.js-show-previous-reports').removeClassName('hidden');
        this._componentElement.down('.js-hide-previous-reports').addClassName('hidden');
    },

    _getButtonsArea: function() {
        return '' +
            '<div class="btns-box" id="' + this._actionButtonsId + '">' +
            '<div class="box-area">' +
            '<div class="form-row">' +
            '<div class="single-row">' +
            '<div class="field-value" id="' + this._rightActionButtonsAreaId + '"> </div>' +
            '</div>' +
            '</div>' +
            '</div>' +
            '</div>';
    },

    _addEvents: function($super) {
        $super();

        $(this._actionCollectId).observe('click', function() {
            this._enableSendButton(this._locale.buttonCollect, this._onCollectClick.bind(this));
        }.bind(this));
        $(this._actionToSupportId).observe('click', function() {
            this._enableSendButton(this._locale.buttonToSupport, this._onSupportClick.bind(this, true));
        }.bind(this));
        this._componentElement.down('.js-show-previous-reports').observe('click', this._onShowReportsClick.bind(this));
        this._componentElement.down('.js-hide-previous-reports').observe('click', this._onHideReportsClick.bind(this));
    },

    _addTooltips: function($super) {
        $super();

        new Jsw.AjaxTooltip.Instance({
            title: this._locale.hintTitle,
            target: $('tooltip'),
            placement: 'right'
        }).setText(this._locale.hintText);
    },

    _getTooltip: function() {
        if (!this._tooltip) {
            this._tooltip = '&nbsp;<span class="s-btn sb-help" id="tooltip">&nbsp;</span>';
        }
        return this._tooltip;
    },

    _disableSendButton: function(title) {
        $(this._sendButtonId).firstDescendant().disable();
        $(this._sendButtonId).addClassName('disabled');
        if (title) {
            $(this._sendButtonId).down('button').update('<span class="wait">' + title + '</span>');
        }
    },

    _enableSendButton: function(title, handler) {
        if (handler) {
            $(this._sendButtonId).down('button').stopObserving('click');
            $(this._sendButtonId).down('button').observe('click', handler);
        }
        if (title) {
            $(this._sendButtonId).down('button').update(title);
        }

        $(this._sendButtonId).firstDescendant().enable();
        $(this._sendButtonId).removeClassName('disabled');
    },

    _checkResponseStatus: function(response) {
        if (response.redirect) {
            Jsw.redirect(response.redirect);
        }

        if (response.status && 'success' != response.status) {
            $A(response.statusMessages).each(function(message) {
                Jsw.addStatusMessage(message.status, message.content);
            });
            this.hide();
            return false;
        }
        return true;
    },

    _onException: function(transport, exception) {
        Jsw.addStatusMessage('error', 'Internal error: ' + exception);
        this.hide();
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.
Jsw.namespace('Jsw.ListContextMenu');

Jsw.ListContextMenu = Class.create(Jsw.Container, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._cls = 'popup-box popup-menu collapsed';
        this._list = this._getConfigParam('list');
    },

    _initComponentElement: function($super) {
        $super();

        this._componentElement.update(
            '<table class="popup-wrapper" cellspacing="0"><tbody><tr><td class="popup-container">' +
                '<div class="c1"><div class="c2"><div class="c3"><div class="c4"><div class="c5">' +
                    '<div class="popup-content">' +
                        '<div class="popup-content-area"></div>' +
                    '</div>' +
                '</div></div></div></div></div>' +
            '</td></tr></tbody></table>'
        );
    },

    /**
     * Called on list redraw
     */
    onRedraw: function() {
        var dropdown;
        this._dropdowns = this._dropdowns || [];
        while (dropdown = this._dropdowns.pop()) {
            Jsw.DropdownManager.unregister(dropdown);
        }

        $$('.btn-list-menu').each(function(contextMenuButton) {
            this._dropdowns.push(Jsw.DropdownManager.register(
                contextMenuButton,
                function() {
                    return contextMenuButton.up('.btn-group').hasClassName('btn-group-open');
                }.bind(this),
                function() {
                    this._toggleMenu(contextMenuButton);
                }.bind(this),
                function() {
                    this._hidePopup();
                }.bind(this)
            ));
        }, this);
        this._initShowOnRowClick();
    },

    /**
     * Show context menu on context menu button click
     */
    _toggleMenu: function(button) {
        var row = this._list.getItemById(button.readAttribute('data-row-id'));
        if (!row || !row.actions || !row.actions.length) {
            return;
        }

        this._prefillPopup(row);
        this._togglePopupNearButton(button);
    },

    /**
     * Get list of actions for popup by row
     */
    _prefillPopup: function(row) {
        var contentArea = this._componentElement.down('.popup-content-area').update('<ul></ul>');
        contentArea = contentArea.down('ul');
        row.actions.each(function(actionInfo) {
            if (actionInfo.separator) {
                contentArea.insert('<li class="separator"><span></span></li>');
                return;
            }
            var item = new Element('li').update(
                '<a class="sb-btn ' + (actionInfo.iconClass ? actionInfo.iconClass : 'sb-no-icon') + '" ' +
                    'href="' + (actionInfo.href ? Jsw.prepareUrl(actionInfo.href) : '#') + '" ' +
                    (actionInfo.newWindow ? 'target="_blank" ' : '') +
                    (actionInfo.onclick ? 'onclick="' + actionInfo.onclick + '" ' : '') +
                '>' +
                    '<i><i><i><span' + (actionInfo.classLabel ? ' class="'+actionInfo.classLabel+'"' : '') + '>' + actionInfo.title + '</span></i></i></i>' +
                '</a>'
            );

            if (this._list._itemActions && this._list._itemActions[actionInfo.name]) {
                item.down('a').observe('click', function() {
                    this._list._itemActions[actionInfo.name](row);
                }.bind(this));
            }

            contentArea.insert(item);
        }, this);
    },

    /**
     * Show prefilled popup on context menu button click
     */
    _togglePopupNearButton: function(button) {
        $(this._list._tableId).select('tr.odd,tr.even').each(function(el) {
            el.removeClassName('row-over');
        });
        this._componentElement.addClassName('collapsed');

        if (!button.up('.btn-group').hasClassName('btn-group-open')) {
            $$('.btn-list-menu').each(function(el) {
                el.up('.btn-group').removeClassName('btn-group-open');
            });

            this._componentElement.removeClassName('collapsed');
            button.up('tr').addClassName('row-over');
        }

        button.up('.btn-group').toggleClassName('btn-group-open');

        var scrollOffsets = document.viewport.getScrollOffsets();
        var buttonPosition = button.viewportOffset();
        buttonPosition.left += scrollOffsets.left;
        buttonPosition.top += scrollOffsets.top;

        var buttonWidth = button.getWidth();
        var buttonHeight = button.getHeight();

        if (!this._componentElement.hasClassName('collapsed')) {
            this._setPosition(
                buttonPosition.left,
                buttonPosition.top + buttonHeight,
                buttonPosition.left + buttonWidth,
                buttonPosition.top
            );
        }
    },

    /**
     * Hide popup and remove selection from row
     */
    _hidePopup: function() {
        this._componentElement.addClassName('collapsed');
        $(this._list._tableId).select('tr.odd,tr.even').each(function(el) {
            el.removeClassName('row-over');
        });
        $$('.btn-list-menu').each(function(menu) {
            menu.up('.btn-group').removeClassName('btn-group-open');
        });
    },

    /**
     * Show popup on click on row
     */
    _initShowOnRowClick: function() {
        $(this._list._tableId).select('tr.odd,tr.even').each(function(el) {
            var button = el.down('.dropdown-toggle');
            if (!button) {
                return;
            }

            var row = this._list.getItemById(button.readAttribute('data-row-id'));
            if (!row || !row.actions || !row.actions.length) {
                return;
            }

            el.addClassName('list-context-actions');
            Jsw.DropdownManager.register(
                el,
                function() {
                    return !this._componentElement.hasClassName('collapsed');
                }.bind(this),
                function(e) {
                    if (e.findElement('a, input')) {
                        return;
                    }

                    var row = this._list.getItemById(button.readAttribute('data-row-id'));
                    if (!row || !row.actions || !row.actions.length) {
                        return;
                    }
                    this._prefillPopup(row);

                    this._componentElement.removeClassName('collapsed');
                    el.addClassName('row-over');
                    this._setPosition(Event.pointerX(e), Event.pointerY(e));

                }.bind(this),
                function() {
                    this._hidePopup(row);
                }.bind(this)
            );
        }, this);
    },

    _setPosition: function(x, y, altX, altY) {
        altX = altX || x;
        altY = altY || y;

        var scrollOffsets = document.viewport.getScrollOffsets();

        var windowWidth = $(document.body).getWidth();
        var popupWidth = this._componentElement.getWidth();
        if (Jsw.isRtl()) {
            if ((altX - popupWidth - scrollOffsets.left) > 0) {
                x = altX - popupWidth;
            }
        } else {
            if ((x + popupWidth - scrollOffsets.left) > windowWidth) {
                x = altX - popupWidth;
            }
        }

        var windowHeight = $(document.body).getHeight();
        var popupHeight = this._componentElement.getHeight();
        var popupMarginTop = parseInt(this._componentElement.getStyle('margin-top'));
        if ((y + popupHeight + popupMarginTop - scrollOffsets.top) > windowHeight) {
            y = altY - popupHeight - 2 * popupMarginTop;
        }

        this._componentElement.setStyle({
            right: 'auto',
            left: x + 'px',
            top: y + 'px'
        });
    }
});

// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.ObjectSwitcher = Class.create(Jsw.LookUp, {
    _tag: 'span',

    _initConfiguration: function($super, config) {
        $super(config);

        this._cls = this._getConfigParam('cls', 'btn-group object-switcher');
        this._listUrl = this._getConfigParam('listUrl', '');
        this._itemUrlTemplate = this._getConfigParam('itemUrlTemplate', '');
        this._owner = this._getConfigParam('owner', null);
    },

    _initCustomLookUpComponent: function() {
        this._customLookUpComponent = new Element('button' , {'type': 'button', 'class': 'btn dropdown-toggle'}).update('···');
        this._componentElement.insert(this._customLookUpComponent);
    },

    _addEvents: function($super) {
        $super();

        this.addEventObserver('component:change', function() {
            Jsw.redirect(this._itemUrlTemplate.interpolate(this._currentValue, /(^|.|\r|\n)(%%(\w+)%%)/));
        }.bind(this));
    },

    _getSearchMoreText: function($super, count) {
        return $super(count)
            + (this._listUrl ? ' ' + this.lmsg('refineSearchMessage', {link: '<a href="' + this._listUrl + '">' + this.lmsg('listOfAllObjects') + '</a>'}) : '');
    },

    _updateData: function(data) {
        this._clearData();

        var myData = [];

        if (null != this._owner) {
            myData = data.filter(function(item) {
                return 1 == item.isSameParent;
            }.bind(this));

            data = data.filter(function(item) {
                return 1 != item.isSameParent;
            }.bind(this));
        }

        var itemElement, insertTo = this._emptyElement;
        if (myData.length) {
            if (data.length) {
                this._dropdownList.insert(new Element('li', {'class': 'dropdown-header'})
                    .update(this.lmsg('myObjectsLabel', {name: this._owner})));
            }

            myData.each(function (item) {
                this._dropdownList.insert(this._createItem(item));
            }.bind(this));

            if (data.length) {
                this._dropdownList.insert(new Element('li', {'class': 'divider'}));
                this._dropdownList.insert(new Element('li', {'class': 'dropdown-header'})
                    .update(this.lmsg('otherObjectsLabel')));
            }
        }

        data.each(function(item) {
            this._dropdownList.insert(this._createItem(item));
        }.bind(this));

        this._addSearchMoreElement();
    },

    _addTooltips: function() {
        this._tooltip = Jsw.Tooltip.init(this._customLookUpComponent, {text: this.lmsg('description')});
    }
});
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.

Jsw.ViewSwitcher = Class.create(Jsw.Component, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._cls = 'view-switcher';
        this._isPowerUserPanel = this._getConfigParam('isPowerUserPanel');
        this._showPowerUserViewWarning = this._getConfigParam('showPowerUserViewWarning');
        this._learnMoreUrl = this._getConfigParam('learnMoreUrl');
    },

    _initComponentElement: function($super) {
        $super();

        this._updateComponentElement(
            '<span class="close"></span>' +
            '<a href="#"><i class="icon-navigation"></i> ' + this.lmsg('title') + '</a>'
        );
    },

    _addEvents: function($super) {
        $super();

        this._componentElement.down('span').observe('click', function(event) {
            event.preventDefault();

            Jsw.messageBox.show({
                'type': Jsw.messageBox.TYPE_YESNO,
                'subtype': 'toggle',
                'text': this.lmsg('confirmationBoxText'),
                'description': this.lmsg('confirmationBoxDescription'),
                'buttonTitles': {
                    'yes': this.lmsg('confirmationBoxButtonYes'),
                    'no': this.lmsg('confirmationBoxButtonNo')
                },
                'onYesClick': function() {
                    this.hide();
                    new Ajax.Request('/admin/index/hide-view-switcher', {method: 'post'});
                }.bind(this)
            });
        }.bindAsEventListener(this));

        this._componentElement.down('a').observe('click', function(event) {
            event.stop();

            var popover = this._getPopоver();
            popover.toggleClassName('collapsed');
            if (popover.hasClassName('collapsed')) {
                return;
            }

            var pos = $$('.view-switcher').first().cumulativeOffset();
            var popHeight = popover.getHeight();
            var topPos = pos[1] + document.viewport.getScrollOffsets().top - popHeight + 'px';
            popover.setStyle({'top': topPos});
        }.bindAsEventListener(this));

        Event.observe(window, 'scroll', function() {
            this._getPopоver().addClassName('collapsed');
        }.bind(this));
    },

    _getPopоver: function() {
        if (!this._popover) {
            this._popover = new Element('div', {'class': 'popup-box top view-switcher-popover collapsed'}).update(
                '<table cellspacing="0" class="popup-wrapper"><tbody><tr><td class="popup-container">' +
                    '<div class="c1"><div class="c2"><div class="c3"><div class="c4"><div class="c5">' +
                        '<div class="popup-heading">' +
                            '<div class="heading-area">' +
                                '<span class="close"></span>' +
                                '<h4><span>' + this.lmsg('title') + '</span></h4>' +
                            '</div>' +
                        '</div>' +
                        '<div class="popup-content">' +
                            '<div class="popup-content-area">' +
                                '<span class="arrow"></span>' +
                                this.lmsg('currentViewMessage', {view: this.lmsg(this._isPowerUserPanel ? 'powerUserView' : 'serviceProviderView')}) +
                                '<p>' + this.lmsg('actionMessage', {
                                    switchLink: '<a href="#" class="js-switch-view">' + this.lmsg('switchView', {view: this.lmsg(this._isPowerUserPanel ? 'serviceProviderView' : 'powerUserView')}) + '</a>',
                                    helpLink: '<a href="' + this._learnMoreUrl + '">' + this.lmsg('learnMore') + '</a>'
                                }) + '</p>' +
                                (this._showPowerUserViewWarning ? '<i class="icon-attention-tr"></i> ' + this.lmsg('powerUserViewWarning') : '') +
                            '</div>' +
                        '</div>' +
                    '</div></div></div></div></div>' +
                '</td></tr></tbody></table>'
            );
            this._popover.down('.heading-area .close').observe('click', function(event) {
                event.preventDefault();
                this._popover.addClassName('collapsed');
            }.bindAsEventListener(this));
            this._popover.down('.popup-content-area .js-switch-view').observe('click', function(event) {
                event.preventDefault();
                new Ajax.Request(Jsw.prepareUrl('/admin/index/change-view'), {
                    method: 'post',
                    onSuccess: function(transport) {
                        var result = transport.responseText.evalJSON();
                        if (result.redirect) {
                            Jsw.redirect(result.redirect);
                        }
                    }
                });
                this._popover.addClassName('collapsed');
            }.bindAsEventListener(this));
            this._popover.observe('click', function(event) {
                event.stopPropagation();
            }.bindAsEventListener(this));
            $(document.body).observe('click', function() {
                this._popover.addClassName('collapsed');
            }.bind(this));

            $(document.body).insert(this._popover);
        }

        return this._popover;
    }
});
